(function(){"use strict";var Vn={exports:{}},Du={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var gc;function Ho(){if(gc)return Du;gc=1;var E=Symbol.for("react.transitional.element"),cl=Symbol.for("react.fragment");function k(h,vl,Sl){var rl=null;if(Sl!==void 0&&(rl=""+Sl),vl.key!==void 0&&(rl=""+vl.key),"key"in vl){Sl={};for(var Dl in vl)Dl!=="key"&&(Sl[Dl]=vl[Dl])}else Sl=vl;return vl=Sl.ref,{$$typeof:E,type:h,key:rl,ref:vl!==void 0?vl:null,props:Sl}}return Du.Fragment=cl,Du.jsx=k,Du.jsxs=k,Du}var Sc;function Ro(){return Sc||(Sc=1,Vn.exports=Ho()),Vn.exports}var U=Ro(),Ln={exports:{}},Uu={},Kn={exports:{}},Jn={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var rc;function No(){return rc||(rc=1,(function(E){function cl(r,A){var B=r.length;r.push(A);l:for(;0<B;){var el=B-1>>>1,sl=r[el];if(0<vl(sl,A))r[el]=A,r[B]=sl,B=el;else break l}}function k(r){return r.length===0?null:r[0]}function h(r){if(r.length===0)return null;var A=r[0],B=r.pop();if(B!==A){r[0]=B;l:for(var el=0,sl=r.length,d=sl>>>1;el<d;){var p=2*(el+1)-1,_=r[p],M=p+1,q=r[M];if(0>vl(_,B))M<sl&&0>vl(q,_)?(r[el]=q,r[M]=B,el=M):(r[el]=_,r[p]=B,el=p);else if(M<sl&&0>vl(q,B))r[el]=q,r[M]=B,el=M;else break l}}return A}function vl(r,A){var B=r.sortIndex-A.sortIndex;return B!==0?B:r.id-A.id}if(E.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var Sl=performance;E.unstable_now=function(){return Sl.now()}}else{var rl=Date,Dl=rl.now();E.unstable_now=function(){return rl.now()-Dl}}var x=[],T=[],$=1,R=null,F=3,Gl=!1,Xl=!1,Rl=!1,Pl=!1,Ul=typeof setTimeout=="function"?setTimeout:null,C=typeof clearTimeout=="function"?clearTimeout:null,bl=typeof setImmediate<"u"?setImmediate:null;function dt(r){for(var A=k(T);A!==null;){if(A.callback===null)h(T);else if(A.startTime<=r)h(T),A.sortIndex=A.expirationTime,cl(x,A);else break;A=k(T)}}function _t(r){if(Rl=!1,dt(r),!Xl)if(k(x)!==null)Xl=!0,Vl||(Vl=!0,Kl());else{var A=k(T);A!==null&&pt(_t,A.startTime-r)}}var Vl=!1,w=-1,Ll=5,Ot=-1;function Va(){return Pl?!0:!(E.unstable_now()-Ot<Ll)}function Mt(){if(Pl=!1,Vl){var r=E.unstable_now();Ot=r;var A=!0;try{l:{Xl=!1,Rl&&(Rl=!1,C(w),w=-1),Gl=!0;var B=F;try{t:{for(dt(r),R=k(x);R!==null&&!(R.expirationTime>r&&Va());){var el=R.callback;if(typeof el=="function"){R.callback=null,F=R.priorityLevel;var sl=el(R.expirationTime<=r);if(r=E.unstable_now(),typeof sl=="function"){R.callback=sl,dt(r),A=!0;break t}R===k(x)&&h(x),dt(r)}else h(x);R=k(x)}if(R!==null)A=!0;else{var d=k(T);d!==null&&pt(_t,d.startTime-r),A=!1}}break l}finally{R=null,F=B,Gl=!1}A=void 0}}finally{A?Kl():Vl=!1}}}var Kl;if(typeof bl=="function")Kl=function(){bl(Mt)};else if(typeof MessageChannel<"u"){var Ea=new MessageChannel,Nt=Ea.port2;Ea.port1.onmessage=Mt,Kl=function(){Nt.postMessage(null)}}else Kl=function(){Ul(Mt,0)};function pt(r,A){w=Ul(function(){r(E.unstable_now())},A)}E.unstable_IdlePriority=5,E.unstable_ImmediatePriority=1,E.unstable_LowPriority=4,E.unstable_NormalPriority=3,E.unstable_Profiling=null,E.unstable_UserBlockingPriority=2,E.unstable_cancelCallback=function(r){r.callback=null},E.unstable_forceFrameRate=function(r){0>r||125<r?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):Ll=0<r?Math.floor(1e3/r):5},E.unstable_getCurrentPriorityLevel=function(){return F},E.unstable_next=function(r){switch(F){case 1:case 2:case 3:var A=3;break;default:A=F}var B=F;F=A;try{return r()}finally{F=B}},E.unstable_requestPaint=function(){Pl=!0},E.unstable_runWithPriority=function(r,A){switch(r){case 1:case 2:case 3:case 4:case 5:break;default:r=3}var B=F;F=r;try{return A()}finally{F=B}},E.unstable_scheduleCallback=function(r,A,B){var el=E.unstable_now();switch(typeof B=="object"&&B!==null?(B=B.delay,B=typeof B=="number"&&0<B?el+B:el):B=el,r){case 1:var sl=-1;break;case 2:sl=250;break;case 5:sl=1073741823;break;case 4:sl=1e4;break;default:sl=5e3}return sl=B+sl,r={id:$++,callback:A,priorityLevel:r,startTime:B,expirationTime:sl,sortIndex:-1},B>el?(r.sortIndex=B,cl(T,r),k(x)===null&&r===k(T)&&(Rl?(C(w),w=-1):Rl=!0,pt(_t,B-el))):(r.sortIndex=sl,cl(x,r),Xl||Gl||(Xl=!0,Vl||(Vl=!0,Kl()))),r},E.unstable_shouldYield=Va,E.unstable_wrapCallback=function(r){var A=F;return function(){var B=F;F=A;try{return r.apply(this,arguments)}finally{F=B}}}})(Jn)),Jn}var bc;function Co(){return bc||(bc=1,Kn.exports=No()),Kn.exports}var wn={exports:{}},j={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var zc;function Bo(){if(zc)return j;zc=1;var E=Symbol.for("react.transitional.element"),cl=Symbol.for("react.portal"),k=Symbol.for("react.fragment"),h=Symbol.for("react.strict_mode"),vl=Symbol.for("react.profiler"),Sl=Symbol.for("react.consumer"),rl=Symbol.for("react.context"),Dl=Symbol.for("react.forward_ref"),x=Symbol.for("react.suspense"),T=Symbol.for("react.memo"),$=Symbol.for("react.lazy"),R=Symbol.for("react.activity"),F=Symbol.iterator;function Gl(d){return d===null||typeof d!="object"?null:(d=F&&d[F]||d["@@iterator"],typeof d=="function"?d:null)}var Xl={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},Rl=Object.assign,Pl={};function Ul(d,p,_){this.props=d,this.context=p,this.refs=Pl,this.updater=_||Xl}Ul.prototype.isReactComponent={},Ul.prototype.setState=function(d,p){if(typeof d!="object"&&typeof d!="function"&&d!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,d,p,"setState")},Ul.prototype.forceUpdate=function(d){this.updater.enqueueForceUpdate(this,d,"forceUpdate")};function C(){}C.prototype=Ul.prototype;function bl(d,p,_){this.props=d,this.context=p,this.refs=Pl,this.updater=_||Xl}var dt=bl.prototype=new C;dt.constructor=bl,Rl(dt,Ul.prototype),dt.isPureReactComponent=!0;var _t=Array.isArray;function Vl(){}var w={H:null,A:null,T:null,S:null},Ll=Object.prototype.hasOwnProperty;function Ot(d,p,_){var M=_.ref;return{$$typeof:E,type:d,key:p,ref:M!==void 0?M:null,props:_}}function Va(d,p){return Ot(d.type,p,d.props)}function Mt(d){return typeof d=="object"&&d!==null&&d.$$typeof===E}function Kl(d){var p={"=":"=0",":":"=2"};return"$"+d.replace(/[=:]/g,function(_){return p[_]})}var Ea=/\/+/g;function Nt(d,p){return typeof d=="object"&&d!==null&&d.key!=null?Kl(""+d.key):p.toString(36)}function pt(d){switch(d.status){case"fulfilled":return d.value;case"rejected":throw d.reason;default:switch(typeof d.status=="string"?d.then(Vl,Vl):(d.status="pending",d.then(function(p){d.status==="pending"&&(d.status="fulfilled",d.value=p)},function(p){d.status==="pending"&&(d.status="rejected",d.reason=p)})),d.status){case"fulfilled":return d.value;case"rejected":throw d.reason}}throw d}function r(d,p,_,M,q){var Q=typeof d;(Q==="undefined"||Q==="boolean")&&(d=null);var tl=!1;if(d===null)tl=!0;else switch(Q){case"bigint":case"string":case"number":tl=!0;break;case"object":switch(d.$$typeof){case E:case cl:tl=!0;break;case $:return tl=d._init,r(tl(d._payload),p,_,M,q)}}if(tl)return q=q(d),tl=M===""?"."+Nt(d,0):M,_t(q)?(_="",tl!=null&&(_=tl.replace(Ea,"$&/")+"/"),r(q,p,_,"",function(xu){return xu})):q!=null&&(Mt(q)&&(q=Va(q,_+(q.key==null||d&&d.key===q.key?"":(""+q.key).replace(Ea,"$&/")+"/")+tl)),p.push(q)),1;tl=0;var Ql=M===""?".":M+":";if(_t(d))for(var zl=0;zl<d.length;zl++)M=d[zl],Q=Ql+Nt(M,zl),tl+=r(M,p,_,Q,q);else if(zl=Gl(d),typeof zl=="function")for(d=zl.call(d),zl=0;!(M=d.next()).done;)M=M.value,Q=Ql+Nt(M,zl++),tl+=r(M,p,_,Q,q);else if(Q==="object"){if(typeof d.then=="function")return r(pt(d),p,_,M,q);throw p=String(d),Error("Objects are not valid as a React child (found: "+(p==="[object Object]"?"object with keys {"+Object.keys(d).join(", ")+"}":p)+"). If you meant to render a collection of children, use an array instead.")}return tl}function A(d,p,_){if(d==null)return d;var M=[],q=0;return r(d,M,"","",function(Q){return p.call(_,Q,q++)}),M}function B(d){if(d._status===-1){var p=d._result;p=p(),p.then(function(_){(d._status===0||d._status===-1)&&(d._status=1,d._result=_)},function(_){(d._status===0||d._status===-1)&&(d._status=2,d._result=_)}),d._status===-1&&(d._status=0,d._result=p)}if(d._status===1)return d._result.default;throw d._result}var el=typeof reportError=="function"?reportError:function(d){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var p=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof d=="object"&&d!==null&&typeof d.message=="string"?String(d.message):String(d),error:d});if(!window.dispatchEvent(p))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",d);return}console.error(d)},sl={map:A,forEach:function(d,p,_){A(d,function(){p.apply(this,arguments)},_)},count:function(d){var p=0;return A(d,function(){p++}),p},toArray:function(d){return A(d,function(p){return p})||[]},only:function(d){if(!Mt(d))throw Error("React.Children.only expected to receive a single React element child.");return d}};return j.Activity=R,j.Children=sl,j.Component=Ul,j.Fragment=k,j.Profiler=vl,j.PureComponent=bl,j.StrictMode=h,j.Suspense=x,j.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=w,j.__COMPILER_RUNTIME={__proto__:null,c:function(d){return w.H.useMemoCache(d)}},j.cache=function(d){return function(){return d.apply(null,arguments)}},j.cacheSignal=function(){return null},j.cloneElement=function(d,p,_){if(d==null)throw Error("The argument must be a React element, but you passed "+d+".");var M=Rl({},d.props),q=d.key;if(p!=null)for(Q in p.key!==void 0&&(q=""+p.key),p)!Ll.call(p,Q)||Q==="key"||Q==="__self"||Q==="__source"||Q==="ref"&&p.ref===void 0||(M[Q]=p[Q]);var Q=arguments.length-2;if(Q===1)M.children=_;else if(1<Q){for(var tl=Array(Q),Ql=0;Ql<Q;Ql++)tl[Ql]=arguments[Ql+2];M.children=tl}return Ot(d.type,q,M)},j.createContext=function(d){return d={$$typeof:rl,_currentValue:d,_currentValue2:d,_threadCount:0,Provider:null,Consumer:null},d.Provider=d,d.Consumer={$$typeof:Sl,_context:d},d},j.createElement=function(d,p,_){var M,q={},Q=null;if(p!=null)for(M in p.key!==void 0&&(Q=""+p.key),p)Ll.call(p,M)&&M!=="key"&&M!=="__self"&&M!=="__source"&&(q[M]=p[M]);var tl=arguments.length-2;if(tl===1)q.children=_;else if(1<tl){for(var Ql=Array(tl),zl=0;zl<tl;zl++)Ql[zl]=arguments[zl+2];q.children=Ql}if(d&&d.defaultProps)for(M in tl=d.defaultProps,tl)q[M]===void 0&&(q[M]=tl[M]);return Ot(d,Q,q)},j.createRef=function(){return{current:null}},j.forwardRef=function(d){return{$$typeof:Dl,render:d}},j.isValidElement=Mt,j.lazy=function(d){return{$$typeof:$,_payload:{_status:-1,_result:d},_init:B}},j.memo=function(d,p){return{$$typeof:T,type:d,compare:p===void 0?null:p}},j.startTransition=function(d){var p=w.T,_={};w.T=_;try{var M=d(),q=w.S;q!==null&&q(_,M),typeof M=="object"&&M!==null&&typeof M.then=="function"&&M.then(Vl,el)}catch(Q){el(Q)}finally{p!==null&&_.types!==null&&(p.types=_.types),w.T=p}},j.unstable_useCacheRefresh=function(){return w.H.useCacheRefresh()},j.use=function(d){return w.H.use(d)},j.useActionState=function(d,p,_){return w.H.useActionState(d,p,_)},j.useCallback=function(d,p){return w.H.useCallback(d,p)},j.useContext=function(d){return w.H.useContext(d)},j.useDebugValue=function(){},j.useDeferredValue=function(d,p){return w.H.useDeferredValue(d,p)},j.useEffect=function(d,p){return w.H.useEffect(d,p)},j.useEffectEvent=function(d){return w.H.useEffectEvent(d)},j.useId=function(){return w.H.useId()},j.useImperativeHandle=function(d,p,_){return w.H.useImperativeHandle(d,p,_)},j.useInsertionEffect=function(d,p){return w.H.useInsertionEffect(d,p)},j.useLayoutEffect=function(d,p){return w.H.useLayoutEffect(d,p)},j.useMemo=function(d,p){return w.H.useMemo(d,p)},j.useOptimistic=function(d,p){return w.H.useOptimistic(d,p)},j.useReducer=function(d,p,_){return w.H.useReducer(d,p,_)},j.useRef=function(d){return w.H.useRef(d)},j.useState=function(d){return w.H.useState(d)},j.useSyncExternalStore=function(d,p,_){return w.H.useSyncExternalStore(d,p,_)},j.useTransition=function(){return w.H.useTransition()},j.version="19.2.4",j}var pc;function Wn(){return pc||(pc=1,wn.exports=Bo()),wn.exports}var kn={exports:{}},Yl={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Tc;function jo(){if(Tc)return Yl;Tc=1;var E=Wn();function cl(x){var T="https://react.dev/errors/"+x;if(1<arguments.length){T+="?args[]="+encodeURIComponent(arguments[1]);for(var $=2;$<arguments.length;$++)T+="&args[]="+encodeURIComponent(arguments[$])}return"Minified React error #"+x+"; visit "+T+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function k(){}var h={d:{f:k,r:function(){throw Error(cl(522))},D:k,C:k,L:k,m:k,X:k,S:k,M:k},p:0,findDOMNode:null},vl=Symbol.for("react.portal");function Sl(x,T,$){var R=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:vl,key:R==null?null:""+R,children:x,containerInfo:T,implementation:$}}var rl=E.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function Dl(x,T){if(x==="font")return"";if(typeof T=="string")return T==="use-credentials"?T:""}return Yl.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=h,Yl.createPortal=function(x,T){var $=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!T||T.nodeType!==1&&T.nodeType!==9&&T.nodeType!==11)throw Error(cl(299));return Sl(x,T,null,$)},Yl.flushSync=function(x){var T=rl.T,$=h.p;try{if(rl.T=null,h.p=2,x)return x()}finally{rl.T=T,h.p=$,h.d.f()}},Yl.preconnect=function(x,T){typeof x=="string"&&(T?(T=T.crossOrigin,T=typeof T=="string"?T==="use-credentials"?T:"":void 0):T=null,h.d.C(x,T))},Yl.prefetchDNS=function(x){typeof x=="string"&&h.d.D(x)},Yl.preinit=function(x,T){if(typeof x=="string"&&T&&typeof T.as=="string"){var $=T.as,R=Dl($,T.crossOrigin),F=typeof T.integrity=="string"?T.integrity:void 0,Gl=typeof T.fetchPriority=="string"?T.fetchPriority:void 0;$==="style"?h.d.S(x,typeof T.precedence=="string"?T.precedence:void 0,{crossOrigin:R,integrity:F,fetchPriority:Gl}):$==="script"&&h.d.X(x,{crossOrigin:R,integrity:F,fetchPriority:Gl,nonce:typeof T.nonce=="string"?T.nonce:void 0})}},Yl.preinitModule=function(x,T){if(typeof x=="string")if(typeof T=="object"&&T!==null){if(T.as==null||T.as==="script"){var $=Dl(T.as,T.crossOrigin);h.d.M(x,{crossOrigin:$,integrity:typeof T.integrity=="string"?T.integrity:void 0,nonce:typeof T.nonce=="string"?T.nonce:void 0})}}else T==null&&h.d.M(x)},Yl.preload=function(x,T){if(typeof x=="string"&&typeof T=="object"&&T!==null&&typeof T.as=="string"){var $=T.as,R=Dl($,T.crossOrigin);h.d.L(x,$,{crossOrigin:R,integrity:typeof T.integrity=="string"?T.integrity:void 0,nonce:typeof T.nonce=="string"?T.nonce:void 0,type:typeof T.type=="string"?T.type:void 0,fetchPriority:typeof T.fetchPriority=="string"?T.fetchPriority:void 0,referrerPolicy:typeof T.referrerPolicy=="string"?T.referrerPolicy:void 0,imageSrcSet:typeof T.imageSrcSet=="string"?T.imageSrcSet:void 0,imageSizes:typeof T.imageSizes=="string"?T.imageSizes:void 0,media:typeof T.media=="string"?T.media:void 0})}},Yl.preloadModule=function(x,T){if(typeof x=="string")if(T){var $=Dl(T.as,T.crossOrigin);h.d.m(x,{as:typeof T.as=="string"&&T.as!=="script"?T.as:void 0,crossOrigin:$,integrity:typeof T.integrity=="string"?T.integrity:void 0})}else h.d.m(x)},Yl.requestFormReset=function(x){h.d.r(x)},Yl.unstable_batchedUpdates=function(x,T){return x(T)},Yl.useFormState=function(x,T,$){return rl.H.useFormState(x,T,$)},Yl.useFormStatus=function(){return rl.H.useHostTransitionStatus()},Yl.version="19.2.4",Yl}var Ec;function qo(){if(Ec)return kn.exports;Ec=1;function E(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(E)}catch(cl){console.error(cl)}}return E(),kn.exports=jo(),kn.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Ac;function Yo(){if(Ac)return Uu;Ac=1;var E=Co(),cl=Wn(),k=qo();function h(l){var t="https://react.dev/errors/"+l;if(1<arguments.length){t+="?args[]="+encodeURIComponent(arguments[1]);for(var a=2;a<arguments.length;a++)t+="&args[]="+encodeURIComponent(arguments[a])}return"Minified React error #"+l+"; visit "+t+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function vl(l){return!(!l||l.nodeType!==1&&l.nodeType!==9&&l.nodeType!==11)}function Sl(l){var t=l,a=l;if(l.alternate)for(;t.return;)t=t.return;else{l=t;do t=l,(t.flags&4098)!==0&&(a=t.return),l=t.return;while(l)}return t.tag===3?a:null}function rl(l){if(l.tag===13){var t=l.memoizedState;if(t===null&&(l=l.alternate,l!==null&&(t=l.memoizedState)),t!==null)return t.dehydrated}return null}function Dl(l){if(l.tag===31){var t=l.memoizedState;if(t===null&&(l=l.alternate,l!==null&&(t=l.memoizedState)),t!==null)return t.dehydrated}return null}function x(l){if(Sl(l)!==l)throw Error(h(188))}function T(l){var t=l.alternate;if(!t){if(t=Sl(l),t===null)throw Error(h(188));return t!==l?null:l}for(var a=l,u=t;;){var e=a.return;if(e===null)break;var n=e.alternate;if(n===null){if(u=e.return,u!==null){a=u;continue}break}if(e.child===n.child){for(n=e.child;n;){if(n===a)return x(e),l;if(n===u)return x(e),t;n=n.sibling}throw Error(h(188))}if(a.return!==u.return)a=e,u=n;else{for(var f=!1,i=e.child;i;){if(i===a){f=!0,a=e,u=n;break}if(i===u){f=!0,u=e,a=n;break}i=i.sibling}if(!f){for(i=n.child;i;){if(i===a){f=!0,a=n,u=e;break}if(i===u){f=!0,u=n,a=e;break}i=i.sibling}if(!f)throw Error(h(189))}}if(a.alternate!==u)throw Error(h(190))}if(a.tag!==3)throw Error(h(188));return a.stateNode.current===a?l:t}function $(l){var t=l.tag;if(t===5||t===26||t===27||t===6)return l;for(l=l.child;l!==null;){if(t=$(l),t!==null)return t;l=l.sibling}return null}var R=Object.assign,F=Symbol.for("react.element"),Gl=Symbol.for("react.transitional.element"),Xl=Symbol.for("react.portal"),Rl=Symbol.for("react.fragment"),Pl=Symbol.for("react.strict_mode"),Ul=Symbol.for("react.profiler"),C=Symbol.for("react.consumer"),bl=Symbol.for("react.context"),dt=Symbol.for("react.forward_ref"),_t=Symbol.for("react.suspense"),Vl=Symbol.for("react.suspense_list"),w=Symbol.for("react.memo"),Ll=Symbol.for("react.lazy"),Ot=Symbol.for("react.activity"),Va=Symbol.for("react.memo_cache_sentinel"),Mt=Symbol.iterator;function Kl(l){return l===null||typeof l!="object"?null:(l=Mt&&l[Mt]||l["@@iterator"],typeof l=="function"?l:null)}var Ea=Symbol.for("react.client.reference");function Nt(l){if(l==null)return null;if(typeof l=="function")return l.$$typeof===Ea?null:l.displayName||l.name||null;if(typeof l=="string")return l;switch(l){case Rl:return"Fragment";case Ul:return"Profiler";case Pl:return"StrictMode";case _t:return"Suspense";case Vl:return"SuspenseList";case Ot:return"Activity"}if(typeof l=="object")switch(l.$$typeof){case Xl:return"Portal";case bl:return l.displayName||"Context";case C:return(l._context.displayName||"Context")+".Consumer";case dt:var t=l.render;return l=l.displayName,l||(l=t.displayName||t.name||"",l=l!==""?"ForwardRef("+l+")":"ForwardRef"),l;case w:return t=l.displayName||null,t!==null?t:Nt(l.type)||"Memo";case Ll:t=l._payload,l=l._init;try{return Nt(l(t))}catch{}}return null}var pt=Array.isArray,r=cl.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,A=k.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,B={pending:!1,data:null,method:null,action:null},el=[],sl=-1;function d(l){return{current:l}}function p(l){0>sl||(l.current=el[sl],el[sl]=null,sl--)}function _(l,t){sl++,el[sl]=l.current,l.current=t}var M=d(null),q=d(null),Q=d(null),tl=d(null);function Ql(l,t){switch(_(Q,t),_(q,l),_(M,null),t.nodeType){case 9:case 11:l=(l=t.documentElement)&&(l=l.namespaceURI)?P0(l):0;break;default:if(l=t.tagName,t=t.namespaceURI)t=P0(t),l=lo(t,l);else switch(l){case"svg":l=1;break;case"math":l=2;break;default:l=0}}p(M),_(M,l)}function zl(){p(M),p(q),p(Q)}function xu(l){l.memoizedState!==null&&_(tl,l);var t=M.current,a=lo(t,l.type);t!==a&&(_(q,l),_(M,a))}function Ae(l){q.current===l&&(p(M),p(q)),tl.current===l&&(p(tl),be._currentValue=B)}var Fn,Uc;function Aa(l){if(Fn===void 0)try{throw Error()}catch(a){var t=a.stack.trim().match(/\n( *(at )?)/);Fn=t&&t[1]||"",Uc=-1<a.stack.indexOf(`
    at`)?" (<anonymous>)":-1<a.stack.indexOf("@")?"@unknown:0:0":""}return`
`+Fn+l+Uc}var In=!1;function Pn(l,t){if(!l||In)return"";In=!0;var a=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var u={DetermineComponentFrameRoot:function(){try{if(t){var z=function(){throw Error()};if(Object.defineProperty(z.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(z,[])}catch(g){var m=g}Reflect.construct(l,[],z)}else{try{z.call()}catch(g){m=g}l.call(z.prototype)}}else{try{throw Error()}catch(g){m=g}(z=l())&&typeof z.catch=="function"&&z.catch(function(){})}}catch(g){if(g&&m&&typeof g.stack=="string")return[g.stack,m.stack]}return[null,null]}};u.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var e=Object.getOwnPropertyDescriptor(u.DetermineComponentFrameRoot,"name");e&&e.configurable&&Object.defineProperty(u.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var n=u.DetermineComponentFrameRoot(),f=n[0],i=n[1];if(f&&i){var c=f.split(`
`),v=i.split(`
`);for(e=u=0;u<c.length&&!c[u].includes("DetermineComponentFrameRoot");)u++;for(;e<v.length&&!v[e].includes("DetermineComponentFrameRoot");)e++;if(u===c.length||e===v.length)for(u=c.length-1,e=v.length-1;1<=u&&0<=e&&c[u]!==v[e];)e--;for(;1<=u&&0<=e;u--,e--)if(c[u]!==v[e]){if(u!==1||e!==1)do if(u--,e--,0>e||c[u]!==v[e]){var S=`
`+c[u].replace(" at new "," at ");return l.displayName&&S.includes("<anonymous>")&&(S=S.replace("<anonymous>",l.displayName)),S}while(1<=u&&0<=e);break}}}finally{In=!1,Error.prepareStackTrace=a}return(a=l?l.displayName||l.name:"")?Aa(a):""}function Ko(l,t){switch(l.tag){case 26:case 27:case 5:return Aa(l.type);case 16:return Aa("Lazy");case 13:return l.child!==t&&t!==null?Aa("Suspense Fallback"):Aa("Suspense");case 19:return Aa("SuspenseList");case 0:case 15:return Pn(l.type,!1);case 11:return Pn(l.type.render,!1);case 1:return Pn(l.type,!0);case 31:return Aa("Activity");default:return""}}function xc(l){try{var t="",a=null;do t+=Ko(l,a),a=l,l=l.return;while(l);return t}catch(u){return`
Error generating stack: `+u.message+`
`+u.stack}}var lf=Object.prototype.hasOwnProperty,tf=E.unstable_scheduleCallback,af=E.unstable_cancelCallback,Jo=E.unstable_shouldYield,wo=E.unstable_requestPaint,lt=E.unstable_now,Wo=E.unstable_getCurrentPriorityLevel,Hc=E.unstable_ImmediatePriority,Rc=E.unstable_UserBlockingPriority,_e=E.unstable_NormalPriority,ko=E.unstable_LowPriority,Nc=E.unstable_IdlePriority,$o=E.log,Fo=E.unstable_setDisableYieldValue,Hu=null,tt=null;function It(l){if(typeof $o=="function"&&Fo(l),tt&&typeof tt.setStrictMode=="function")try{tt.setStrictMode(Hu,l)}catch{}}var at=Math.clz32?Math.clz32:ly,Io=Math.log,Po=Math.LN2;function ly(l){return l>>>=0,l===0?32:31-(Io(l)/Po|0)|0}var Oe=256,Me=262144,De=4194304;function _a(l){var t=l&42;if(t!==0)return t;switch(l&-l){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:return l&261888;case 262144:case 524288:case 1048576:case 2097152:return l&3932160;case 4194304:case 8388608:case 16777216:case 33554432:return l&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return l}}function Ue(l,t,a){var u=l.pendingLanes;if(u===0)return 0;var e=0,n=l.suspendedLanes,f=l.pingedLanes;l=l.warmLanes;var i=u&134217727;return i!==0?(u=i&~n,u!==0?e=_a(u):(f&=i,f!==0?e=_a(f):a||(a=i&~l,a!==0&&(e=_a(a))))):(i=u&~n,i!==0?e=_a(i):f!==0?e=_a(f):a||(a=u&~l,a!==0&&(e=_a(a)))),e===0?0:t!==0&&t!==e&&(t&n)===0&&(n=e&-e,a=t&-t,n>=a||n===32&&(a&4194048)!==0)?t:e}function Ru(l,t){return(l.pendingLanes&~(l.suspendedLanes&~l.pingedLanes)&t)===0}function ty(l,t){switch(l){case 1:case 2:case 4:case 8:case 64:return t+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return t+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function Cc(){var l=De;return De<<=1,(De&62914560)===0&&(De=4194304),l}function uf(l){for(var t=[],a=0;31>a;a++)t.push(l);return t}function Nu(l,t){l.pendingLanes|=t,t!==268435456&&(l.suspendedLanes=0,l.pingedLanes=0,l.warmLanes=0)}function ay(l,t,a,u,e,n){var f=l.pendingLanes;l.pendingLanes=a,l.suspendedLanes=0,l.pingedLanes=0,l.warmLanes=0,l.expiredLanes&=a,l.entangledLanes&=a,l.errorRecoveryDisabledLanes&=a,l.shellSuspendCounter=0;var i=l.entanglements,c=l.expirationTimes,v=l.hiddenUpdates;for(a=f&~a;0<a;){var S=31-at(a),z=1<<S;i[S]=0,c[S]=-1;var m=v[S];if(m!==null)for(v[S]=null,S=0;S<m.length;S++){var g=m[S];g!==null&&(g.lane&=-536870913)}a&=~z}u!==0&&Bc(l,u,0),n!==0&&e===0&&l.tag!==0&&(l.suspendedLanes|=n&~(f&~t))}function Bc(l,t,a){l.pendingLanes|=t,l.suspendedLanes&=~t;var u=31-at(t);l.entangledLanes|=t,l.entanglements[u]=l.entanglements[u]|1073741824|a&261930}function jc(l,t){var a=l.entangledLanes|=t;for(l=l.entanglements;a;){var u=31-at(a),e=1<<u;e&t|l[u]&t&&(l[u]|=t),a&=~e}}function qc(l,t){var a=t&-t;return a=(a&42)!==0?1:ef(a),(a&(l.suspendedLanes|t))!==0?0:a}function ef(l){switch(l){case 2:l=1;break;case 8:l=4;break;case 32:l=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:l=128;break;case 268435456:l=134217728;break;default:l=0}return l}function nf(l){return l&=-l,2<l?8<l?(l&134217727)!==0?32:268435456:8:2}function Yc(){var l=A.p;return l!==0?l:(l=window.event,l===void 0?32:Ao(l.type))}function Gc(l,t){var a=A.p;try{return A.p=l,t()}finally{A.p=a}}var Pt=Math.random().toString(36).slice(2),Nl="__reactFiber$"+Pt,Jl="__reactProps$"+Pt,La="__reactContainer$"+Pt,ff="__reactEvents$"+Pt,uy="__reactListeners$"+Pt,ey="__reactHandles$"+Pt,Xc="__reactResources$"+Pt,Cu="__reactMarker$"+Pt;function cf(l){delete l[Nl],delete l[Jl],delete l[ff],delete l[uy],delete l[ey]}function Ka(l){var t=l[Nl];if(t)return t;for(var a=l.parentNode;a;){if(t=a[La]||a[Nl]){if(a=t.alternate,t.child!==null||a!==null&&a.child!==null)for(l=io(l);l!==null;){if(a=l[Nl])return a;l=io(l)}return t}l=a,a=l.parentNode}return null}function Ja(l){if(l=l[Nl]||l[La]){var t=l.tag;if(t===5||t===6||t===13||t===31||t===26||t===27||t===3)return l}return null}function Bu(l){var t=l.tag;if(t===5||t===26||t===27||t===6)return l.stateNode;throw Error(h(33))}function wa(l){var t=l[Xc];return t||(t=l[Xc]={hoistableStyles:new Map,hoistableScripts:new Map}),t}function xl(l){l[Cu]=!0}var Qc=new Set,Zc={};function Oa(l,t){Wa(l,t),Wa(l+"Capture",t)}function Wa(l,t){for(Zc[l]=t,l=0;l<t.length;l++)Qc.add(t[l])}var ny=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),Vc={},Lc={};function fy(l){return lf.call(Lc,l)?!0:lf.call(Vc,l)?!1:ny.test(l)?Lc[l]=!0:(Vc[l]=!0,!1)}function xe(l,t,a){if(fy(t))if(a===null)l.removeAttribute(t);else{switch(typeof a){case"undefined":case"function":case"symbol":l.removeAttribute(t);return;case"boolean":var u=t.toLowerCase().slice(0,5);if(u!=="data-"&&u!=="aria-"){l.removeAttribute(t);return}}l.setAttribute(t,""+a)}}function He(l,t,a){if(a===null)l.removeAttribute(t);else{switch(typeof a){case"undefined":case"function":case"symbol":case"boolean":l.removeAttribute(t);return}l.setAttribute(t,""+a)}}function Ct(l,t,a,u){if(u===null)l.removeAttribute(a);else{switch(typeof u){case"undefined":case"function":case"symbol":case"boolean":l.removeAttribute(a);return}l.setAttributeNS(t,a,""+u)}}function ot(l){switch(typeof l){case"bigint":case"boolean":case"number":case"string":case"undefined":return l;case"object":return l;default:return""}}function Kc(l){var t=l.type;return(l=l.nodeName)&&l.toLowerCase()==="input"&&(t==="checkbox"||t==="radio")}function iy(l,t,a){var u=Object.getOwnPropertyDescriptor(l.constructor.prototype,t);if(!l.hasOwnProperty(t)&&typeof u<"u"&&typeof u.get=="function"&&typeof u.set=="function"){var e=u.get,n=u.set;return Object.defineProperty(l,t,{configurable:!0,get:function(){return e.call(this)},set:function(f){a=""+f,n.call(this,f)}}),Object.defineProperty(l,t,{enumerable:u.enumerable}),{getValue:function(){return a},setValue:function(f){a=""+f},stopTracking:function(){l._valueTracker=null,delete l[t]}}}}function sf(l){if(!l._valueTracker){var t=Kc(l)?"checked":"value";l._valueTracker=iy(l,t,""+l[t])}}function Jc(l){if(!l)return!1;var t=l._valueTracker;if(!t)return!0;var a=t.getValue(),u="";return l&&(u=Kc(l)?l.checked?"true":"false":l.value),l=u,l!==a?(t.setValue(l),!0):!1}function Re(l){if(l=l||(typeof document<"u"?document:void 0),typeof l>"u")return null;try{return l.activeElement||l.body}catch{return l.body}}var cy=/[\n"\\]/g;function yt(l){return l.replace(cy,function(t){return"\\"+t.charCodeAt(0).toString(16)+" "})}function df(l,t,a,u,e,n,f,i){l.name="",f!=null&&typeof f!="function"&&typeof f!="symbol"&&typeof f!="boolean"?l.type=f:l.removeAttribute("type"),t!=null?f==="number"?(t===0&&l.value===""||l.value!=t)&&(l.value=""+ot(t)):l.value!==""+ot(t)&&(l.value=""+ot(t)):f!=="submit"&&f!=="reset"||l.removeAttribute("value"),t!=null?of(l,f,ot(t)):a!=null?of(l,f,ot(a)):u!=null&&l.removeAttribute("value"),e==null&&n!=null&&(l.defaultChecked=!!n),e!=null&&(l.checked=e&&typeof e!="function"&&typeof e!="symbol"),i!=null&&typeof i!="function"&&typeof i!="symbol"&&typeof i!="boolean"?l.name=""+ot(i):l.removeAttribute("name")}function wc(l,t,a,u,e,n,f,i){if(n!=null&&typeof n!="function"&&typeof n!="symbol"&&typeof n!="boolean"&&(l.type=n),t!=null||a!=null){if(!(n!=="submit"&&n!=="reset"||t!=null)){sf(l);return}a=a!=null?""+ot(a):"",t=t!=null?""+ot(t):a,i||t===l.value||(l.value=t),l.defaultValue=t}u=u??e,u=typeof u!="function"&&typeof u!="symbol"&&!!u,l.checked=i?l.checked:!!u,l.defaultChecked=!!u,f!=null&&typeof f!="function"&&typeof f!="symbol"&&typeof f!="boolean"&&(l.name=f),sf(l)}function of(l,t,a){t==="number"&&Re(l.ownerDocument)===l||l.defaultValue===""+a||(l.defaultValue=""+a)}function ka(l,t,a,u){if(l=l.options,t){t={};for(var e=0;e<a.length;e++)t["$"+a[e]]=!0;for(a=0;a<l.length;a++)e=t.hasOwnProperty("$"+l[a].value),l[a].selected!==e&&(l[a].selected=e),e&&u&&(l[a].defaultSelected=!0)}else{for(a=""+ot(a),t=null,e=0;e<l.length;e++){if(l[e].value===a){l[e].selected=!0,u&&(l[e].defaultSelected=!0);return}t!==null||l[e].disabled||(t=l[e])}t!==null&&(t.selected=!0)}}function Wc(l,t,a){if(t!=null&&(t=""+ot(t),t!==l.value&&(l.value=t),a==null)){l.defaultValue!==t&&(l.defaultValue=t);return}l.defaultValue=a!=null?""+ot(a):""}function kc(l,t,a,u){if(t==null){if(u!=null){if(a!=null)throw Error(h(92));if(pt(u)){if(1<u.length)throw Error(h(93));u=u[0]}a=u}a==null&&(a=""),t=a}a=ot(t),l.defaultValue=a,u=l.textContent,u===a&&u!==""&&u!==null&&(l.value=u),sf(l)}function $a(l,t){if(t){var a=l.firstChild;if(a&&a===l.lastChild&&a.nodeType===3){a.nodeValue=t;return}}l.textContent=t}var sy=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function $c(l,t,a){var u=t.indexOf("--")===0;a==null||typeof a=="boolean"||a===""?u?l.setProperty(t,""):t==="float"?l.cssFloat="":l[t]="":u?l.setProperty(t,a):typeof a!="number"||a===0||sy.has(t)?t==="float"?l.cssFloat=a:l[t]=(""+a).trim():l[t]=a+"px"}function Fc(l,t,a){if(t!=null&&typeof t!="object")throw Error(h(62));if(l=l.style,a!=null){for(var u in a)!a.hasOwnProperty(u)||t!=null&&t.hasOwnProperty(u)||(u.indexOf("--")===0?l.setProperty(u,""):u==="float"?l.cssFloat="":l[u]="");for(var e in t)u=t[e],t.hasOwnProperty(e)&&a[e]!==u&&$c(l,e,u)}else for(var n in t)t.hasOwnProperty(n)&&$c(l,n,t[n])}function yf(l){if(l.indexOf("-")===-1)return!1;switch(l){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var dy=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),oy=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function Ne(l){return oy.test(""+l)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":l}function Bt(){}var vf=null;function mf(l){return l=l.target||l.srcElement||window,l.correspondingUseElement&&(l=l.correspondingUseElement),l.nodeType===3?l.parentNode:l}var Fa=null,Ia=null;function Ic(l){var t=Ja(l);if(t&&(l=t.stateNode)){var a=l[Jl]||null;l:switch(l=t.stateNode,t.type){case"input":if(df(l,a.value,a.defaultValue,a.defaultValue,a.checked,a.defaultChecked,a.type,a.name),t=a.name,a.type==="radio"&&t!=null){for(a=l;a.parentNode;)a=a.parentNode;for(a=a.querySelectorAll('input[name="'+yt(""+t)+'"][type="radio"]'),t=0;t<a.length;t++){var u=a[t];if(u!==l&&u.form===l.form){var e=u[Jl]||null;if(!e)throw Error(h(90));df(u,e.value,e.defaultValue,e.defaultValue,e.checked,e.defaultChecked,e.type,e.name)}}for(t=0;t<a.length;t++)u=a[t],u.form===l.form&&Jc(u)}break l;case"textarea":Wc(l,a.value,a.defaultValue);break l;case"select":t=a.value,t!=null&&ka(l,!!a.multiple,t,!1)}}}var hf=!1;function Pc(l,t,a){if(hf)return l(t,a);hf=!0;try{var u=l(t);return u}finally{if(hf=!1,(Fa!==null||Ia!==null)&&(pn(),Fa&&(t=Fa,l=Ia,Ia=Fa=null,Ic(t),l)))for(t=0;t<l.length;t++)Ic(l[t])}}function ju(l,t){var a=l.stateNode;if(a===null)return null;var u=a[Jl]||null;if(u===null)return null;a=u[t];l:switch(t){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(u=!u.disabled)||(l=l.type,u=!(l==="button"||l==="input"||l==="select"||l==="textarea")),l=!u;break l;default:l=!1}if(l)return null;if(a&&typeof a!="function")throw Error(h(231,t,typeof a));return a}var jt=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),gf=!1;if(jt)try{var qu={};Object.defineProperty(qu,"passive",{get:function(){gf=!0}}),window.addEventListener("test",qu,qu),window.removeEventListener("test",qu,qu)}catch{gf=!1}var la=null,Sf=null,Ce=null;function ls(){if(Ce)return Ce;var l,t=Sf,a=t.length,u,e="value"in la?la.value:la.textContent,n=e.length;for(l=0;l<a&&t[l]===e[l];l++);var f=a-l;for(u=1;u<=f&&t[a-u]===e[n-u];u++);return Ce=e.slice(l,1<u?1-u:void 0)}function Be(l){var t=l.keyCode;return"charCode"in l?(l=l.charCode,l===0&&t===13&&(l=13)):l=t,l===10&&(l=13),32<=l||l===13?l:0}function je(){return!0}function ts(){return!1}function wl(l){function t(a,u,e,n,f){this._reactName=a,this._targetInst=e,this.type=u,this.nativeEvent=n,this.target=f,this.currentTarget=null;for(var i in l)l.hasOwnProperty(i)&&(a=l[i],this[i]=a?a(n):n[i]);return this.isDefaultPrevented=(n.defaultPrevented!=null?n.defaultPrevented:n.returnValue===!1)?je:ts,this.isPropagationStopped=ts,this}return R(t.prototype,{preventDefault:function(){this.defaultPrevented=!0;var a=this.nativeEvent;a&&(a.preventDefault?a.preventDefault():typeof a.returnValue!="unknown"&&(a.returnValue=!1),this.isDefaultPrevented=je)},stopPropagation:function(){var a=this.nativeEvent;a&&(a.stopPropagation?a.stopPropagation():typeof a.cancelBubble!="unknown"&&(a.cancelBubble=!0),this.isPropagationStopped=je)},persist:function(){},isPersistent:je}),t}var Ma={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(l){return l.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},qe=wl(Ma),Yu=R({},Ma,{view:0,detail:0}),yy=wl(Yu),rf,bf,Gu,Ye=R({},Yu,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:pf,button:0,buttons:0,relatedTarget:function(l){return l.relatedTarget===void 0?l.fromElement===l.srcElement?l.toElement:l.fromElement:l.relatedTarget},movementX:function(l){return"movementX"in l?l.movementX:(l!==Gu&&(Gu&&l.type==="mousemove"?(rf=l.screenX-Gu.screenX,bf=l.screenY-Gu.screenY):bf=rf=0,Gu=l),rf)},movementY:function(l){return"movementY"in l?l.movementY:bf}}),as=wl(Ye),vy=R({},Ye,{dataTransfer:0}),my=wl(vy),hy=R({},Yu,{relatedTarget:0}),zf=wl(hy),gy=R({},Ma,{animationName:0,elapsedTime:0,pseudoElement:0}),Sy=wl(gy),ry=R({},Ma,{clipboardData:function(l){return"clipboardData"in l?l.clipboardData:window.clipboardData}}),by=wl(ry),zy=R({},Ma,{data:0}),us=wl(zy),py={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},Ty={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},Ey={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function Ay(l){var t=this.nativeEvent;return t.getModifierState?t.getModifierState(l):(l=Ey[l])?!!t[l]:!1}function pf(){return Ay}var _y=R({},Yu,{key:function(l){if(l.key){var t=py[l.key]||l.key;if(t!=="Unidentified")return t}return l.type==="keypress"?(l=Be(l),l===13?"Enter":String.fromCharCode(l)):l.type==="keydown"||l.type==="keyup"?Ty[l.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:pf,charCode:function(l){return l.type==="keypress"?Be(l):0},keyCode:function(l){return l.type==="keydown"||l.type==="keyup"?l.keyCode:0},which:function(l){return l.type==="keypress"?Be(l):l.type==="keydown"||l.type==="keyup"?l.keyCode:0}}),Oy=wl(_y),My=R({},Ye,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),es=wl(My),Dy=R({},Yu,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:pf}),Uy=wl(Dy),xy=R({},Ma,{propertyName:0,elapsedTime:0,pseudoElement:0}),Hy=wl(xy),Ry=R({},Ye,{deltaX:function(l){return"deltaX"in l?l.deltaX:"wheelDeltaX"in l?-l.wheelDeltaX:0},deltaY:function(l){return"deltaY"in l?l.deltaY:"wheelDeltaY"in l?-l.wheelDeltaY:"wheelDelta"in l?-l.wheelDelta:0},deltaZ:0,deltaMode:0}),Ny=wl(Ry),Cy=R({},Ma,{newState:0,oldState:0}),By=wl(Cy),jy=[9,13,27,32],Tf=jt&&"CompositionEvent"in window,Xu=null;jt&&"documentMode"in document&&(Xu=document.documentMode);var qy=jt&&"TextEvent"in window&&!Xu,ns=jt&&(!Tf||Xu&&8<Xu&&11>=Xu),fs=" ",is=!1;function cs(l,t){switch(l){case"keyup":return jy.indexOf(t.keyCode)!==-1;case"keydown":return t.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function ss(l){return l=l.detail,typeof l=="object"&&"data"in l?l.data:null}var Pa=!1;function Yy(l,t){switch(l){case"compositionend":return ss(t);case"keypress":return t.which!==32?null:(is=!0,fs);case"textInput":return l=t.data,l===fs&&is?null:l;default:return null}}function Gy(l,t){if(Pa)return l==="compositionend"||!Tf&&cs(l,t)?(l=ls(),Ce=Sf=la=null,Pa=!1,l):null;switch(l){case"paste":return null;case"keypress":if(!(t.ctrlKey||t.altKey||t.metaKey)||t.ctrlKey&&t.altKey){if(t.char&&1<t.char.length)return t.char;if(t.which)return String.fromCharCode(t.which)}return null;case"compositionend":return ns&&t.locale!=="ko"?null:t.data;default:return null}}var Xy={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function ds(l){var t=l&&l.nodeName&&l.nodeName.toLowerCase();return t==="input"?!!Xy[l.type]:t==="textarea"}function os(l,t,a,u){Fa?Ia?Ia.push(u):Ia=[u]:Fa=u,t=Dn(t,"onChange"),0<t.length&&(a=new qe("onChange","change",null,a,u),l.push({event:a,listeners:t}))}var Qu=null,Zu=null;function Qy(l){w0(l,0)}function Ge(l){var t=Bu(l);if(Jc(t))return l}function ys(l,t){if(l==="change")return t}var vs=!1;if(jt){var Ef;if(jt){var Af="oninput"in document;if(!Af){var ms=document.createElement("div");ms.setAttribute("oninput","return;"),Af=typeof ms.oninput=="function"}Ef=Af}else Ef=!1;vs=Ef&&(!document.documentMode||9<document.documentMode)}function hs(){Qu&&(Qu.detachEvent("onpropertychange",gs),Zu=Qu=null)}function gs(l){if(l.propertyName==="value"&&Ge(Zu)){var t=[];os(t,Zu,l,mf(l)),Pc(Qy,t)}}function Zy(l,t,a){l==="focusin"?(hs(),Qu=t,Zu=a,Qu.attachEvent("onpropertychange",gs)):l==="focusout"&&hs()}function Vy(l){if(l==="selectionchange"||l==="keyup"||l==="keydown")return Ge(Zu)}function Ly(l,t){if(l==="click")return Ge(t)}function Ky(l,t){if(l==="input"||l==="change")return Ge(t)}function Jy(l,t){return l===t&&(l!==0||1/l===1/t)||l!==l&&t!==t}var ut=typeof Object.is=="function"?Object.is:Jy;function Vu(l,t){if(ut(l,t))return!0;if(typeof l!="object"||l===null||typeof t!="object"||t===null)return!1;var a=Object.keys(l),u=Object.keys(t);if(a.length!==u.length)return!1;for(u=0;u<a.length;u++){var e=a[u];if(!lf.call(t,e)||!ut(l[e],t[e]))return!1}return!0}function Ss(l){for(;l&&l.firstChild;)l=l.firstChild;return l}function rs(l,t){var a=Ss(l);l=0;for(var u;a;){if(a.nodeType===3){if(u=l+a.textContent.length,l<=t&&u>=t)return{node:a,offset:t-l};l=u}l:{for(;a;){if(a.nextSibling){a=a.nextSibling;break l}a=a.parentNode}a=void 0}a=Ss(a)}}function bs(l,t){return l&&t?l===t?!0:l&&l.nodeType===3?!1:t&&t.nodeType===3?bs(l,t.parentNode):"contains"in l?l.contains(t):l.compareDocumentPosition?!!(l.compareDocumentPosition(t)&16):!1:!1}function zs(l){l=l!=null&&l.ownerDocument!=null&&l.ownerDocument.defaultView!=null?l.ownerDocument.defaultView:window;for(var t=Re(l.document);t instanceof l.HTMLIFrameElement;){try{var a=typeof t.contentWindow.location.href=="string"}catch{a=!1}if(a)l=t.contentWindow;else break;t=Re(l.document)}return t}function _f(l){var t=l&&l.nodeName&&l.nodeName.toLowerCase();return t&&(t==="input"&&(l.type==="text"||l.type==="search"||l.type==="tel"||l.type==="url"||l.type==="password")||t==="textarea"||l.contentEditable==="true")}var wy=jt&&"documentMode"in document&&11>=document.documentMode,lu=null,Of=null,Lu=null,Mf=!1;function ps(l,t,a){var u=a.window===a?a.document:a.nodeType===9?a:a.ownerDocument;Mf||lu==null||lu!==Re(u)||(u=lu,"selectionStart"in u&&_f(u)?u={start:u.selectionStart,end:u.selectionEnd}:(u=(u.ownerDocument&&u.ownerDocument.defaultView||window).getSelection(),u={anchorNode:u.anchorNode,anchorOffset:u.anchorOffset,focusNode:u.focusNode,focusOffset:u.focusOffset}),Lu&&Vu(Lu,u)||(Lu=u,u=Dn(Of,"onSelect"),0<u.length&&(t=new qe("onSelect","select",null,t,a),l.push({event:t,listeners:u}),t.target=lu)))}function Da(l,t){var a={};return a[l.toLowerCase()]=t.toLowerCase(),a["Webkit"+l]="webkit"+t,a["Moz"+l]="moz"+t,a}var tu={animationend:Da("Animation","AnimationEnd"),animationiteration:Da("Animation","AnimationIteration"),animationstart:Da("Animation","AnimationStart"),transitionrun:Da("Transition","TransitionRun"),transitionstart:Da("Transition","TransitionStart"),transitioncancel:Da("Transition","TransitionCancel"),transitionend:Da("Transition","TransitionEnd")},Df={},Ts={};jt&&(Ts=document.createElement("div").style,"AnimationEvent"in window||(delete tu.animationend.animation,delete tu.animationiteration.animation,delete tu.animationstart.animation),"TransitionEvent"in window||delete tu.transitionend.transition);function Ua(l){if(Df[l])return Df[l];if(!tu[l])return l;var t=tu[l],a;for(a in t)if(t.hasOwnProperty(a)&&a in Ts)return Df[l]=t[a];return l}var Es=Ua("animationend"),As=Ua("animationiteration"),_s=Ua("animationstart"),Wy=Ua("transitionrun"),ky=Ua("transitionstart"),$y=Ua("transitioncancel"),Os=Ua("transitionend"),Ms=new Map,Uf="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");Uf.push("scrollEnd");function Tt(l,t){Ms.set(l,t),Oa(t,[l])}var Xe=typeof reportError=="function"?reportError:function(l){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var t=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof l=="object"&&l!==null&&typeof l.message=="string"?String(l.message):String(l),error:l});if(!window.dispatchEvent(t))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",l);return}console.error(l)},vt=[],au=0,xf=0;function Qe(){for(var l=au,t=xf=au=0;t<l;){var a=vt[t];vt[t++]=null;var u=vt[t];vt[t++]=null;var e=vt[t];vt[t++]=null;var n=vt[t];if(vt[t++]=null,u!==null&&e!==null){var f=u.pending;f===null?e.next=e:(e.next=f.next,f.next=e),u.pending=e}n!==0&&Ds(a,e,n)}}function Ze(l,t,a,u){vt[au++]=l,vt[au++]=t,vt[au++]=a,vt[au++]=u,xf|=u,l.lanes|=u,l=l.alternate,l!==null&&(l.lanes|=u)}function Hf(l,t,a,u){return Ze(l,t,a,u),Ve(l)}function xa(l,t){return Ze(l,null,null,t),Ve(l)}function Ds(l,t,a){l.lanes|=a;var u=l.alternate;u!==null&&(u.lanes|=a);for(var e=!1,n=l.return;n!==null;)n.childLanes|=a,u=n.alternate,u!==null&&(u.childLanes|=a),n.tag===22&&(l=n.stateNode,l===null||l._visibility&1||(e=!0)),l=n,n=n.return;return l.tag===3?(n=l.stateNode,e&&t!==null&&(e=31-at(a),l=n.hiddenUpdates,u=l[e],u===null?l[e]=[t]:u.push(t),t.lane=a|536870912),n):null}function Ve(l){if(50<ye)throw ye=0,Xi=null,Error(h(185));for(var t=l.return;t!==null;)l=t,t=l.return;return l.tag===3?l.stateNode:null}var uu={};function Fy(l,t,a,u){this.tag=l,this.key=a,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=t,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=u,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function et(l,t,a,u){return new Fy(l,t,a,u)}function Rf(l){return l=l.prototype,!(!l||!l.isReactComponent)}function qt(l,t){var a=l.alternate;return a===null?(a=et(l.tag,t,l.key,l.mode),a.elementType=l.elementType,a.type=l.type,a.stateNode=l.stateNode,a.alternate=l,l.alternate=a):(a.pendingProps=t,a.type=l.type,a.flags=0,a.subtreeFlags=0,a.deletions=null),a.flags=l.flags&65011712,a.childLanes=l.childLanes,a.lanes=l.lanes,a.child=l.child,a.memoizedProps=l.memoizedProps,a.memoizedState=l.memoizedState,a.updateQueue=l.updateQueue,t=l.dependencies,a.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext},a.sibling=l.sibling,a.index=l.index,a.ref=l.ref,a.refCleanup=l.refCleanup,a}function Us(l,t){l.flags&=65011714;var a=l.alternate;return a===null?(l.childLanes=0,l.lanes=t,l.child=null,l.subtreeFlags=0,l.memoizedProps=null,l.memoizedState=null,l.updateQueue=null,l.dependencies=null,l.stateNode=null):(l.childLanes=a.childLanes,l.lanes=a.lanes,l.child=a.child,l.subtreeFlags=0,l.deletions=null,l.memoizedProps=a.memoizedProps,l.memoizedState=a.memoizedState,l.updateQueue=a.updateQueue,l.type=a.type,t=a.dependencies,l.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext}),l}function Le(l,t,a,u,e,n){var f=0;if(u=l,typeof l=="function")Rf(l)&&(f=1);else if(typeof l=="string")f=am(l,a,M.current)?26:l==="html"||l==="head"||l==="body"?27:5;else l:switch(l){case Ot:return l=et(31,a,t,e),l.elementType=Ot,l.lanes=n,l;case Rl:return Ha(a.children,e,n,t);case Pl:f=8,e|=24;break;case Ul:return l=et(12,a,t,e|2),l.elementType=Ul,l.lanes=n,l;case _t:return l=et(13,a,t,e),l.elementType=_t,l.lanes=n,l;case Vl:return l=et(19,a,t,e),l.elementType=Vl,l.lanes=n,l;default:if(typeof l=="object"&&l!==null)switch(l.$$typeof){case bl:f=10;break l;case C:f=9;break l;case dt:f=11;break l;case w:f=14;break l;case Ll:f=16,u=null;break l}f=29,a=Error(h(130,l===null?"null":typeof l,"")),u=null}return t=et(f,a,t,e),t.elementType=l,t.type=u,t.lanes=n,t}function Ha(l,t,a,u){return l=et(7,l,u,t),l.lanes=a,l}function Nf(l,t,a){return l=et(6,l,null,t),l.lanes=a,l}function xs(l){var t=et(18,null,null,0);return t.stateNode=l,t}function Cf(l,t,a){return t=et(4,l.children!==null?l.children:[],l.key,t),t.lanes=a,t.stateNode={containerInfo:l.containerInfo,pendingChildren:null,implementation:l.implementation},t}var Hs=new WeakMap;function mt(l,t){if(typeof l=="object"&&l!==null){var a=Hs.get(l);return a!==void 0?a:(t={value:l,source:t,stack:xc(t)},Hs.set(l,t),t)}return{value:l,source:t,stack:xc(t)}}var eu=[],nu=0,Ke=null,Ku=0,ht=[],gt=0,ta=null,Dt=1,Ut="";function Yt(l,t){eu[nu++]=Ku,eu[nu++]=Ke,Ke=l,Ku=t}function Rs(l,t,a){ht[gt++]=Dt,ht[gt++]=Ut,ht[gt++]=ta,ta=l;var u=Dt;l=Ut;var e=32-at(u)-1;u&=~(1<<e),a+=1;var n=32-at(t)+e;if(30<n){var f=e-e%5;n=(u&(1<<f)-1).toString(32),u>>=f,e-=f,Dt=1<<32-at(t)+e|a<<e|u,Ut=n+l}else Dt=1<<n|a<<e|u,Ut=l}function Bf(l){l.return!==null&&(Yt(l,1),Rs(l,1,0))}function jf(l){for(;l===Ke;)Ke=eu[--nu],eu[nu]=null,Ku=eu[--nu],eu[nu]=null;for(;l===ta;)ta=ht[--gt],ht[gt]=null,Ut=ht[--gt],ht[gt]=null,Dt=ht[--gt],ht[gt]=null}function Ns(l,t){ht[gt++]=Dt,ht[gt++]=Ut,ht[gt++]=ta,Dt=t.id,Ut=t.overflow,ta=l}var Cl=null,ol=null,W=!1,aa=null,St=!1,qf=Error(h(519));function ua(l){var t=Error(h(418,1<arguments.length&&arguments[1]!==void 0&&arguments[1]?"text":"HTML",""));throw Ju(mt(t,l)),qf}function Cs(l){var t=l.stateNode,a=l.type,u=l.memoizedProps;switch(t[Nl]=l,t[Jl]=u,a){case"dialog":V("cancel",t),V("close",t);break;case"iframe":case"object":case"embed":V("load",t);break;case"video":case"audio":for(a=0;a<me.length;a++)V(me[a],t);break;case"source":V("error",t);break;case"img":case"image":case"link":V("error",t),V("load",t);break;case"details":V("toggle",t);break;case"input":V("invalid",t),wc(t,u.value,u.defaultValue,u.checked,u.defaultChecked,u.type,u.name,!0);break;case"select":V("invalid",t);break;case"textarea":V("invalid",t),kc(t,u.value,u.defaultValue,u.children)}a=u.children,typeof a!="string"&&typeof a!="number"&&typeof a!="bigint"||t.textContent===""+a||u.suppressHydrationWarning===!0||F0(t.textContent,a)?(u.popover!=null&&(V("beforetoggle",t),V("toggle",t)),u.onScroll!=null&&V("scroll",t),u.onScrollEnd!=null&&V("scrollend",t),u.onClick!=null&&(t.onclick=Bt),t=!0):t=!1,t||ua(l,!0)}function Bs(l){for(Cl=l.return;Cl;)switch(Cl.tag){case 5:case 31:case 13:St=!1;return;case 27:case 3:St=!0;return;default:Cl=Cl.return}}function fu(l){if(l!==Cl)return!1;if(!W)return Bs(l),W=!0,!1;var t=l.tag,a;if((a=t!==3&&t!==27)&&((a=t===5)&&(a=l.type,a=!(a!=="form"&&a!=="button")||tc(l.type,l.memoizedProps)),a=!a),a&&ol&&ua(l),Bs(l),t===13){if(l=l.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(h(317));ol=fo(l)}else if(t===31){if(l=l.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(h(317));ol=fo(l)}else t===27?(t=ol,Sa(l.type)?(l=fc,fc=null,ol=l):ol=t):ol=Cl?bt(l.stateNode.nextSibling):null;return!0}function Ra(){ol=Cl=null,W=!1}function Yf(){var l=aa;return l!==null&&(Fl===null?Fl=l:Fl.push.apply(Fl,l),aa=null),l}function Ju(l){aa===null?aa=[l]:aa.push(l)}var Gf=d(null),Na=null,Gt=null;function ea(l,t,a){_(Gf,t._currentValue),t._currentValue=a}function Xt(l){l._currentValue=Gf.current,p(Gf)}function Xf(l,t,a){for(;l!==null;){var u=l.alternate;if((l.childLanes&t)!==t?(l.childLanes|=t,u!==null&&(u.childLanes|=t)):u!==null&&(u.childLanes&t)!==t&&(u.childLanes|=t),l===a)break;l=l.return}}function Qf(l,t,a,u){var e=l.child;for(e!==null&&(e.return=l);e!==null;){var n=e.dependencies;if(n!==null){var f=e.child;n=n.firstContext;l:for(;n!==null;){var i=n;n=e;for(var c=0;c<t.length;c++)if(i.context===t[c]){n.lanes|=a,i=n.alternate,i!==null&&(i.lanes|=a),Xf(n.return,a,l),u||(f=null);break l}n=i.next}}else if(e.tag===18){if(f=e.return,f===null)throw Error(h(341));f.lanes|=a,n=f.alternate,n!==null&&(n.lanes|=a),Xf(f,a,l),f=null}else f=e.child;if(f!==null)f.return=e;else for(f=e;f!==null;){if(f===l){f=null;break}if(e=f.sibling,e!==null){e.return=f.return,f=e;break}f=f.return}e=f}}function iu(l,t,a,u){l=null;for(var e=t,n=!1;e!==null;){if(!n){if((e.flags&524288)!==0)n=!0;else if((e.flags&262144)!==0)break}if(e.tag===10){var f=e.alternate;if(f===null)throw Error(h(387));if(f=f.memoizedProps,f!==null){var i=e.type;ut(e.pendingProps.value,f.value)||(l!==null?l.push(i):l=[i])}}else if(e===tl.current){if(f=e.alternate,f===null)throw Error(h(387));f.memoizedState.memoizedState!==e.memoizedState.memoizedState&&(l!==null?l.push(be):l=[be])}e=e.return}l!==null&&Qf(t,l,a,u),t.flags|=262144}function Je(l){for(l=l.firstContext;l!==null;){if(!ut(l.context._currentValue,l.memoizedValue))return!0;l=l.next}return!1}function Ca(l){Na=l,Gt=null,l=l.dependencies,l!==null&&(l.firstContext=null)}function Bl(l){return js(Na,l)}function we(l,t){return Na===null&&Ca(l),js(l,t)}function js(l,t){var a=t._currentValue;if(t={context:t,memoizedValue:a,next:null},Gt===null){if(l===null)throw Error(h(308));Gt=t,l.dependencies={lanes:0,firstContext:t},l.flags|=524288}else Gt=Gt.next=t;return a}var Iy=typeof AbortController<"u"?AbortController:function(){var l=[],t=this.signal={aborted:!1,addEventListener:function(a,u){l.push(u)}};this.abort=function(){t.aborted=!0,l.forEach(function(a){return a()})}},Py=E.unstable_scheduleCallback,lv=E.unstable_NormalPriority,El={$$typeof:bl,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function Zf(){return{controller:new Iy,data:new Map,refCount:0}}function wu(l){l.refCount--,l.refCount===0&&Py(lv,function(){l.controller.abort()})}var Wu=null,Vf=0,cu=0,su=null;function tv(l,t){if(Wu===null){var a=Wu=[];Vf=0,cu=Ji(),su={status:"pending",value:void 0,then:function(u){a.push(u)}}}return Vf++,t.then(qs,qs),t}function qs(){if(--Vf===0&&Wu!==null){su!==null&&(su.status="fulfilled");var l=Wu;Wu=null,cu=0,su=null;for(var t=0;t<l.length;t++)(0,l[t])()}}function av(l,t){var a=[],u={status:"pending",value:null,reason:null,then:function(e){a.push(e)}};return l.then(function(){u.status="fulfilled",u.value=t;for(var e=0;e<a.length;e++)(0,a[e])(t)},function(e){for(u.status="rejected",u.reason=e,e=0;e<a.length;e++)(0,a[e])(void 0)}),u}var Ys=r.S;r.S=function(l,t){p0=lt(),typeof t=="object"&&t!==null&&typeof t.then=="function"&&tv(l,t),Ys!==null&&Ys(l,t)};var Ba=d(null);function Lf(){var l=Ba.current;return l!==null?l:dl.pooledCache}function We(l,t){t===null?_(Ba,Ba.current):_(Ba,t.pool)}function Gs(){var l=Lf();return l===null?null:{parent:El._currentValue,pool:l}}var du=Error(h(460)),Kf=Error(h(474)),ke=Error(h(542)),$e={then:function(){}};function Xs(l){return l=l.status,l==="fulfilled"||l==="rejected"}function Qs(l,t,a){switch(a=l[a],a===void 0?l.push(t):a!==t&&(t.then(Bt,Bt),t=a),t.status){case"fulfilled":return t.value;case"rejected":throw l=t.reason,Vs(l),l;default:if(typeof t.status=="string")t.then(Bt,Bt);else{if(l=dl,l!==null&&100<l.shellSuspendCounter)throw Error(h(482));l=t,l.status="pending",l.then(function(u){if(t.status==="pending"){var e=t;e.status="fulfilled",e.value=u}},function(u){if(t.status==="pending"){var e=t;e.status="rejected",e.reason=u}})}switch(t.status){case"fulfilled":return t.value;case"rejected":throw l=t.reason,Vs(l),l}throw qa=t,du}}function ja(l){try{var t=l._init;return t(l._payload)}catch(a){throw a!==null&&typeof a=="object"&&typeof a.then=="function"?(qa=a,du):a}}var qa=null;function Zs(){if(qa===null)throw Error(h(459));var l=qa;return qa=null,l}function Vs(l){if(l===du||l===ke)throw Error(h(483))}var ou=null,ku=0;function Fe(l){var t=ku;return ku+=1,ou===null&&(ou=[]),Qs(ou,l,t)}function $u(l,t){t=t.props.ref,l.ref=t!==void 0?t:null}function Ie(l,t){throw t.$$typeof===F?Error(h(525)):(l=Object.prototype.toString.call(t),Error(h(31,l==="[object Object]"?"object with keys {"+Object.keys(t).join(", ")+"}":l)))}function Ls(l){function t(o,s){if(l){var y=o.deletions;y===null?(o.deletions=[s],o.flags|=16):y.push(s)}}function a(o,s){if(!l)return null;for(;s!==null;)t(o,s),s=s.sibling;return null}function u(o){for(var s=new Map;o!==null;)o.key!==null?s.set(o.key,o):s.set(o.index,o),o=o.sibling;return s}function e(o,s){return o=qt(o,s),o.index=0,o.sibling=null,o}function n(o,s,y){return o.index=y,l?(y=o.alternate,y!==null?(y=y.index,y<s?(o.flags|=67108866,s):y):(o.flags|=67108866,s)):(o.flags|=1048576,s)}function f(o){return l&&o.alternate===null&&(o.flags|=67108866),o}function i(o,s,y,b){return s===null||s.tag!==6?(s=Nf(y,o.mode,b),s.return=o,s):(s=e(s,y),s.return=o,s)}function c(o,s,y,b){var H=y.type;return H===Rl?S(o,s,y.props.children,b,y.key):s!==null&&(s.elementType===H||typeof H=="object"&&H!==null&&H.$$typeof===Ll&&ja(H)===s.type)?(s=e(s,y.props),$u(s,y),s.return=o,s):(s=Le(y.type,y.key,y.props,null,o.mode,b),$u(s,y),s.return=o,s)}function v(o,s,y,b){return s===null||s.tag!==4||s.stateNode.containerInfo!==y.containerInfo||s.stateNode.implementation!==y.implementation?(s=Cf(y,o.mode,b),s.return=o,s):(s=e(s,y.children||[]),s.return=o,s)}function S(o,s,y,b,H){return s===null||s.tag!==7?(s=Ha(y,o.mode,b,H),s.return=o,s):(s=e(s,y),s.return=o,s)}function z(o,s,y){if(typeof s=="string"&&s!==""||typeof s=="number"||typeof s=="bigint")return s=Nf(""+s,o.mode,y),s.return=o,s;if(typeof s=="object"&&s!==null){switch(s.$$typeof){case Gl:return y=Le(s.type,s.key,s.props,null,o.mode,y),$u(y,s),y.return=o,y;case Xl:return s=Cf(s,o.mode,y),s.return=o,s;case Ll:return s=ja(s),z(o,s,y)}if(pt(s)||Kl(s))return s=Ha(s,o.mode,y,null),s.return=o,s;if(typeof s.then=="function")return z(o,Fe(s),y);if(s.$$typeof===bl)return z(o,we(o,s),y);Ie(o,s)}return null}function m(o,s,y,b){var H=s!==null?s.key:null;if(typeof y=="string"&&y!==""||typeof y=="number"||typeof y=="bigint")return H!==null?null:i(o,s,""+y,b);if(typeof y=="object"&&y!==null){switch(y.$$typeof){case Gl:return y.key===H?c(o,s,y,b):null;case Xl:return y.key===H?v(o,s,y,b):null;case Ll:return y=ja(y),m(o,s,y,b)}if(pt(y)||Kl(y))return H!==null?null:S(o,s,y,b,null);if(typeof y.then=="function")return m(o,s,Fe(y),b);if(y.$$typeof===bl)return m(o,s,we(o,y),b);Ie(o,y)}return null}function g(o,s,y,b,H){if(typeof b=="string"&&b!==""||typeof b=="number"||typeof b=="bigint")return o=o.get(y)||null,i(s,o,""+b,H);if(typeof b=="object"&&b!==null){switch(b.$$typeof){case Gl:return o=o.get(b.key===null?y:b.key)||null,c(s,o,b,H);case Xl:return o=o.get(b.key===null?y:b.key)||null,v(s,o,b,H);case Ll:return b=ja(b),g(o,s,y,b,H)}if(pt(b)||Kl(b))return o=o.get(y)||null,S(s,o,b,H,null);if(typeof b.then=="function")return g(o,s,y,Fe(b),H);if(b.$$typeof===bl)return g(o,s,y,we(s,b),H);Ie(s,b)}return null}function O(o,s,y,b){for(var H=null,I=null,D=s,G=s=0,J=null;D!==null&&G<y.length;G++){D.index>G?(J=D,D=null):J=D.sibling;var P=m(o,D,y[G],b);if(P===null){D===null&&(D=J);break}l&&D&&P.alternate===null&&t(o,D),s=n(P,s,G),I===null?H=P:I.sibling=P,I=P,D=J}if(G===y.length)return a(o,D),W&&Yt(o,G),H;if(D===null){for(;G<y.length;G++)D=z(o,y[G],b),D!==null&&(s=n(D,s,G),I===null?H=D:I.sibling=D,I=D);return W&&Yt(o,G),H}for(D=u(D);G<y.length;G++)J=g(D,o,G,y[G],b),J!==null&&(l&&J.alternate!==null&&D.delete(J.key===null?G:J.key),s=n(J,s,G),I===null?H=J:I.sibling=J,I=J);return l&&D.forEach(function(Ta){return t(o,Ta)}),W&&Yt(o,G),H}function N(o,s,y,b){if(y==null)throw Error(h(151));for(var H=null,I=null,D=s,G=s=0,J=null,P=y.next();D!==null&&!P.done;G++,P=y.next()){D.index>G?(J=D,D=null):J=D.sibling;var Ta=m(o,D,P.value,b);if(Ta===null){D===null&&(D=J);break}l&&D&&Ta.alternate===null&&t(o,D),s=n(Ta,s,G),I===null?H=Ta:I.sibling=Ta,I=Ta,D=J}if(P.done)return a(o,D),W&&Yt(o,G),H;if(D===null){for(;!P.done;G++,P=y.next())P=z(o,P.value,b),P!==null&&(s=n(P,s,G),I===null?H=P:I.sibling=P,I=P);return W&&Yt(o,G),H}for(D=u(D);!P.done;G++,P=y.next())P=g(D,o,G,P.value,b),P!==null&&(l&&P.alternate!==null&&D.delete(P.key===null?G:P.key),s=n(P,s,G),I===null?H=P:I.sibling=P,I=P);return l&&D.forEach(function(vm){return t(o,vm)}),W&&Yt(o,G),H}function il(o,s,y,b){if(typeof y=="object"&&y!==null&&y.type===Rl&&y.key===null&&(y=y.props.children),typeof y=="object"&&y!==null){switch(y.$$typeof){case Gl:l:{for(var H=y.key;s!==null;){if(s.key===H){if(H=y.type,H===Rl){if(s.tag===7){a(o,s.sibling),b=e(s,y.props.children),b.return=o,o=b;break l}}else if(s.elementType===H||typeof H=="object"&&H!==null&&H.$$typeof===Ll&&ja(H)===s.type){a(o,s.sibling),b=e(s,y.props),$u(b,y),b.return=o,o=b;break l}a(o,s);break}else t(o,s);s=s.sibling}y.type===Rl?(b=Ha(y.props.children,o.mode,b,y.key),b.return=o,o=b):(b=Le(y.type,y.key,y.props,null,o.mode,b),$u(b,y),b.return=o,o=b)}return f(o);case Xl:l:{for(H=y.key;s!==null;){if(s.key===H)if(s.tag===4&&s.stateNode.containerInfo===y.containerInfo&&s.stateNode.implementation===y.implementation){a(o,s.sibling),b=e(s,y.children||[]),b.return=o,o=b;break l}else{a(o,s);break}else t(o,s);s=s.sibling}b=Cf(y,o.mode,b),b.return=o,o=b}return f(o);case Ll:return y=ja(y),il(o,s,y,b)}if(pt(y))return O(o,s,y,b);if(Kl(y)){if(H=Kl(y),typeof H!="function")throw Error(h(150));return y=H.call(y),N(o,s,y,b)}if(typeof y.then=="function")return il(o,s,Fe(y),b);if(y.$$typeof===bl)return il(o,s,we(o,y),b);Ie(o,y)}return typeof y=="string"&&y!==""||typeof y=="number"||typeof y=="bigint"?(y=""+y,s!==null&&s.tag===6?(a(o,s.sibling),b=e(s,y),b.return=o,o=b):(a(o,s),b=Nf(y,o.mode,b),b.return=o,o=b),f(o)):a(o,s)}return function(o,s,y,b){try{ku=0;var H=il(o,s,y,b);return ou=null,H}catch(D){if(D===du||D===ke)throw D;var I=et(29,D,null,o.mode);return I.lanes=b,I.return=o,I}finally{}}}var Ya=Ls(!0),Ks=Ls(!1),na=!1;function Jf(l){l.updateQueue={baseState:l.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function wf(l,t){l=l.updateQueue,t.updateQueue===l&&(t.updateQueue={baseState:l.baseState,firstBaseUpdate:l.firstBaseUpdate,lastBaseUpdate:l.lastBaseUpdate,shared:l.shared,callbacks:null})}function fa(l){return{lane:l,tag:0,payload:null,callback:null,next:null}}function ia(l,t,a){var u=l.updateQueue;if(u===null)return null;if(u=u.shared,(ll&2)!==0){var e=u.pending;return e===null?t.next=t:(t.next=e.next,e.next=t),u.pending=t,t=Ve(l),Ds(l,null,a),t}return Ze(l,u,t,a),Ve(l)}function Fu(l,t,a){if(t=t.updateQueue,t!==null&&(t=t.shared,(a&4194048)!==0)){var u=t.lanes;u&=l.pendingLanes,a|=u,t.lanes=a,jc(l,a)}}function Wf(l,t){var a=l.updateQueue,u=l.alternate;if(u!==null&&(u=u.updateQueue,a===u)){var e=null,n=null;if(a=a.firstBaseUpdate,a!==null){do{var f={lane:a.lane,tag:a.tag,payload:a.payload,callback:null,next:null};n===null?e=n=f:n=n.next=f,a=a.next}while(a!==null);n===null?e=n=t:n=n.next=t}else e=n=t;a={baseState:u.baseState,firstBaseUpdate:e,lastBaseUpdate:n,shared:u.shared,callbacks:u.callbacks},l.updateQueue=a;return}l=a.lastBaseUpdate,l===null?a.firstBaseUpdate=t:l.next=t,a.lastBaseUpdate=t}var kf=!1;function Iu(){if(kf){var l=su;if(l!==null)throw l}}function Pu(l,t,a,u){kf=!1;var e=l.updateQueue;na=!1;var n=e.firstBaseUpdate,f=e.lastBaseUpdate,i=e.shared.pending;if(i!==null){e.shared.pending=null;var c=i,v=c.next;c.next=null,f===null?n=v:f.next=v,f=c;var S=l.alternate;S!==null&&(S=S.updateQueue,i=S.lastBaseUpdate,i!==f&&(i===null?S.firstBaseUpdate=v:i.next=v,S.lastBaseUpdate=c))}if(n!==null){var z=e.baseState;f=0,S=v=c=null,i=n;do{var m=i.lane&-536870913,g=m!==i.lane;if(g?(K&m)===m:(u&m)===m){m!==0&&m===cu&&(kf=!0),S!==null&&(S=S.next={lane:0,tag:i.tag,payload:i.payload,callback:null,next:null});l:{var O=l,N=i;m=t;var il=a;switch(N.tag){case 1:if(O=N.payload,typeof O=="function"){z=O.call(il,z,m);break l}z=O;break l;case 3:O.flags=O.flags&-65537|128;case 0:if(O=N.payload,m=typeof O=="function"?O.call(il,z,m):O,m==null)break l;z=R({},z,m);break l;case 2:na=!0}}m=i.callback,m!==null&&(l.flags|=64,g&&(l.flags|=8192),g=e.callbacks,g===null?e.callbacks=[m]:g.push(m))}else g={lane:m,tag:i.tag,payload:i.payload,callback:i.callback,next:null},S===null?(v=S=g,c=z):S=S.next=g,f|=m;if(i=i.next,i===null){if(i=e.shared.pending,i===null)break;g=i,i=g.next,g.next=null,e.lastBaseUpdate=g,e.shared.pending=null}}while(!0);S===null&&(c=z),e.baseState=c,e.firstBaseUpdate=v,e.lastBaseUpdate=S,n===null&&(e.shared.lanes=0),ya|=f,l.lanes=f,l.memoizedState=z}}function Js(l,t){if(typeof l!="function")throw Error(h(191,l));l.call(t)}function ws(l,t){var a=l.callbacks;if(a!==null)for(l.callbacks=null,l=0;l<a.length;l++)Js(a[l],t)}var yu=d(null),Pe=d(0);function Ws(l,t){l=kt,_(Pe,l),_(yu,t),kt=l|t.baseLanes}function $f(){_(Pe,kt),_(yu,yu.current)}function Ff(){kt=Pe.current,p(yu),p(Pe)}var nt=d(null),rt=null;function ca(l){var t=l.alternate;_(pl,pl.current&1),_(nt,l),rt===null&&(t===null||yu.current!==null||t.memoizedState!==null)&&(rt=l)}function If(l){_(pl,pl.current),_(nt,l),rt===null&&(rt=l)}function ks(l){l.tag===22?(_(pl,pl.current),_(nt,l),rt===null&&(rt=l)):sa()}function sa(){_(pl,pl.current),_(nt,nt.current)}function ft(l){p(nt),rt===l&&(rt=null),p(pl)}var pl=d(0);function ln(l){for(var t=l;t!==null;){if(t.tag===13){var a=t.memoizedState;if(a!==null&&(a=a.dehydrated,a===null||ec(a)||nc(a)))return t}else if(t.tag===19&&(t.memoizedProps.revealOrder==="forwards"||t.memoizedProps.revealOrder==="backwards"||t.memoizedProps.revealOrder==="unstable_legacy-backwards"||t.memoizedProps.revealOrder==="together")){if((t.flags&128)!==0)return t}else if(t.child!==null){t.child.return=t,t=t.child;continue}if(t===l)break;for(;t.sibling===null;){if(t.return===null||t.return===l)return null;t=t.return}t.sibling.return=t.return,t=t.sibling}return null}var Qt=0,Y=null,nl=null,Al=null,tn=!1,vu=!1,Ga=!1,an=0,le=0,mu=null,uv=0;function hl(){throw Error(h(321))}function Pf(l,t){if(t===null)return!1;for(var a=0;a<t.length&&a<l.length;a++)if(!ut(l[a],t[a]))return!1;return!0}function li(l,t,a,u,e,n){return Qt=n,Y=t,t.memoizedState=null,t.updateQueue=null,t.lanes=0,r.H=l===null||l.memoizedState===null?Rd:hi,Ga=!1,n=a(u,e),Ga=!1,vu&&(n=Fs(t,a,u,e)),$s(l),n}function $s(l){r.H=ue;var t=nl!==null&&nl.next!==null;if(Qt=0,Al=nl=Y=null,tn=!1,le=0,mu=null,t)throw Error(h(300));l===null||_l||(l=l.dependencies,l!==null&&Je(l)&&(_l=!0))}function Fs(l,t,a,u){Y=l;var e=0;do{if(vu&&(mu=null),le=0,vu=!1,25<=e)throw Error(h(301));if(e+=1,Al=nl=null,l.updateQueue!=null){var n=l.updateQueue;n.lastEffect=null,n.events=null,n.stores=null,n.memoCache!=null&&(n.memoCache.index=0)}r.H=Nd,n=t(a,u)}while(vu);return n}function ev(){var l=r.H,t=l.useState()[0];return t=typeof t.then=="function"?te(t):t,l=l.useState()[0],(nl!==null?nl.memoizedState:null)!==l&&(Y.flags|=1024),t}function ti(){var l=an!==0;return an=0,l}function ai(l,t,a){t.updateQueue=l.updateQueue,t.flags&=-2053,l.lanes&=~a}function ui(l){if(tn){for(l=l.memoizedState;l!==null;){var t=l.queue;t!==null&&(t.pending=null),l=l.next}tn=!1}Qt=0,Al=nl=Y=null,vu=!1,le=an=0,mu=null}function Zl(){var l={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return Al===null?Y.memoizedState=Al=l:Al=Al.next=l,Al}function Tl(){if(nl===null){var l=Y.alternate;l=l!==null?l.memoizedState:null}else l=nl.next;var t=Al===null?Y.memoizedState:Al.next;if(t!==null)Al=t,nl=l;else{if(l===null)throw Y.alternate===null?Error(h(467)):Error(h(310));nl=l,l={memoizedState:nl.memoizedState,baseState:nl.baseState,baseQueue:nl.baseQueue,queue:nl.queue,next:null},Al===null?Y.memoizedState=Al=l:Al=Al.next=l}return Al}function un(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function te(l){var t=le;return le+=1,mu===null&&(mu=[]),l=Qs(mu,l,t),t=Y,(Al===null?t.memoizedState:Al.next)===null&&(t=t.alternate,r.H=t===null||t.memoizedState===null?Rd:hi),l}function en(l){if(l!==null&&typeof l=="object"){if(typeof l.then=="function")return te(l);if(l.$$typeof===bl)return Bl(l)}throw Error(h(438,String(l)))}function ei(l){var t=null,a=Y.updateQueue;if(a!==null&&(t=a.memoCache),t==null){var u=Y.alternate;u!==null&&(u=u.updateQueue,u!==null&&(u=u.memoCache,u!=null&&(t={data:u.data.map(function(e){return e.slice()}),index:0})))}if(t==null&&(t={data:[],index:0}),a===null&&(a=un(),Y.updateQueue=a),a.memoCache=t,a=t.data[t.index],a===void 0)for(a=t.data[t.index]=Array(l),u=0;u<l;u++)a[u]=Va;return t.index++,a}function Zt(l,t){return typeof t=="function"?t(l):t}function nn(l){var t=Tl();return ni(t,nl,l)}function ni(l,t,a){var u=l.queue;if(u===null)throw Error(h(311));u.lastRenderedReducer=a;var e=l.baseQueue,n=u.pending;if(n!==null){if(e!==null){var f=e.next;e.next=n.next,n.next=f}t.baseQueue=e=n,u.pending=null}if(n=l.baseState,e===null)l.memoizedState=n;else{t=e.next;var i=f=null,c=null,v=t,S=!1;do{var z=v.lane&-536870913;if(z!==v.lane?(K&z)===z:(Qt&z)===z){var m=v.revertLane;if(m===0)c!==null&&(c=c.next={lane:0,revertLane:0,gesture:null,action:v.action,hasEagerState:v.hasEagerState,eagerState:v.eagerState,next:null}),z===cu&&(S=!0);else if((Qt&m)===m){v=v.next,m===cu&&(S=!0);continue}else z={lane:0,revertLane:v.revertLane,gesture:null,action:v.action,hasEagerState:v.hasEagerState,eagerState:v.eagerState,next:null},c===null?(i=c=z,f=n):c=c.next=z,Y.lanes|=m,ya|=m;z=v.action,Ga&&a(n,z),n=v.hasEagerState?v.eagerState:a(n,z)}else m={lane:z,revertLane:v.revertLane,gesture:v.gesture,action:v.action,hasEagerState:v.hasEagerState,eagerState:v.eagerState,next:null},c===null?(i=c=m,f=n):c=c.next=m,Y.lanes|=z,ya|=z;v=v.next}while(v!==null&&v!==t);if(c===null?f=n:c.next=i,!ut(n,l.memoizedState)&&(_l=!0,S&&(a=su,a!==null)))throw a;l.memoizedState=n,l.baseState=f,l.baseQueue=c,u.lastRenderedState=n}return e===null&&(u.lanes=0),[l.memoizedState,u.dispatch]}function fi(l){var t=Tl(),a=t.queue;if(a===null)throw Error(h(311));a.lastRenderedReducer=l;var u=a.dispatch,e=a.pending,n=t.memoizedState;if(e!==null){a.pending=null;var f=e=e.next;do n=l(n,f.action),f=f.next;while(f!==e);ut(n,t.memoizedState)||(_l=!0),t.memoizedState=n,t.baseQueue===null&&(t.baseState=n),a.lastRenderedState=n}return[n,u]}function Is(l,t,a){var u=Y,e=Tl(),n=W;if(n){if(a===void 0)throw Error(h(407));a=a()}else a=t();var f=!ut((nl||e).memoizedState,a);if(f&&(e.memoizedState=a,_l=!0),e=e.queue,si(td.bind(null,u,e,l),[l]),e.getSnapshot!==t||f||Al!==null&&Al.memoizedState.tag&1){if(u.flags|=2048,hu(9,{destroy:void 0},ld.bind(null,u,e,a,t),null),dl===null)throw Error(h(349));n||(Qt&127)!==0||Ps(u,t,a)}return a}function Ps(l,t,a){l.flags|=16384,l={getSnapshot:t,value:a},t=Y.updateQueue,t===null?(t=un(),Y.updateQueue=t,t.stores=[l]):(a=t.stores,a===null?t.stores=[l]:a.push(l))}function ld(l,t,a,u){t.value=a,t.getSnapshot=u,ad(t)&&ud(l)}function td(l,t,a){return a(function(){ad(t)&&ud(l)})}function ad(l){var t=l.getSnapshot;l=l.value;try{var a=t();return!ut(l,a)}catch{return!0}}function ud(l){var t=xa(l,2);t!==null&&Il(t,l,2)}function ii(l){var t=Zl();if(typeof l=="function"){var a=l;if(l=a(),Ga){It(!0);try{a()}finally{It(!1)}}}return t.memoizedState=t.baseState=l,t.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Zt,lastRenderedState:l},t}function ed(l,t,a,u){return l.baseState=a,ni(l,nl,typeof u=="function"?u:Zt)}function nv(l,t,a,u,e){if(sn(l))throw Error(h(485));if(l=t.action,l!==null){var n={payload:e,action:l,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(f){n.listeners.push(f)}};r.T!==null?a(!0):n.isTransition=!1,u(n),a=t.pending,a===null?(n.next=t.pending=n,nd(t,n)):(n.next=a.next,t.pending=a.next=n)}}function nd(l,t){var a=t.action,u=t.payload,e=l.state;if(t.isTransition){var n=r.T,f={};r.T=f;try{var i=a(e,u),c=r.S;c!==null&&c(f,i),fd(l,t,i)}catch(v){ci(l,t,v)}finally{n!==null&&f.types!==null&&(n.types=f.types),r.T=n}}else try{n=a(e,u),fd(l,t,n)}catch(v){ci(l,t,v)}}function fd(l,t,a){a!==null&&typeof a=="object"&&typeof a.then=="function"?a.then(function(u){id(l,t,u)},function(u){return ci(l,t,u)}):id(l,t,a)}function id(l,t,a){t.status="fulfilled",t.value=a,cd(t),l.state=a,t=l.pending,t!==null&&(a=t.next,a===t?l.pending=null:(a=a.next,t.next=a,nd(l,a)))}function ci(l,t,a){var u=l.pending;if(l.pending=null,u!==null){u=u.next;do t.status="rejected",t.reason=a,cd(t),t=t.next;while(t!==u)}l.action=null}function cd(l){l=l.listeners;for(var t=0;t<l.length;t++)(0,l[t])()}function sd(l,t){return t}function dd(l,t){if(W){var a=dl.formState;if(a!==null){l:{var u=Y;if(W){if(ol){t:{for(var e=ol,n=St;e.nodeType!==8;){if(!n){e=null;break t}if(e=bt(e.nextSibling),e===null){e=null;break t}}n=e.data,e=n==="F!"||n==="F"?e:null}if(e){ol=bt(e.nextSibling),u=e.data==="F!";break l}}ua(u)}u=!1}u&&(t=a[0])}}return a=Zl(),a.memoizedState=a.baseState=t,u={pending:null,lanes:0,dispatch:null,lastRenderedReducer:sd,lastRenderedState:t},a.queue=u,a=Ud.bind(null,Y,u),u.dispatch=a,u=ii(!1),n=mi.bind(null,Y,!1,u.queue),u=Zl(),e={state:t,dispatch:null,action:l,pending:null},u.queue=e,a=nv.bind(null,Y,e,n,a),e.dispatch=a,u.memoizedState=l,[t,a,!1]}function od(l){var t=Tl();return yd(t,nl,l)}function yd(l,t,a){if(t=ni(l,t,sd)[0],l=nn(Zt)[0],typeof t=="object"&&t!==null&&typeof t.then=="function")try{var u=te(t)}catch(f){throw f===du?ke:f}else u=t;t=Tl();var e=t.queue,n=e.dispatch;return a!==t.memoizedState&&(Y.flags|=2048,hu(9,{destroy:void 0},fv.bind(null,e,a),null)),[u,n,l]}function fv(l,t){l.action=t}function vd(l){var t=Tl(),a=nl;if(a!==null)return yd(t,a,l);Tl(),t=t.memoizedState,a=Tl();var u=a.queue.dispatch;return a.memoizedState=l,[t,u,!1]}function hu(l,t,a,u){return l={tag:l,create:a,deps:u,inst:t,next:null},t=Y.updateQueue,t===null&&(t=un(),Y.updateQueue=t),a=t.lastEffect,a===null?t.lastEffect=l.next=l:(u=a.next,a.next=l,l.next=u,t.lastEffect=l),l}function md(){return Tl().memoizedState}function fn(l,t,a,u){var e=Zl();Y.flags|=l,e.memoizedState=hu(1|t,{destroy:void 0},a,u===void 0?null:u)}function cn(l,t,a,u){var e=Tl();u=u===void 0?null:u;var n=e.memoizedState.inst;nl!==null&&u!==null&&Pf(u,nl.memoizedState.deps)?e.memoizedState=hu(t,n,a,u):(Y.flags|=l,e.memoizedState=hu(1|t,n,a,u))}function hd(l,t){fn(8390656,8,l,t)}function si(l,t){cn(2048,8,l,t)}function iv(l){Y.flags|=4;var t=Y.updateQueue;if(t===null)t=un(),Y.updateQueue=t,t.events=[l];else{var a=t.events;a===null?t.events=[l]:a.push(l)}}function gd(l){var t=Tl().memoizedState;return iv({ref:t,nextImpl:l}),function(){if((ll&2)!==0)throw Error(h(440));return t.impl.apply(void 0,arguments)}}function Sd(l,t){return cn(4,2,l,t)}function rd(l,t){return cn(4,4,l,t)}function bd(l,t){if(typeof t=="function"){l=l();var a=t(l);return function(){typeof a=="function"?a():t(null)}}if(t!=null)return l=l(),t.current=l,function(){t.current=null}}function zd(l,t,a){a=a!=null?a.concat([l]):null,cn(4,4,bd.bind(null,t,l),a)}function di(){}function pd(l,t){var a=Tl();t=t===void 0?null:t;var u=a.memoizedState;return t!==null&&Pf(t,u[1])?u[0]:(a.memoizedState=[l,t],l)}function Td(l,t){var a=Tl();t=t===void 0?null:t;var u=a.memoizedState;if(t!==null&&Pf(t,u[1]))return u[0];if(u=l(),Ga){It(!0);try{l()}finally{It(!1)}}return a.memoizedState=[u,t],u}function oi(l,t,a){return a===void 0||(Qt&1073741824)!==0&&(K&261930)===0?l.memoizedState=t:(l.memoizedState=a,l=E0(),Y.lanes|=l,ya|=l,a)}function Ed(l,t,a,u){return ut(a,t)?a:yu.current!==null?(l=oi(l,a,u),ut(l,t)||(_l=!0),l):(Qt&42)===0||(Qt&1073741824)!==0&&(K&261930)===0?(_l=!0,l.memoizedState=a):(l=E0(),Y.lanes|=l,ya|=l,t)}function Ad(l,t,a,u,e){var n=A.p;A.p=n!==0&&8>n?n:8;var f=r.T,i={};r.T=i,mi(l,!1,t,a);try{var c=e(),v=r.S;if(v!==null&&v(i,c),c!==null&&typeof c=="object"&&typeof c.then=="function"){var S=av(c,u);ae(l,t,S,st(l))}else ae(l,t,u,st(l))}catch(z){ae(l,t,{then:function(){},status:"rejected",reason:z},st())}finally{A.p=n,f!==null&&i.types!==null&&(f.types=i.types),r.T=f}}function cv(){}function yi(l,t,a,u){if(l.tag!==5)throw Error(h(476));var e=_d(l).queue;Ad(l,e,t,B,a===null?cv:function(){return Od(l),a(u)})}function _d(l){var t=l.memoizedState;if(t!==null)return t;t={memoizedState:B,baseState:B,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Zt,lastRenderedState:B},next:null};var a={};return t.next={memoizedState:a,baseState:a,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Zt,lastRenderedState:a},next:null},l.memoizedState=t,l=l.alternate,l!==null&&(l.memoizedState=t),t}function Od(l){var t=_d(l);t.next===null&&(t=l.alternate.memoizedState),ae(l,t.next.queue,{},st())}function vi(){return Bl(be)}function Md(){return Tl().memoizedState}function Dd(){return Tl().memoizedState}function sv(l){for(var t=l.return;t!==null;){switch(t.tag){case 24:case 3:var a=st();l=fa(a);var u=ia(t,l,a);u!==null&&(Il(u,t,a),Fu(u,t,a)),t={cache:Zf()},l.payload=t;return}t=t.return}}function dv(l,t,a){var u=st();a={lane:u,revertLane:0,gesture:null,action:a,hasEagerState:!1,eagerState:null,next:null},sn(l)?xd(t,a):(a=Hf(l,t,a,u),a!==null&&(Il(a,l,u),Hd(a,t,u)))}function Ud(l,t,a){var u=st();ae(l,t,a,u)}function ae(l,t,a,u){var e={lane:u,revertLane:0,gesture:null,action:a,hasEagerState:!1,eagerState:null,next:null};if(sn(l))xd(t,e);else{var n=l.alternate;if(l.lanes===0&&(n===null||n.lanes===0)&&(n=t.lastRenderedReducer,n!==null))try{var f=t.lastRenderedState,i=n(f,a);if(e.hasEagerState=!0,e.eagerState=i,ut(i,f))return Ze(l,t,e,0),dl===null&&Qe(),!1}catch{}finally{}if(a=Hf(l,t,e,u),a!==null)return Il(a,l,u),Hd(a,t,u),!0}return!1}function mi(l,t,a,u){if(u={lane:2,revertLane:Ji(),gesture:null,action:u,hasEagerState:!1,eagerState:null,next:null},sn(l)){if(t)throw Error(h(479))}else t=Hf(l,a,u,2),t!==null&&Il(t,l,2)}function sn(l){var t=l.alternate;return l===Y||t!==null&&t===Y}function xd(l,t){vu=tn=!0;var a=l.pending;a===null?t.next=t:(t.next=a.next,a.next=t),l.pending=t}function Hd(l,t,a){if((a&4194048)!==0){var u=t.lanes;u&=l.pendingLanes,a|=u,t.lanes=a,jc(l,a)}}var ue={readContext:Bl,use:en,useCallback:hl,useContext:hl,useEffect:hl,useImperativeHandle:hl,useLayoutEffect:hl,useInsertionEffect:hl,useMemo:hl,useReducer:hl,useRef:hl,useState:hl,useDebugValue:hl,useDeferredValue:hl,useTransition:hl,useSyncExternalStore:hl,useId:hl,useHostTransitionStatus:hl,useFormState:hl,useActionState:hl,useOptimistic:hl,useMemoCache:hl,useCacheRefresh:hl};ue.useEffectEvent=hl;var Rd={readContext:Bl,use:en,useCallback:function(l,t){return Zl().memoizedState=[l,t===void 0?null:t],l},useContext:Bl,useEffect:hd,useImperativeHandle:function(l,t,a){a=a!=null?a.concat([l]):null,fn(4194308,4,bd.bind(null,t,l),a)},useLayoutEffect:function(l,t){return fn(4194308,4,l,t)},useInsertionEffect:function(l,t){fn(4,2,l,t)},useMemo:function(l,t){var a=Zl();t=t===void 0?null:t;var u=l();if(Ga){It(!0);try{l()}finally{It(!1)}}return a.memoizedState=[u,t],u},useReducer:function(l,t,a){var u=Zl();if(a!==void 0){var e=a(t);if(Ga){It(!0);try{a(t)}finally{It(!1)}}}else e=t;return u.memoizedState=u.baseState=e,l={pending:null,lanes:0,dispatch:null,lastRenderedReducer:l,lastRenderedState:e},u.queue=l,l=l.dispatch=dv.bind(null,Y,l),[u.memoizedState,l]},useRef:function(l){var t=Zl();return l={current:l},t.memoizedState=l},useState:function(l){l=ii(l);var t=l.queue,a=Ud.bind(null,Y,t);return t.dispatch=a,[l.memoizedState,a]},useDebugValue:di,useDeferredValue:function(l,t){var a=Zl();return oi(a,l,t)},useTransition:function(){var l=ii(!1);return l=Ad.bind(null,Y,l.queue,!0,!1),Zl().memoizedState=l,[!1,l]},useSyncExternalStore:function(l,t,a){var u=Y,e=Zl();if(W){if(a===void 0)throw Error(h(407));a=a()}else{if(a=t(),dl===null)throw Error(h(349));(K&127)!==0||Ps(u,t,a)}e.memoizedState=a;var n={value:a,getSnapshot:t};return e.queue=n,hd(td.bind(null,u,n,l),[l]),u.flags|=2048,hu(9,{destroy:void 0},ld.bind(null,u,n,a,t),null),a},useId:function(){var l=Zl(),t=dl.identifierPrefix;if(W){var a=Ut,u=Dt;a=(u&~(1<<32-at(u)-1)).toString(32)+a,t="_"+t+"R_"+a,a=an++,0<a&&(t+="H"+a.toString(32)),t+="_"}else a=uv++,t="_"+t+"r_"+a.toString(32)+"_";return l.memoizedState=t},useHostTransitionStatus:vi,useFormState:dd,useActionState:dd,useOptimistic:function(l){var t=Zl();t.memoizedState=t.baseState=l;var a={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return t.queue=a,t=mi.bind(null,Y,!0,a),a.dispatch=t,[l,t]},useMemoCache:ei,useCacheRefresh:function(){return Zl().memoizedState=sv.bind(null,Y)},useEffectEvent:function(l){var t=Zl(),a={impl:l};return t.memoizedState=a,function(){if((ll&2)!==0)throw Error(h(440));return a.impl.apply(void 0,arguments)}}},hi={readContext:Bl,use:en,useCallback:pd,useContext:Bl,useEffect:si,useImperativeHandle:zd,useInsertionEffect:Sd,useLayoutEffect:rd,useMemo:Td,useReducer:nn,useRef:md,useState:function(){return nn(Zt)},useDebugValue:di,useDeferredValue:function(l,t){var a=Tl();return Ed(a,nl.memoizedState,l,t)},useTransition:function(){var l=nn(Zt)[0],t=Tl().memoizedState;return[typeof l=="boolean"?l:te(l),t]},useSyncExternalStore:Is,useId:Md,useHostTransitionStatus:vi,useFormState:od,useActionState:od,useOptimistic:function(l,t){var a=Tl();return ed(a,nl,l,t)},useMemoCache:ei,useCacheRefresh:Dd};hi.useEffectEvent=gd;var Nd={readContext:Bl,use:en,useCallback:pd,useContext:Bl,useEffect:si,useImperativeHandle:zd,useInsertionEffect:Sd,useLayoutEffect:rd,useMemo:Td,useReducer:fi,useRef:md,useState:function(){return fi(Zt)},useDebugValue:di,useDeferredValue:function(l,t){var a=Tl();return nl===null?oi(a,l,t):Ed(a,nl.memoizedState,l,t)},useTransition:function(){var l=fi(Zt)[0],t=Tl().memoizedState;return[typeof l=="boolean"?l:te(l),t]},useSyncExternalStore:Is,useId:Md,useHostTransitionStatus:vi,useFormState:vd,useActionState:vd,useOptimistic:function(l,t){var a=Tl();return nl!==null?ed(a,nl,l,t):(a.baseState=l,[l,a.queue.dispatch])},useMemoCache:ei,useCacheRefresh:Dd};Nd.useEffectEvent=gd;function gi(l,t,a,u){t=l.memoizedState,a=a(u,t),a=a==null?t:R({},t,a),l.memoizedState=a,l.lanes===0&&(l.updateQueue.baseState=a)}var Si={enqueueSetState:function(l,t,a){l=l._reactInternals;var u=st(),e=fa(u);e.payload=t,a!=null&&(e.callback=a),t=ia(l,e,u),t!==null&&(Il(t,l,u),Fu(t,l,u))},enqueueReplaceState:function(l,t,a){l=l._reactInternals;var u=st(),e=fa(u);e.tag=1,e.payload=t,a!=null&&(e.callback=a),t=ia(l,e,u),t!==null&&(Il(t,l,u),Fu(t,l,u))},enqueueForceUpdate:function(l,t){l=l._reactInternals;var a=st(),u=fa(a);u.tag=2,t!=null&&(u.callback=t),t=ia(l,u,a),t!==null&&(Il(t,l,a),Fu(t,l,a))}};function Cd(l,t,a,u,e,n,f){return l=l.stateNode,typeof l.shouldComponentUpdate=="function"?l.shouldComponentUpdate(u,n,f):t.prototype&&t.prototype.isPureReactComponent?!Vu(a,u)||!Vu(e,n):!0}function Bd(l,t,a,u){l=t.state,typeof t.componentWillReceiveProps=="function"&&t.componentWillReceiveProps(a,u),typeof t.UNSAFE_componentWillReceiveProps=="function"&&t.UNSAFE_componentWillReceiveProps(a,u),t.state!==l&&Si.enqueueReplaceState(t,t.state,null)}function Xa(l,t){var a=t;if("ref"in t){a={};for(var u in t)u!=="ref"&&(a[u]=t[u])}if(l=l.defaultProps){a===t&&(a=R({},a));for(var e in l)a[e]===void 0&&(a[e]=l[e])}return a}function jd(l){Xe(l)}function qd(l){console.error(l)}function Yd(l){Xe(l)}function dn(l,t){try{var a=l.onUncaughtError;a(t.value,{componentStack:t.stack})}catch(u){setTimeout(function(){throw u})}}function Gd(l,t,a){try{var u=l.onCaughtError;u(a.value,{componentStack:a.stack,errorBoundary:t.tag===1?t.stateNode:null})}catch(e){setTimeout(function(){throw e})}}function ri(l,t,a){return a=fa(a),a.tag=3,a.payload={element:null},a.callback=function(){dn(l,t)},a}function Xd(l){return l=fa(l),l.tag=3,l}function Qd(l,t,a,u){var e=a.type.getDerivedStateFromError;if(typeof e=="function"){var n=u.value;l.payload=function(){return e(n)},l.callback=function(){Gd(t,a,u)}}var f=a.stateNode;f!==null&&typeof f.componentDidCatch=="function"&&(l.callback=function(){Gd(t,a,u),typeof e!="function"&&(va===null?va=new Set([this]):va.add(this));var i=u.stack;this.componentDidCatch(u.value,{componentStack:i!==null?i:""})})}function ov(l,t,a,u,e){if(a.flags|=32768,u!==null&&typeof u=="object"&&typeof u.then=="function"){if(t=a.alternate,t!==null&&iu(t,a,e,!0),a=nt.current,a!==null){switch(a.tag){case 31:case 13:return rt===null?Tn():a.alternate===null&&gl===0&&(gl=3),a.flags&=-257,a.flags|=65536,a.lanes=e,u===$e?a.flags|=16384:(t=a.updateQueue,t===null?a.updateQueue=new Set([u]):t.add(u),Vi(l,u,e)),!1;case 22:return a.flags|=65536,u===$e?a.flags|=16384:(t=a.updateQueue,t===null?(t={transitions:null,markerInstances:null,retryQueue:new Set([u])},a.updateQueue=t):(a=t.retryQueue,a===null?t.retryQueue=new Set([u]):a.add(u)),Vi(l,u,e)),!1}throw Error(h(435,a.tag))}return Vi(l,u,e),Tn(),!1}if(W)return t=nt.current,t!==null?((t.flags&65536)===0&&(t.flags|=256),t.flags|=65536,t.lanes=e,u!==qf&&(l=Error(h(422),{cause:u}),Ju(mt(l,a)))):(u!==qf&&(t=Error(h(423),{cause:u}),Ju(mt(t,a))),l=l.current.alternate,l.flags|=65536,e&=-e,l.lanes|=e,u=mt(u,a),e=ri(l.stateNode,u,e),Wf(l,e),gl!==4&&(gl=2)),!1;var n=Error(h(520),{cause:u});if(n=mt(n,a),oe===null?oe=[n]:oe.push(n),gl!==4&&(gl=2),t===null)return!0;u=mt(u,a),a=t;do{switch(a.tag){case 3:return a.flags|=65536,l=e&-e,a.lanes|=l,l=ri(a.stateNode,u,l),Wf(a,l),!1;case 1:if(t=a.type,n=a.stateNode,(a.flags&128)===0&&(typeof t.getDerivedStateFromError=="function"||n!==null&&typeof n.componentDidCatch=="function"&&(va===null||!va.has(n))))return a.flags|=65536,e&=-e,a.lanes|=e,e=Xd(e),Qd(e,l,a,u),Wf(a,e),!1}a=a.return}while(a!==null);return!1}var bi=Error(h(461)),_l=!1;function jl(l,t,a,u){t.child=l===null?Ks(t,null,a,u):Ya(t,l.child,a,u)}function Zd(l,t,a,u,e){a=a.render;var n=t.ref;if("ref"in u){var f={};for(var i in u)i!=="ref"&&(f[i]=u[i])}else f=u;return Ca(t),u=li(l,t,a,f,n,e),i=ti(),l!==null&&!_l?(ai(l,t,e),Vt(l,t,e)):(W&&i&&Bf(t),t.flags|=1,jl(l,t,u,e),t.child)}function Vd(l,t,a,u,e){if(l===null){var n=a.type;return typeof n=="function"&&!Rf(n)&&n.defaultProps===void 0&&a.compare===null?(t.tag=15,t.type=n,Ld(l,t,n,u,e)):(l=Le(a.type,null,u,t,t.mode,e),l.ref=t.ref,l.return=t,t.child=l)}if(n=l.child,!Mi(l,e)){var f=n.memoizedProps;if(a=a.compare,a=a!==null?a:Vu,a(f,u)&&l.ref===t.ref)return Vt(l,t,e)}return t.flags|=1,l=qt(n,u),l.ref=t.ref,l.return=t,t.child=l}function Ld(l,t,a,u,e){if(l!==null){var n=l.memoizedProps;if(Vu(n,u)&&l.ref===t.ref)if(_l=!1,t.pendingProps=u=n,Mi(l,e))(l.flags&131072)!==0&&(_l=!0);else return t.lanes=l.lanes,Vt(l,t,e)}return zi(l,t,a,u,e)}function Kd(l,t,a,u){var e=u.children,n=l!==null?l.memoizedState:null;if(l===null&&t.stateNode===null&&(t.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),u.mode==="hidden"){if((t.flags&128)!==0){if(n=n!==null?n.baseLanes|a:a,l!==null){for(u=t.child=l.child,e=0;u!==null;)e=e|u.lanes|u.childLanes,u=u.sibling;u=e&~n}else u=0,t.child=null;return Jd(l,t,n,a,u)}if((a&536870912)!==0)t.memoizedState={baseLanes:0,cachePool:null},l!==null&&We(t,n!==null?n.cachePool:null),n!==null?Ws(t,n):$f(),ks(t);else return u=t.lanes=536870912,Jd(l,t,n!==null?n.baseLanes|a:a,a,u)}else n!==null?(We(t,n.cachePool),Ws(t,n),sa(),t.memoizedState=null):(l!==null&&We(t,null),$f(),sa());return jl(l,t,e,a),t.child}function ee(l,t){return l!==null&&l.tag===22||t.stateNode!==null||(t.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),t.sibling}function Jd(l,t,a,u,e){var n=Lf();return n=n===null?null:{parent:El._currentValue,pool:n},t.memoizedState={baseLanes:a,cachePool:n},l!==null&&We(t,null),$f(),ks(t),l!==null&&iu(l,t,u,!0),t.childLanes=e,null}function on(l,t){return t=vn({mode:t.mode,children:t.children},l.mode),t.ref=l.ref,l.child=t,t.return=l,t}function wd(l,t,a){return Ya(t,l.child,null,a),l=on(t,t.pendingProps),l.flags|=2,ft(t),t.memoizedState=null,l}function yv(l,t,a){var u=t.pendingProps,e=(t.flags&128)!==0;if(t.flags&=-129,l===null){if(W){if(u.mode==="hidden")return l=on(t,u),t.lanes=536870912,ee(null,l);if(If(t),(l=ol)?(l=no(l,St),l=l!==null&&l.data==="&"?l:null,l!==null&&(t.memoizedState={dehydrated:l,treeContext:ta!==null?{id:Dt,overflow:Ut}:null,retryLane:536870912,hydrationErrors:null},a=xs(l),a.return=t,t.child=a,Cl=t,ol=null)):l=null,l===null)throw ua(t);return t.lanes=536870912,null}return on(t,u)}var n=l.memoizedState;if(n!==null){var f=n.dehydrated;if(If(t),e)if(t.flags&256)t.flags&=-257,t=wd(l,t,a);else if(t.memoizedState!==null)t.child=l.child,t.flags|=128,t=null;else throw Error(h(558));else if(_l||iu(l,t,a,!1),e=(a&l.childLanes)!==0,_l||e){if(u=dl,u!==null&&(f=qc(u,a),f!==0&&f!==n.retryLane))throw n.retryLane=f,xa(l,f),Il(u,l,f),bi;Tn(),t=wd(l,t,a)}else l=n.treeContext,ol=bt(f.nextSibling),Cl=t,W=!0,aa=null,St=!1,l!==null&&Ns(t,l),t=on(t,u),t.flags|=4096;return t}return l=qt(l.child,{mode:u.mode,children:u.children}),l.ref=t.ref,t.child=l,l.return=t,l}function yn(l,t){var a=t.ref;if(a===null)l!==null&&l.ref!==null&&(t.flags|=4194816);else{if(typeof a!="function"&&typeof a!="object")throw Error(h(284));(l===null||l.ref!==a)&&(t.flags|=4194816)}}function zi(l,t,a,u,e){return Ca(t),a=li(l,t,a,u,void 0,e),u=ti(),l!==null&&!_l?(ai(l,t,e),Vt(l,t,e)):(W&&u&&Bf(t),t.flags|=1,jl(l,t,a,e),t.child)}function Wd(l,t,a,u,e,n){return Ca(t),t.updateQueue=null,a=Fs(t,u,a,e),$s(l),u=ti(),l!==null&&!_l?(ai(l,t,n),Vt(l,t,n)):(W&&u&&Bf(t),t.flags|=1,jl(l,t,a,n),t.child)}function kd(l,t,a,u,e){if(Ca(t),t.stateNode===null){var n=uu,f=a.contextType;typeof f=="object"&&f!==null&&(n=Bl(f)),n=new a(u,n),t.memoizedState=n.state!==null&&n.state!==void 0?n.state:null,n.updater=Si,t.stateNode=n,n._reactInternals=t,n=t.stateNode,n.props=u,n.state=t.memoizedState,n.refs={},Jf(t),f=a.contextType,n.context=typeof f=="object"&&f!==null?Bl(f):uu,n.state=t.memoizedState,f=a.getDerivedStateFromProps,typeof f=="function"&&(gi(t,a,f,u),n.state=t.memoizedState),typeof a.getDerivedStateFromProps=="function"||typeof n.getSnapshotBeforeUpdate=="function"||typeof n.UNSAFE_componentWillMount!="function"&&typeof n.componentWillMount!="function"||(f=n.state,typeof n.componentWillMount=="function"&&n.componentWillMount(),typeof n.UNSAFE_componentWillMount=="function"&&n.UNSAFE_componentWillMount(),f!==n.state&&Si.enqueueReplaceState(n,n.state,null),Pu(t,u,n,e),Iu(),n.state=t.memoizedState),typeof n.componentDidMount=="function"&&(t.flags|=4194308),u=!0}else if(l===null){n=t.stateNode;var i=t.memoizedProps,c=Xa(a,i);n.props=c;var v=n.context,S=a.contextType;f=uu,typeof S=="object"&&S!==null&&(f=Bl(S));var z=a.getDerivedStateFromProps;S=typeof z=="function"||typeof n.getSnapshotBeforeUpdate=="function",i=t.pendingProps!==i,S||typeof n.UNSAFE_componentWillReceiveProps!="function"&&typeof n.componentWillReceiveProps!="function"||(i||v!==f)&&Bd(t,n,u,f),na=!1;var m=t.memoizedState;n.state=m,Pu(t,u,n,e),Iu(),v=t.memoizedState,i||m!==v||na?(typeof z=="function"&&(gi(t,a,z,u),v=t.memoizedState),(c=na||Cd(t,a,c,u,m,v,f))?(S||typeof n.UNSAFE_componentWillMount!="function"&&typeof n.componentWillMount!="function"||(typeof n.componentWillMount=="function"&&n.componentWillMount(),typeof n.UNSAFE_componentWillMount=="function"&&n.UNSAFE_componentWillMount()),typeof n.componentDidMount=="function"&&(t.flags|=4194308)):(typeof n.componentDidMount=="function"&&(t.flags|=4194308),t.memoizedProps=u,t.memoizedState=v),n.props=u,n.state=v,n.context=f,u=c):(typeof n.componentDidMount=="function"&&(t.flags|=4194308),u=!1)}else{n=t.stateNode,wf(l,t),f=t.memoizedProps,S=Xa(a,f),n.props=S,z=t.pendingProps,m=n.context,v=a.contextType,c=uu,typeof v=="object"&&v!==null&&(c=Bl(v)),i=a.getDerivedStateFromProps,(v=typeof i=="function"||typeof n.getSnapshotBeforeUpdate=="function")||typeof n.UNSAFE_componentWillReceiveProps!="function"&&typeof n.componentWillReceiveProps!="function"||(f!==z||m!==c)&&Bd(t,n,u,c),na=!1,m=t.memoizedState,n.state=m,Pu(t,u,n,e),Iu();var g=t.memoizedState;f!==z||m!==g||na||l!==null&&l.dependencies!==null&&Je(l.dependencies)?(typeof i=="function"&&(gi(t,a,i,u),g=t.memoizedState),(S=na||Cd(t,a,S,u,m,g,c)||l!==null&&l.dependencies!==null&&Je(l.dependencies))?(v||typeof n.UNSAFE_componentWillUpdate!="function"&&typeof n.componentWillUpdate!="function"||(typeof n.componentWillUpdate=="function"&&n.componentWillUpdate(u,g,c),typeof n.UNSAFE_componentWillUpdate=="function"&&n.UNSAFE_componentWillUpdate(u,g,c)),typeof n.componentDidUpdate=="function"&&(t.flags|=4),typeof n.getSnapshotBeforeUpdate=="function"&&(t.flags|=1024)):(typeof n.componentDidUpdate!="function"||f===l.memoizedProps&&m===l.memoizedState||(t.flags|=4),typeof n.getSnapshotBeforeUpdate!="function"||f===l.memoizedProps&&m===l.memoizedState||(t.flags|=1024),t.memoizedProps=u,t.memoizedState=g),n.props=u,n.state=g,n.context=c,u=S):(typeof n.componentDidUpdate!="function"||f===l.memoizedProps&&m===l.memoizedState||(t.flags|=4),typeof n.getSnapshotBeforeUpdate!="function"||f===l.memoizedProps&&m===l.memoizedState||(t.flags|=1024),u=!1)}return n=u,yn(l,t),u=(t.flags&128)!==0,n||u?(n=t.stateNode,a=u&&typeof a.getDerivedStateFromError!="function"?null:n.render(),t.flags|=1,l!==null&&u?(t.child=Ya(t,l.child,null,e),t.child=Ya(t,null,a,e)):jl(l,t,a,e),t.memoizedState=n.state,l=t.child):l=Vt(l,t,e),l}function $d(l,t,a,u){return Ra(),t.flags|=256,jl(l,t,a,u),t.child}var pi={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function Ti(l){return{baseLanes:l,cachePool:Gs()}}function Ei(l,t,a){return l=l!==null?l.childLanes&~a:0,t&&(l|=ct),l}function Fd(l,t,a){var u=t.pendingProps,e=!1,n=(t.flags&128)!==0,f;if((f=n)||(f=l!==null&&l.memoizedState===null?!1:(pl.current&2)!==0),f&&(e=!0,t.flags&=-129),f=(t.flags&32)!==0,t.flags&=-33,l===null){if(W){if(e?ca(t):sa(),(l=ol)?(l=no(l,St),l=l!==null&&l.data!=="&"?l:null,l!==null&&(t.memoizedState={dehydrated:l,treeContext:ta!==null?{id:Dt,overflow:Ut}:null,retryLane:536870912,hydrationErrors:null},a=xs(l),a.return=t,t.child=a,Cl=t,ol=null)):l=null,l===null)throw ua(t);return nc(l)?t.lanes=32:t.lanes=536870912,null}var i=u.children;return u=u.fallback,e?(sa(),e=t.mode,i=vn({mode:"hidden",children:i},e),u=Ha(u,e,a,null),i.return=t,u.return=t,i.sibling=u,t.child=i,u=t.child,u.memoizedState=Ti(a),u.childLanes=Ei(l,f,a),t.memoizedState=pi,ee(null,u)):(ca(t),Ai(t,i))}var c=l.memoizedState;if(c!==null&&(i=c.dehydrated,i!==null)){if(n)t.flags&256?(ca(t),t.flags&=-257,t=_i(l,t,a)):t.memoizedState!==null?(sa(),t.child=l.child,t.flags|=128,t=null):(sa(),i=u.fallback,e=t.mode,u=vn({mode:"visible",children:u.children},e),i=Ha(i,e,a,null),i.flags|=2,u.return=t,i.return=t,u.sibling=i,t.child=u,Ya(t,l.child,null,a),u=t.child,u.memoizedState=Ti(a),u.childLanes=Ei(l,f,a),t.memoizedState=pi,t=ee(null,u));else if(ca(t),nc(i)){if(f=i.nextSibling&&i.nextSibling.dataset,f)var v=f.dgst;f=v,u=Error(h(419)),u.stack="",u.digest=f,Ju({value:u,source:null,stack:null}),t=_i(l,t,a)}else if(_l||iu(l,t,a,!1),f=(a&l.childLanes)!==0,_l||f){if(f=dl,f!==null&&(u=qc(f,a),u!==0&&u!==c.retryLane))throw c.retryLane=u,xa(l,u),Il(f,l,u),bi;ec(i)||Tn(),t=_i(l,t,a)}else ec(i)?(t.flags|=192,t.child=l.child,t=null):(l=c.treeContext,ol=bt(i.nextSibling),Cl=t,W=!0,aa=null,St=!1,l!==null&&Ns(t,l),t=Ai(t,u.children),t.flags|=4096);return t}return e?(sa(),i=u.fallback,e=t.mode,c=l.child,v=c.sibling,u=qt(c,{mode:"hidden",children:u.children}),u.subtreeFlags=c.subtreeFlags&65011712,v!==null?i=qt(v,i):(i=Ha(i,e,a,null),i.flags|=2),i.return=t,u.return=t,u.sibling=i,t.child=u,ee(null,u),u=t.child,i=l.child.memoizedState,i===null?i=Ti(a):(e=i.cachePool,e!==null?(c=El._currentValue,e=e.parent!==c?{parent:c,pool:c}:e):e=Gs(),i={baseLanes:i.baseLanes|a,cachePool:e}),u.memoizedState=i,u.childLanes=Ei(l,f,a),t.memoizedState=pi,ee(l.child,u)):(ca(t),a=l.child,l=a.sibling,a=qt(a,{mode:"visible",children:u.children}),a.return=t,a.sibling=null,l!==null&&(f=t.deletions,f===null?(t.deletions=[l],t.flags|=16):f.push(l)),t.child=a,t.memoizedState=null,a)}function Ai(l,t){return t=vn({mode:"visible",children:t},l.mode),t.return=l,l.child=t}function vn(l,t){return l=et(22,l,null,t),l.lanes=0,l}function _i(l,t,a){return Ya(t,l.child,null,a),l=Ai(t,t.pendingProps.children),l.flags|=2,t.memoizedState=null,l}function Id(l,t,a){l.lanes|=t;var u=l.alternate;u!==null&&(u.lanes|=t),Xf(l.return,t,a)}function Oi(l,t,a,u,e,n){var f=l.memoizedState;f===null?l.memoizedState={isBackwards:t,rendering:null,renderingStartTime:0,last:u,tail:a,tailMode:e,treeForkCount:n}:(f.isBackwards=t,f.rendering=null,f.renderingStartTime=0,f.last=u,f.tail=a,f.tailMode=e,f.treeForkCount=n)}function Pd(l,t,a){var u=t.pendingProps,e=u.revealOrder,n=u.tail;u=u.children;var f=pl.current,i=(f&2)!==0;if(i?(f=f&1|2,t.flags|=128):f&=1,_(pl,f),jl(l,t,u,a),u=W?Ku:0,!i&&l!==null&&(l.flags&128)!==0)l:for(l=t.child;l!==null;){if(l.tag===13)l.memoizedState!==null&&Id(l,a,t);else if(l.tag===19)Id(l,a,t);else if(l.child!==null){l.child.return=l,l=l.child;continue}if(l===t)break l;for(;l.sibling===null;){if(l.return===null||l.return===t)break l;l=l.return}l.sibling.return=l.return,l=l.sibling}switch(e){case"forwards":for(a=t.child,e=null;a!==null;)l=a.alternate,l!==null&&ln(l)===null&&(e=a),a=a.sibling;a=e,a===null?(e=t.child,t.child=null):(e=a.sibling,a.sibling=null),Oi(t,!1,e,a,n,u);break;case"backwards":case"unstable_legacy-backwards":for(a=null,e=t.child,t.child=null;e!==null;){if(l=e.alternate,l!==null&&ln(l)===null){t.child=e;break}l=e.sibling,e.sibling=a,a=e,e=l}Oi(t,!0,a,null,n,u);break;case"together":Oi(t,!1,null,null,void 0,u);break;default:t.memoizedState=null}return t.child}function Vt(l,t,a){if(l!==null&&(t.dependencies=l.dependencies),ya|=t.lanes,(a&t.childLanes)===0)if(l!==null){if(iu(l,t,a,!1),(a&t.childLanes)===0)return null}else return null;if(l!==null&&t.child!==l.child)throw Error(h(153));if(t.child!==null){for(l=t.child,a=qt(l,l.pendingProps),t.child=a,a.return=t;l.sibling!==null;)l=l.sibling,a=a.sibling=qt(l,l.pendingProps),a.return=t;a.sibling=null}return t.child}function Mi(l,t){return(l.lanes&t)!==0?!0:(l=l.dependencies,!!(l!==null&&Je(l)))}function vv(l,t,a){switch(t.tag){case 3:Ql(t,t.stateNode.containerInfo),ea(t,El,l.memoizedState.cache),Ra();break;case 27:case 5:xu(t);break;case 4:Ql(t,t.stateNode.containerInfo);break;case 10:ea(t,t.type,t.memoizedProps.value);break;case 31:if(t.memoizedState!==null)return t.flags|=128,If(t),null;break;case 13:var u=t.memoizedState;if(u!==null)return u.dehydrated!==null?(ca(t),t.flags|=128,null):(a&t.child.childLanes)!==0?Fd(l,t,a):(ca(t),l=Vt(l,t,a),l!==null?l.sibling:null);ca(t);break;case 19:var e=(l.flags&128)!==0;if(u=(a&t.childLanes)!==0,u||(iu(l,t,a,!1),u=(a&t.childLanes)!==0),e){if(u)return Pd(l,t,a);t.flags|=128}if(e=t.memoizedState,e!==null&&(e.rendering=null,e.tail=null,e.lastEffect=null),_(pl,pl.current),u)break;return null;case 22:return t.lanes=0,Kd(l,t,a,t.pendingProps);case 24:ea(t,El,l.memoizedState.cache)}return Vt(l,t,a)}function l0(l,t,a){if(l!==null)if(l.memoizedProps!==t.pendingProps)_l=!0;else{if(!Mi(l,a)&&(t.flags&128)===0)return _l=!1,vv(l,t,a);_l=(l.flags&131072)!==0}else _l=!1,W&&(t.flags&1048576)!==0&&Rs(t,Ku,t.index);switch(t.lanes=0,t.tag){case 16:l:{var u=t.pendingProps;if(l=ja(t.elementType),t.type=l,typeof l=="function")Rf(l)?(u=Xa(l,u),t.tag=1,t=kd(null,t,l,u,a)):(t.tag=0,t=zi(null,t,l,u,a));else{if(l!=null){var e=l.$$typeof;if(e===dt){t.tag=11,t=Zd(null,t,l,u,a);break l}else if(e===w){t.tag=14,t=Vd(null,t,l,u,a);break l}}throw t=Nt(l)||l,Error(h(306,t,""))}}return t;case 0:return zi(l,t,t.type,t.pendingProps,a);case 1:return u=t.type,e=Xa(u,t.pendingProps),kd(l,t,u,e,a);case 3:l:{if(Ql(t,t.stateNode.containerInfo),l===null)throw Error(h(387));u=t.pendingProps;var n=t.memoizedState;e=n.element,wf(l,t),Pu(t,u,null,a);var f=t.memoizedState;if(u=f.cache,ea(t,El,u),u!==n.cache&&Qf(t,[El],a,!0),Iu(),u=f.element,n.isDehydrated)if(n={element:u,isDehydrated:!1,cache:f.cache},t.updateQueue.baseState=n,t.memoizedState=n,t.flags&256){t=$d(l,t,u,a);break l}else if(u!==e){e=mt(Error(h(424)),t),Ju(e),t=$d(l,t,u,a);break l}else{switch(l=t.stateNode.containerInfo,l.nodeType){case 9:l=l.body;break;default:l=l.nodeName==="HTML"?l.ownerDocument.body:l}for(ol=bt(l.firstChild),Cl=t,W=!0,aa=null,St=!0,a=Ks(t,null,u,a),t.child=a;a;)a.flags=a.flags&-3|4096,a=a.sibling}else{if(Ra(),u===e){t=Vt(l,t,a);break l}jl(l,t,u,a)}t=t.child}return t;case 26:return yn(l,t),l===null?(a=yo(t.type,null,t.pendingProps,null))?t.memoizedState=a:W||(a=t.type,l=t.pendingProps,u=Un(Q.current).createElement(a),u[Nl]=t,u[Jl]=l,ql(u,a,l),xl(u),t.stateNode=u):t.memoizedState=yo(t.type,l.memoizedProps,t.pendingProps,l.memoizedState),null;case 27:return xu(t),l===null&&W&&(u=t.stateNode=co(t.type,t.pendingProps,Q.current),Cl=t,St=!0,e=ol,Sa(t.type)?(fc=e,ol=bt(u.firstChild)):ol=e),jl(l,t,t.pendingProps.children,a),yn(l,t),l===null&&(t.flags|=4194304),t.child;case 5:return l===null&&W&&((e=u=ol)&&(u=Vv(u,t.type,t.pendingProps,St),u!==null?(t.stateNode=u,Cl=t,ol=bt(u.firstChild),St=!1,e=!0):e=!1),e||ua(t)),xu(t),e=t.type,n=t.pendingProps,f=l!==null?l.memoizedProps:null,u=n.children,tc(e,n)?u=null:f!==null&&tc(e,f)&&(t.flags|=32),t.memoizedState!==null&&(e=li(l,t,ev,null,null,a),be._currentValue=e),yn(l,t),jl(l,t,u,a),t.child;case 6:return l===null&&W&&((l=a=ol)&&(a=Lv(a,t.pendingProps,St),a!==null?(t.stateNode=a,Cl=t,ol=null,l=!0):l=!1),l||ua(t)),null;case 13:return Fd(l,t,a);case 4:return Ql(t,t.stateNode.containerInfo),u=t.pendingProps,l===null?t.child=Ya(t,null,u,a):jl(l,t,u,a),t.child;case 11:return Zd(l,t,t.type,t.pendingProps,a);case 7:return jl(l,t,t.pendingProps,a),t.child;case 8:return jl(l,t,t.pendingProps.children,a),t.child;case 12:return jl(l,t,t.pendingProps.children,a),t.child;case 10:return u=t.pendingProps,ea(t,t.type,u.value),jl(l,t,u.children,a),t.child;case 9:return e=t.type._context,u=t.pendingProps.children,Ca(t),e=Bl(e),u=u(e),t.flags|=1,jl(l,t,u,a),t.child;case 14:return Vd(l,t,t.type,t.pendingProps,a);case 15:return Ld(l,t,t.type,t.pendingProps,a);case 19:return Pd(l,t,a);case 31:return yv(l,t,a);case 22:return Kd(l,t,a,t.pendingProps);case 24:return Ca(t),u=Bl(El),l===null?(e=Lf(),e===null&&(e=dl,n=Zf(),e.pooledCache=n,n.refCount++,n!==null&&(e.pooledCacheLanes|=a),e=n),t.memoizedState={parent:u,cache:e},Jf(t),ea(t,El,e)):((l.lanes&a)!==0&&(wf(l,t),Pu(t,null,null,a),Iu()),e=l.memoizedState,n=t.memoizedState,e.parent!==u?(e={parent:u,cache:u},t.memoizedState=e,t.lanes===0&&(t.memoizedState=t.updateQueue.baseState=e),ea(t,El,u)):(u=n.cache,ea(t,El,u),u!==e.cache&&Qf(t,[El],a,!0))),jl(l,t,t.pendingProps.children,a),t.child;case 29:throw t.pendingProps}throw Error(h(156,t.tag))}function Lt(l){l.flags|=4}function Di(l,t,a,u,e){if((t=(l.mode&32)!==0)&&(t=!1),t){if(l.flags|=16777216,(e&335544128)===e)if(l.stateNode.complete)l.flags|=8192;else if(M0())l.flags|=8192;else throw qa=$e,Kf}else l.flags&=-16777217}function t0(l,t){if(t.type!=="stylesheet"||(t.state.loading&4)!==0)l.flags&=-16777217;else if(l.flags|=16777216,!So(t))if(M0())l.flags|=8192;else throw qa=$e,Kf}function mn(l,t){t!==null&&(l.flags|=4),l.flags&16384&&(t=l.tag!==22?Cc():536870912,l.lanes|=t,bu|=t)}function ne(l,t){if(!W)switch(l.tailMode){case"hidden":t=l.tail;for(var a=null;t!==null;)t.alternate!==null&&(a=t),t=t.sibling;a===null?l.tail=null:a.sibling=null;break;case"collapsed":a=l.tail;for(var u=null;a!==null;)a.alternate!==null&&(u=a),a=a.sibling;u===null?t||l.tail===null?l.tail=null:l.tail.sibling=null:u.sibling=null}}function yl(l){var t=l.alternate!==null&&l.alternate.child===l.child,a=0,u=0;if(t)for(var e=l.child;e!==null;)a|=e.lanes|e.childLanes,u|=e.subtreeFlags&65011712,u|=e.flags&65011712,e.return=l,e=e.sibling;else for(e=l.child;e!==null;)a|=e.lanes|e.childLanes,u|=e.subtreeFlags,u|=e.flags,e.return=l,e=e.sibling;return l.subtreeFlags|=u,l.childLanes=a,t}function mv(l,t,a){var u=t.pendingProps;switch(jf(t),t.tag){case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return yl(t),null;case 1:return yl(t),null;case 3:return a=t.stateNode,u=null,l!==null&&(u=l.memoizedState.cache),t.memoizedState.cache!==u&&(t.flags|=2048),Xt(El),zl(),a.pendingContext&&(a.context=a.pendingContext,a.pendingContext=null),(l===null||l.child===null)&&(fu(t)?Lt(t):l===null||l.memoizedState.isDehydrated&&(t.flags&256)===0||(t.flags|=1024,Yf())),yl(t),null;case 26:var e=t.type,n=t.memoizedState;return l===null?(Lt(t),n!==null?(yl(t),t0(t,n)):(yl(t),Di(t,e,null,u,a))):n?n!==l.memoizedState?(Lt(t),yl(t),t0(t,n)):(yl(t),t.flags&=-16777217):(l=l.memoizedProps,l!==u&&Lt(t),yl(t),Di(t,e,l,u,a)),null;case 27:if(Ae(t),a=Q.current,e=t.type,l!==null&&t.stateNode!=null)l.memoizedProps!==u&&Lt(t);else{if(!u){if(t.stateNode===null)throw Error(h(166));return yl(t),null}l=M.current,fu(t)?Cs(t):(l=co(e,u,a),t.stateNode=l,Lt(t))}return yl(t),null;case 5:if(Ae(t),e=t.type,l!==null&&t.stateNode!=null)l.memoizedProps!==u&&Lt(t);else{if(!u){if(t.stateNode===null)throw Error(h(166));return yl(t),null}if(n=M.current,fu(t))Cs(t);else{var f=Un(Q.current);switch(n){case 1:n=f.createElementNS("http://www.w3.org/2000/svg",e);break;case 2:n=f.createElementNS("http://www.w3.org/1998/Math/MathML",e);break;default:switch(e){case"svg":n=f.createElementNS("http://www.w3.org/2000/svg",e);break;case"math":n=f.createElementNS("http://www.w3.org/1998/Math/MathML",e);break;case"script":n=f.createElement("div"),n.innerHTML="<script><\/script>",n=n.removeChild(n.firstChild);break;case"select":n=typeof u.is=="string"?f.createElement("select",{is:u.is}):f.createElement("select"),u.multiple?n.multiple=!0:u.size&&(n.size=u.size);break;default:n=typeof u.is=="string"?f.createElement(e,{is:u.is}):f.createElement(e)}}n[Nl]=t,n[Jl]=u;l:for(f=t.child;f!==null;){if(f.tag===5||f.tag===6)n.appendChild(f.stateNode);else if(f.tag!==4&&f.tag!==27&&f.child!==null){f.child.return=f,f=f.child;continue}if(f===t)break l;for(;f.sibling===null;){if(f.return===null||f.return===t)break l;f=f.return}f.sibling.return=f.return,f=f.sibling}t.stateNode=n;l:switch(ql(n,e,u),e){case"button":case"input":case"select":case"textarea":u=!!u.autoFocus;break l;case"img":u=!0;break l;default:u=!1}u&&Lt(t)}}return yl(t),Di(t,t.type,l===null?null:l.memoizedProps,t.pendingProps,a),null;case 6:if(l&&t.stateNode!=null)l.memoizedProps!==u&&Lt(t);else{if(typeof u!="string"&&t.stateNode===null)throw Error(h(166));if(l=Q.current,fu(t)){if(l=t.stateNode,a=t.memoizedProps,u=null,e=Cl,e!==null)switch(e.tag){case 27:case 5:u=e.memoizedProps}l[Nl]=t,l=!!(l.nodeValue===a||u!==null&&u.suppressHydrationWarning===!0||F0(l.nodeValue,a)),l||ua(t,!0)}else l=Un(l).createTextNode(u),l[Nl]=t,t.stateNode=l}return yl(t),null;case 31:if(a=t.memoizedState,l===null||l.memoizedState!==null){if(u=fu(t),a!==null){if(l===null){if(!u)throw Error(h(318));if(l=t.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(h(557));l[Nl]=t}else Ra(),(t.flags&128)===0&&(t.memoizedState=null),t.flags|=4;yl(t),l=!1}else a=Yf(),l!==null&&l.memoizedState!==null&&(l.memoizedState.hydrationErrors=a),l=!0;if(!l)return t.flags&256?(ft(t),t):(ft(t),null);if((t.flags&128)!==0)throw Error(h(558))}return yl(t),null;case 13:if(u=t.memoizedState,l===null||l.memoizedState!==null&&l.memoizedState.dehydrated!==null){if(e=fu(t),u!==null&&u.dehydrated!==null){if(l===null){if(!e)throw Error(h(318));if(e=t.memoizedState,e=e!==null?e.dehydrated:null,!e)throw Error(h(317));e[Nl]=t}else Ra(),(t.flags&128)===0&&(t.memoizedState=null),t.flags|=4;yl(t),e=!1}else e=Yf(),l!==null&&l.memoizedState!==null&&(l.memoizedState.hydrationErrors=e),e=!0;if(!e)return t.flags&256?(ft(t),t):(ft(t),null)}return ft(t),(t.flags&128)!==0?(t.lanes=a,t):(a=u!==null,l=l!==null&&l.memoizedState!==null,a&&(u=t.child,e=null,u.alternate!==null&&u.alternate.memoizedState!==null&&u.alternate.memoizedState.cachePool!==null&&(e=u.alternate.memoizedState.cachePool.pool),n=null,u.memoizedState!==null&&u.memoizedState.cachePool!==null&&(n=u.memoizedState.cachePool.pool),n!==e&&(u.flags|=2048)),a!==l&&a&&(t.child.flags|=8192),mn(t,t.updateQueue),yl(t),null);case 4:return zl(),l===null&&$i(t.stateNode.containerInfo),yl(t),null;case 10:return Xt(t.type),yl(t),null;case 19:if(p(pl),u=t.memoizedState,u===null)return yl(t),null;if(e=(t.flags&128)!==0,n=u.rendering,n===null)if(e)ne(u,!1);else{if(gl!==0||l!==null&&(l.flags&128)!==0)for(l=t.child;l!==null;){if(n=ln(l),n!==null){for(t.flags|=128,ne(u,!1),l=n.updateQueue,t.updateQueue=l,mn(t,l),t.subtreeFlags=0,l=a,a=t.child;a!==null;)Us(a,l),a=a.sibling;return _(pl,pl.current&1|2),W&&Yt(t,u.treeForkCount),t.child}l=l.sibling}u.tail!==null&&lt()>bn&&(t.flags|=128,e=!0,ne(u,!1),t.lanes=4194304)}else{if(!e)if(l=ln(n),l!==null){if(t.flags|=128,e=!0,l=l.updateQueue,t.updateQueue=l,mn(t,l),ne(u,!0),u.tail===null&&u.tailMode==="hidden"&&!n.alternate&&!W)return yl(t),null}else 2*lt()-u.renderingStartTime>bn&&a!==536870912&&(t.flags|=128,e=!0,ne(u,!1),t.lanes=4194304);u.isBackwards?(n.sibling=t.child,t.child=n):(l=u.last,l!==null?l.sibling=n:t.child=n,u.last=n)}return u.tail!==null?(l=u.tail,u.rendering=l,u.tail=l.sibling,u.renderingStartTime=lt(),l.sibling=null,a=pl.current,_(pl,e?a&1|2:a&1),W&&Yt(t,u.treeForkCount),l):(yl(t),null);case 22:case 23:return ft(t),Ff(),u=t.memoizedState!==null,l!==null?l.memoizedState!==null!==u&&(t.flags|=8192):u&&(t.flags|=8192),u?(a&536870912)!==0&&(t.flags&128)===0&&(yl(t),t.subtreeFlags&6&&(t.flags|=8192)):yl(t),a=t.updateQueue,a!==null&&mn(t,a.retryQueue),a=null,l!==null&&l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(a=l.memoizedState.cachePool.pool),u=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(u=t.memoizedState.cachePool.pool),u!==a&&(t.flags|=2048),l!==null&&p(Ba),null;case 24:return a=null,l!==null&&(a=l.memoizedState.cache),t.memoizedState.cache!==a&&(t.flags|=2048),Xt(El),yl(t),null;case 25:return null;case 30:return null}throw Error(h(156,t.tag))}function hv(l,t){switch(jf(t),t.tag){case 1:return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 3:return Xt(El),zl(),l=t.flags,(l&65536)!==0&&(l&128)===0?(t.flags=l&-65537|128,t):null;case 26:case 27:case 5:return Ae(t),null;case 31:if(t.memoizedState!==null){if(ft(t),t.alternate===null)throw Error(h(340));Ra()}return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 13:if(ft(t),l=t.memoizedState,l!==null&&l.dehydrated!==null){if(t.alternate===null)throw Error(h(340));Ra()}return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 19:return p(pl),null;case 4:return zl(),null;case 10:return Xt(t.type),null;case 22:case 23:return ft(t),Ff(),l!==null&&p(Ba),l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 24:return Xt(El),null;case 25:return null;default:return null}}function a0(l,t){switch(jf(t),t.tag){case 3:Xt(El),zl();break;case 26:case 27:case 5:Ae(t);break;case 4:zl();break;case 31:t.memoizedState!==null&&ft(t);break;case 13:ft(t);break;case 19:p(pl);break;case 10:Xt(t.type);break;case 22:case 23:ft(t),Ff(),l!==null&&p(Ba);break;case 24:Xt(El)}}function fe(l,t){try{var a=t.updateQueue,u=a!==null?a.lastEffect:null;if(u!==null){var e=u.next;a=e;do{if((a.tag&l)===l){u=void 0;var n=a.create,f=a.inst;u=n(),f.destroy=u}a=a.next}while(a!==e)}}catch(i){ul(t,t.return,i)}}function da(l,t,a){try{var u=t.updateQueue,e=u!==null?u.lastEffect:null;if(e!==null){var n=e.next;u=n;do{if((u.tag&l)===l){var f=u.inst,i=f.destroy;if(i!==void 0){f.destroy=void 0,e=t;var c=a,v=i;try{v()}catch(S){ul(e,c,S)}}}u=u.next}while(u!==n)}}catch(S){ul(t,t.return,S)}}function u0(l){var t=l.updateQueue;if(t!==null){var a=l.stateNode;try{ws(t,a)}catch(u){ul(l,l.return,u)}}}function e0(l,t,a){a.props=Xa(l.type,l.memoizedProps),a.state=l.memoizedState;try{a.componentWillUnmount()}catch(u){ul(l,t,u)}}function ie(l,t){try{var a=l.ref;if(a!==null){switch(l.tag){case 26:case 27:case 5:var u=l.stateNode;break;case 30:u=l.stateNode;break;default:u=l.stateNode}typeof a=="function"?l.refCleanup=a(u):a.current=u}}catch(e){ul(l,t,e)}}function xt(l,t){var a=l.ref,u=l.refCleanup;if(a!==null)if(typeof u=="function")try{u()}catch(e){ul(l,t,e)}finally{l.refCleanup=null,l=l.alternate,l!=null&&(l.refCleanup=null)}else if(typeof a=="function")try{a(null)}catch(e){ul(l,t,e)}else a.current=null}function n0(l){var t=l.type,a=l.memoizedProps,u=l.stateNode;try{l:switch(t){case"button":case"input":case"select":case"textarea":a.autoFocus&&u.focus();break l;case"img":a.src?u.src=a.src:a.srcSet&&(u.srcset=a.srcSet)}}catch(e){ul(l,l.return,e)}}function Ui(l,t,a){try{var u=l.stateNode;qv(u,l.type,a,t),u[Jl]=t}catch(e){ul(l,l.return,e)}}function f0(l){return l.tag===5||l.tag===3||l.tag===26||l.tag===27&&Sa(l.type)||l.tag===4}function xi(l){l:for(;;){for(;l.sibling===null;){if(l.return===null||f0(l.return))return null;l=l.return}for(l.sibling.return=l.return,l=l.sibling;l.tag!==5&&l.tag!==6&&l.tag!==18;){if(l.tag===27&&Sa(l.type)||l.flags&2||l.child===null||l.tag===4)continue l;l.child.return=l,l=l.child}if(!(l.flags&2))return l.stateNode}}function Hi(l,t,a){var u=l.tag;if(u===5||u===6)l=l.stateNode,t?(a.nodeType===9?a.body:a.nodeName==="HTML"?a.ownerDocument.body:a).insertBefore(l,t):(t=a.nodeType===9?a.body:a.nodeName==="HTML"?a.ownerDocument.body:a,t.appendChild(l),a=a._reactRootContainer,a!=null||t.onclick!==null||(t.onclick=Bt));else if(u!==4&&(u===27&&Sa(l.type)&&(a=l.stateNode,t=null),l=l.child,l!==null))for(Hi(l,t,a),l=l.sibling;l!==null;)Hi(l,t,a),l=l.sibling}function hn(l,t,a){var u=l.tag;if(u===5||u===6)l=l.stateNode,t?a.insertBefore(l,t):a.appendChild(l);else if(u!==4&&(u===27&&Sa(l.type)&&(a=l.stateNode),l=l.child,l!==null))for(hn(l,t,a),l=l.sibling;l!==null;)hn(l,t,a),l=l.sibling}function i0(l){var t=l.stateNode,a=l.memoizedProps;try{for(var u=l.type,e=t.attributes;e.length;)t.removeAttributeNode(e[0]);ql(t,u,a),t[Nl]=l,t[Jl]=a}catch(n){ul(l,l.return,n)}}var Kt=!1,Ol=!1,Ri=!1,c0=typeof WeakSet=="function"?WeakSet:Set,Hl=null;function gv(l,t){if(l=l.containerInfo,Pi=jn,l=zs(l),_f(l)){if("selectionStart"in l)var a={start:l.selectionStart,end:l.selectionEnd};else l:{a=(a=l.ownerDocument)&&a.defaultView||window;var u=a.getSelection&&a.getSelection();if(u&&u.rangeCount!==0){a=u.anchorNode;var e=u.anchorOffset,n=u.focusNode;u=u.focusOffset;try{a.nodeType,n.nodeType}catch{a=null;break l}var f=0,i=-1,c=-1,v=0,S=0,z=l,m=null;t:for(;;){for(var g;z!==a||e!==0&&z.nodeType!==3||(i=f+e),z!==n||u!==0&&z.nodeType!==3||(c=f+u),z.nodeType===3&&(f+=z.nodeValue.length),(g=z.firstChild)!==null;)m=z,z=g;for(;;){if(z===l)break t;if(m===a&&++v===e&&(i=f),m===n&&++S===u&&(c=f),(g=z.nextSibling)!==null)break;z=m,m=z.parentNode}z=g}a=i===-1||c===-1?null:{start:i,end:c}}else a=null}a=a||{start:0,end:0}}else a=null;for(lc={focusedElem:l,selectionRange:a},jn=!1,Hl=t;Hl!==null;)if(t=Hl,l=t.child,(t.subtreeFlags&1028)!==0&&l!==null)l.return=t,Hl=l;else for(;Hl!==null;){switch(t=Hl,n=t.alternate,l=t.flags,t.tag){case 0:if((l&4)!==0&&(l=t.updateQueue,l=l!==null?l.events:null,l!==null))for(a=0;a<l.length;a++)e=l[a],e.ref.impl=e.nextImpl;break;case 11:case 15:break;case 1:if((l&1024)!==0&&n!==null){l=void 0,a=t,e=n.memoizedProps,n=n.memoizedState,u=a.stateNode;try{var O=Xa(a.type,e);l=u.getSnapshotBeforeUpdate(O,n),u.__reactInternalSnapshotBeforeUpdate=l}catch(N){ul(a,a.return,N)}}break;case 3:if((l&1024)!==0){if(l=t.stateNode.containerInfo,a=l.nodeType,a===9)uc(l);else if(a===1)switch(l.nodeName){case"HEAD":case"HTML":case"BODY":uc(l);break;default:l.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((l&1024)!==0)throw Error(h(163))}if(l=t.sibling,l!==null){l.return=t.return,Hl=l;break}Hl=t.return}}function s0(l,t,a){var u=a.flags;switch(a.tag){case 0:case 11:case 15:wt(l,a),u&4&&fe(5,a);break;case 1:if(wt(l,a),u&4)if(l=a.stateNode,t===null)try{l.componentDidMount()}catch(f){ul(a,a.return,f)}else{var e=Xa(a.type,t.memoizedProps);t=t.memoizedState;try{l.componentDidUpdate(e,t,l.__reactInternalSnapshotBeforeUpdate)}catch(f){ul(a,a.return,f)}}u&64&&u0(a),u&512&&ie(a,a.return);break;case 3:if(wt(l,a),u&64&&(l=a.updateQueue,l!==null)){if(t=null,a.child!==null)switch(a.child.tag){case 27:case 5:t=a.child.stateNode;break;case 1:t=a.child.stateNode}try{ws(l,t)}catch(f){ul(a,a.return,f)}}break;case 27:t===null&&u&4&&i0(a);case 26:case 5:wt(l,a),t===null&&u&4&&n0(a),u&512&&ie(a,a.return);break;case 12:wt(l,a);break;case 31:wt(l,a),u&4&&y0(l,a);break;case 13:wt(l,a),u&4&&v0(l,a),u&64&&(l=a.memoizedState,l!==null&&(l=l.dehydrated,l!==null&&(a=_v.bind(null,a),Kv(l,a))));break;case 22:if(u=a.memoizedState!==null||Kt,!u){t=t!==null&&t.memoizedState!==null||Ol,e=Kt;var n=Ol;Kt=u,(Ol=t)&&!n?Wt(l,a,(a.subtreeFlags&8772)!==0):wt(l,a),Kt=e,Ol=n}break;case 30:break;default:wt(l,a)}}function d0(l){var t=l.alternate;t!==null&&(l.alternate=null,d0(t)),l.child=null,l.deletions=null,l.sibling=null,l.tag===5&&(t=l.stateNode,t!==null&&cf(t)),l.stateNode=null,l.return=null,l.dependencies=null,l.memoizedProps=null,l.memoizedState=null,l.pendingProps=null,l.stateNode=null,l.updateQueue=null}var ml=null,Wl=!1;function Jt(l,t,a){for(a=a.child;a!==null;)o0(l,t,a),a=a.sibling}function o0(l,t,a){if(tt&&typeof tt.onCommitFiberUnmount=="function")try{tt.onCommitFiberUnmount(Hu,a)}catch{}switch(a.tag){case 26:Ol||xt(a,t),Jt(l,t,a),a.memoizedState?a.memoizedState.count--:a.stateNode&&(a=a.stateNode,a.parentNode.removeChild(a));break;case 27:Ol||xt(a,t);var u=ml,e=Wl;Sa(a.type)&&(ml=a.stateNode,Wl=!1),Jt(l,t,a),ge(a.stateNode),ml=u,Wl=e;break;case 5:Ol||xt(a,t);case 6:if(u=ml,e=Wl,ml=null,Jt(l,t,a),ml=u,Wl=e,ml!==null)if(Wl)try{(ml.nodeType===9?ml.body:ml.nodeName==="HTML"?ml.ownerDocument.body:ml).removeChild(a.stateNode)}catch(n){ul(a,t,n)}else try{ml.removeChild(a.stateNode)}catch(n){ul(a,t,n)}break;case 18:ml!==null&&(Wl?(l=ml,uo(l.nodeType===9?l.body:l.nodeName==="HTML"?l.ownerDocument.body:l,a.stateNode),Mu(l)):uo(ml,a.stateNode));break;case 4:u=ml,e=Wl,ml=a.stateNode.containerInfo,Wl=!0,Jt(l,t,a),ml=u,Wl=e;break;case 0:case 11:case 14:case 15:da(2,a,t),Ol||da(4,a,t),Jt(l,t,a);break;case 1:Ol||(xt(a,t),u=a.stateNode,typeof u.componentWillUnmount=="function"&&e0(a,t,u)),Jt(l,t,a);break;case 21:Jt(l,t,a);break;case 22:Ol=(u=Ol)||a.memoizedState!==null,Jt(l,t,a),Ol=u;break;default:Jt(l,t,a)}}function y0(l,t){if(t.memoizedState===null&&(l=t.alternate,l!==null&&(l=l.memoizedState,l!==null))){l=l.dehydrated;try{Mu(l)}catch(a){ul(t,t.return,a)}}}function v0(l,t){if(t.memoizedState===null&&(l=t.alternate,l!==null&&(l=l.memoizedState,l!==null&&(l=l.dehydrated,l!==null))))try{Mu(l)}catch(a){ul(t,t.return,a)}}function Sv(l){switch(l.tag){case 31:case 13:case 19:var t=l.stateNode;return t===null&&(t=l.stateNode=new c0),t;case 22:return l=l.stateNode,t=l._retryCache,t===null&&(t=l._retryCache=new c0),t;default:throw Error(h(435,l.tag))}}function gn(l,t){var a=Sv(l);t.forEach(function(u){if(!a.has(u)){a.add(u);var e=Ov.bind(null,l,u);u.then(e,e)}})}function kl(l,t){var a=t.deletions;if(a!==null)for(var u=0;u<a.length;u++){var e=a[u],n=l,f=t,i=f;l:for(;i!==null;){switch(i.tag){case 27:if(Sa(i.type)){ml=i.stateNode,Wl=!1;break l}break;case 5:ml=i.stateNode,Wl=!1;break l;case 3:case 4:ml=i.stateNode.containerInfo,Wl=!0;break l}i=i.return}if(ml===null)throw Error(h(160));o0(n,f,e),ml=null,Wl=!1,n=e.alternate,n!==null&&(n.return=null),e.return=null}if(t.subtreeFlags&13886)for(t=t.child;t!==null;)m0(t,l),t=t.sibling}var Et=null;function m0(l,t){var a=l.alternate,u=l.flags;switch(l.tag){case 0:case 11:case 14:case 15:kl(t,l),$l(l),u&4&&(da(3,l,l.return),fe(3,l),da(5,l,l.return));break;case 1:kl(t,l),$l(l),u&512&&(Ol||a===null||xt(a,a.return)),u&64&&Kt&&(l=l.updateQueue,l!==null&&(u=l.callbacks,u!==null&&(a=l.shared.hiddenCallbacks,l.shared.hiddenCallbacks=a===null?u:a.concat(u))));break;case 26:var e=Et;if(kl(t,l),$l(l),u&512&&(Ol||a===null||xt(a,a.return)),u&4){var n=a!==null?a.memoizedState:null;if(u=l.memoizedState,a===null)if(u===null)if(l.stateNode===null){l:{u=l.type,a=l.memoizedProps,e=e.ownerDocument||e;t:switch(u){case"title":n=e.getElementsByTagName("title")[0],(!n||n[Cu]||n[Nl]||n.namespaceURI==="http://www.w3.org/2000/svg"||n.hasAttribute("itemprop"))&&(n=e.createElement(u),e.head.insertBefore(n,e.querySelector("head > title"))),ql(n,u,a),n[Nl]=l,xl(n),u=n;break l;case"link":var f=ho("link","href",e).get(u+(a.href||""));if(f){for(var i=0;i<f.length;i++)if(n=f[i],n.getAttribute("href")===(a.href==null||a.href===""?null:a.href)&&n.getAttribute("rel")===(a.rel==null?null:a.rel)&&n.getAttribute("title")===(a.title==null?null:a.title)&&n.getAttribute("crossorigin")===(a.crossOrigin==null?null:a.crossOrigin)){f.splice(i,1);break t}}n=e.createElement(u),ql(n,u,a),e.head.appendChild(n);break;case"meta":if(f=ho("meta","content",e).get(u+(a.content||""))){for(i=0;i<f.length;i++)if(n=f[i],n.getAttribute("content")===(a.content==null?null:""+a.content)&&n.getAttribute("name")===(a.name==null?null:a.name)&&n.getAttribute("property")===(a.property==null?null:a.property)&&n.getAttribute("http-equiv")===(a.httpEquiv==null?null:a.httpEquiv)&&n.getAttribute("charset")===(a.charSet==null?null:a.charSet)){f.splice(i,1);break t}}n=e.createElement(u),ql(n,u,a),e.head.appendChild(n);break;default:throw Error(h(468,u))}n[Nl]=l,xl(n),u=n}l.stateNode=u}else go(e,l.type,l.stateNode);else l.stateNode=mo(e,u,l.memoizedProps);else n!==u?(n===null?a.stateNode!==null&&(a=a.stateNode,a.parentNode.removeChild(a)):n.count--,u===null?go(e,l.type,l.stateNode):mo(e,u,l.memoizedProps)):u===null&&l.stateNode!==null&&Ui(l,l.memoizedProps,a.memoizedProps)}break;case 27:kl(t,l),$l(l),u&512&&(Ol||a===null||xt(a,a.return)),a!==null&&u&4&&Ui(l,l.memoizedProps,a.memoizedProps);break;case 5:if(kl(t,l),$l(l),u&512&&(Ol||a===null||xt(a,a.return)),l.flags&32){e=l.stateNode;try{$a(e,"")}catch(O){ul(l,l.return,O)}}u&4&&l.stateNode!=null&&(e=l.memoizedProps,Ui(l,e,a!==null?a.memoizedProps:e)),u&1024&&(Ri=!0);break;case 6:if(kl(t,l),$l(l),u&4){if(l.stateNode===null)throw Error(h(162));u=l.memoizedProps,a=l.stateNode;try{a.nodeValue=u}catch(O){ul(l,l.return,O)}}break;case 3:if(Rn=null,e=Et,Et=xn(t.containerInfo),kl(t,l),Et=e,$l(l),u&4&&a!==null&&a.memoizedState.isDehydrated)try{Mu(t.containerInfo)}catch(O){ul(l,l.return,O)}Ri&&(Ri=!1,h0(l));break;case 4:u=Et,Et=xn(l.stateNode.containerInfo),kl(t,l),$l(l),Et=u;break;case 12:kl(t,l),$l(l);break;case 31:kl(t,l),$l(l),u&4&&(u=l.updateQueue,u!==null&&(l.updateQueue=null,gn(l,u)));break;case 13:kl(t,l),$l(l),l.child.flags&8192&&l.memoizedState!==null!=(a!==null&&a.memoizedState!==null)&&(rn=lt()),u&4&&(u=l.updateQueue,u!==null&&(l.updateQueue=null,gn(l,u)));break;case 22:e=l.memoizedState!==null;var c=a!==null&&a.memoizedState!==null,v=Kt,S=Ol;if(Kt=v||e,Ol=S||c,kl(t,l),Ol=S,Kt=v,$l(l),u&8192)l:for(t=l.stateNode,t._visibility=e?t._visibility&-2:t._visibility|1,e&&(a===null||c||Kt||Ol||Qa(l)),a=null,t=l;;){if(t.tag===5||t.tag===26){if(a===null){c=a=t;try{if(n=c.stateNode,e)f=n.style,typeof f.setProperty=="function"?f.setProperty("display","none","important"):f.display="none";else{i=c.stateNode;var z=c.memoizedProps.style,m=z!=null&&z.hasOwnProperty("display")?z.display:null;i.style.display=m==null||typeof m=="boolean"?"":(""+m).trim()}}catch(O){ul(c,c.return,O)}}}else if(t.tag===6){if(a===null){c=t;try{c.stateNode.nodeValue=e?"":c.memoizedProps}catch(O){ul(c,c.return,O)}}}else if(t.tag===18){if(a===null){c=t;try{var g=c.stateNode;e?eo(g,!0):eo(c.stateNode,!1)}catch(O){ul(c,c.return,O)}}}else if((t.tag!==22&&t.tag!==23||t.memoizedState===null||t===l)&&t.child!==null){t.child.return=t,t=t.child;continue}if(t===l)break l;for(;t.sibling===null;){if(t.return===null||t.return===l)break l;a===t&&(a=null),t=t.return}a===t&&(a=null),t.sibling.return=t.return,t=t.sibling}u&4&&(u=l.updateQueue,u!==null&&(a=u.retryQueue,a!==null&&(u.retryQueue=null,gn(l,a))));break;case 19:kl(t,l),$l(l),u&4&&(u=l.updateQueue,u!==null&&(l.updateQueue=null,gn(l,u)));break;case 30:break;case 21:break;default:kl(t,l),$l(l)}}function $l(l){var t=l.flags;if(t&2){try{for(var a,u=l.return;u!==null;){if(f0(u)){a=u;break}u=u.return}if(a==null)throw Error(h(160));switch(a.tag){case 27:var e=a.stateNode,n=xi(l);hn(l,n,e);break;case 5:var f=a.stateNode;a.flags&32&&($a(f,""),a.flags&=-33);var i=xi(l);hn(l,i,f);break;case 3:case 4:var c=a.stateNode.containerInfo,v=xi(l);Hi(l,v,c);break;default:throw Error(h(161))}}catch(S){ul(l,l.return,S)}l.flags&=-3}t&4096&&(l.flags&=-4097)}function h0(l){if(l.subtreeFlags&1024)for(l=l.child;l!==null;){var t=l;h0(t),t.tag===5&&t.flags&1024&&t.stateNode.reset(),l=l.sibling}}function wt(l,t){if(t.subtreeFlags&8772)for(t=t.child;t!==null;)s0(l,t.alternate,t),t=t.sibling}function Qa(l){for(l=l.child;l!==null;){var t=l;switch(t.tag){case 0:case 11:case 14:case 15:da(4,t,t.return),Qa(t);break;case 1:xt(t,t.return);var a=t.stateNode;typeof a.componentWillUnmount=="function"&&e0(t,t.return,a),Qa(t);break;case 27:ge(t.stateNode);case 26:case 5:xt(t,t.return),Qa(t);break;case 22:t.memoizedState===null&&Qa(t);break;case 30:Qa(t);break;default:Qa(t)}l=l.sibling}}function Wt(l,t,a){for(a=a&&(t.subtreeFlags&8772)!==0,t=t.child;t!==null;){var u=t.alternate,e=l,n=t,f=n.flags;switch(n.tag){case 0:case 11:case 15:Wt(e,n,a),fe(4,n);break;case 1:if(Wt(e,n,a),u=n,e=u.stateNode,typeof e.componentDidMount=="function")try{e.componentDidMount()}catch(v){ul(u,u.return,v)}if(u=n,e=u.updateQueue,e!==null){var i=u.stateNode;try{var c=e.shared.hiddenCallbacks;if(c!==null)for(e.shared.hiddenCallbacks=null,e=0;e<c.length;e++)Js(c[e],i)}catch(v){ul(u,u.return,v)}}a&&f&64&&u0(n),ie(n,n.return);break;case 27:i0(n);case 26:case 5:Wt(e,n,a),a&&u===null&&f&4&&n0(n),ie(n,n.return);break;case 12:Wt(e,n,a);break;case 31:Wt(e,n,a),a&&f&4&&y0(e,n);break;case 13:Wt(e,n,a),a&&f&4&&v0(e,n);break;case 22:n.memoizedState===null&&Wt(e,n,a),ie(n,n.return);break;case 30:break;default:Wt(e,n,a)}t=t.sibling}}function Ni(l,t){var a=null;l!==null&&l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(a=l.memoizedState.cachePool.pool),l=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(l=t.memoizedState.cachePool.pool),l!==a&&(l!=null&&l.refCount++,a!=null&&wu(a))}function Ci(l,t){l=null,t.alternate!==null&&(l=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==l&&(t.refCount++,l!=null&&wu(l))}function At(l,t,a,u){if(t.subtreeFlags&10256)for(t=t.child;t!==null;)g0(l,t,a,u),t=t.sibling}function g0(l,t,a,u){var e=t.flags;switch(t.tag){case 0:case 11:case 15:At(l,t,a,u),e&2048&&fe(9,t);break;case 1:At(l,t,a,u);break;case 3:At(l,t,a,u),e&2048&&(l=null,t.alternate!==null&&(l=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==l&&(t.refCount++,l!=null&&wu(l)));break;case 12:if(e&2048){At(l,t,a,u),l=t.stateNode;try{var n=t.memoizedProps,f=n.id,i=n.onPostCommit;typeof i=="function"&&i(f,t.alternate===null?"mount":"update",l.passiveEffectDuration,-0)}catch(c){ul(t,t.return,c)}}else At(l,t,a,u);break;case 31:At(l,t,a,u);break;case 13:At(l,t,a,u);break;case 23:break;case 22:n=t.stateNode,f=t.alternate,t.memoizedState!==null?n._visibility&2?At(l,t,a,u):ce(l,t):n._visibility&2?At(l,t,a,u):(n._visibility|=2,gu(l,t,a,u,(t.subtreeFlags&10256)!==0||!1)),e&2048&&Ni(f,t);break;case 24:At(l,t,a,u),e&2048&&Ci(t.alternate,t);break;default:At(l,t,a,u)}}function gu(l,t,a,u,e){for(e=e&&((t.subtreeFlags&10256)!==0||!1),t=t.child;t!==null;){var n=l,f=t,i=a,c=u,v=f.flags;switch(f.tag){case 0:case 11:case 15:gu(n,f,i,c,e),fe(8,f);break;case 23:break;case 22:var S=f.stateNode;f.memoizedState!==null?S._visibility&2?gu(n,f,i,c,e):ce(n,f):(S._visibility|=2,gu(n,f,i,c,e)),e&&v&2048&&Ni(f.alternate,f);break;case 24:gu(n,f,i,c,e),e&&v&2048&&Ci(f.alternate,f);break;default:gu(n,f,i,c,e)}t=t.sibling}}function ce(l,t){if(t.subtreeFlags&10256)for(t=t.child;t!==null;){var a=l,u=t,e=u.flags;switch(u.tag){case 22:ce(a,u),e&2048&&Ni(u.alternate,u);break;case 24:ce(a,u),e&2048&&Ci(u.alternate,u);break;default:ce(a,u)}t=t.sibling}}var se=8192;function Su(l,t,a){if(l.subtreeFlags&se)for(l=l.child;l!==null;)S0(l,t,a),l=l.sibling}function S0(l,t,a){switch(l.tag){case 26:Su(l,t,a),l.flags&se&&l.memoizedState!==null&&um(a,Et,l.memoizedState,l.memoizedProps);break;case 5:Su(l,t,a);break;case 3:case 4:var u=Et;Et=xn(l.stateNode.containerInfo),Su(l,t,a),Et=u;break;case 22:l.memoizedState===null&&(u=l.alternate,u!==null&&u.memoizedState!==null?(u=se,se=16777216,Su(l,t,a),se=u):Su(l,t,a));break;default:Su(l,t,a)}}function r0(l){var t=l.alternate;if(t!==null&&(l=t.child,l!==null)){t.child=null;do t=l.sibling,l.sibling=null,l=t;while(l!==null)}}function de(l){var t=l.deletions;if((l.flags&16)!==0){if(t!==null)for(var a=0;a<t.length;a++){var u=t[a];Hl=u,z0(u,l)}r0(l)}if(l.subtreeFlags&10256)for(l=l.child;l!==null;)b0(l),l=l.sibling}function b0(l){switch(l.tag){case 0:case 11:case 15:de(l),l.flags&2048&&da(9,l,l.return);break;case 3:de(l);break;case 12:de(l);break;case 22:var t=l.stateNode;l.memoizedState!==null&&t._visibility&2&&(l.return===null||l.return.tag!==13)?(t._visibility&=-3,Sn(l)):de(l);break;default:de(l)}}function Sn(l){var t=l.deletions;if((l.flags&16)!==0){if(t!==null)for(var a=0;a<t.length;a++){var u=t[a];Hl=u,z0(u,l)}r0(l)}for(l=l.child;l!==null;){switch(t=l,t.tag){case 0:case 11:case 15:da(8,t,t.return),Sn(t);break;case 22:a=t.stateNode,a._visibility&2&&(a._visibility&=-3,Sn(t));break;default:Sn(t)}l=l.sibling}}function z0(l,t){for(;Hl!==null;){var a=Hl;switch(a.tag){case 0:case 11:case 15:da(8,a,t);break;case 23:case 22:if(a.memoizedState!==null&&a.memoizedState.cachePool!==null){var u=a.memoizedState.cachePool.pool;u!=null&&u.refCount++}break;case 24:wu(a.memoizedState.cache)}if(u=a.child,u!==null)u.return=a,Hl=u;else l:for(a=l;Hl!==null;){u=Hl;var e=u.sibling,n=u.return;if(d0(u),u===a){Hl=null;break l}if(e!==null){e.return=n,Hl=e;break l}Hl=n}}}var rv={getCacheForType:function(l){var t=Bl(El),a=t.data.get(l);return a===void 0&&(a=l(),t.data.set(l,a)),a},cacheSignal:function(){return Bl(El).controller.signal}},bv=typeof WeakMap=="function"?WeakMap:Map,ll=0,dl=null,Z=null,K=0,al=0,it=null,oa=!1,ru=!1,Bi=!1,kt=0,gl=0,ya=0,Za=0,ji=0,ct=0,bu=0,oe=null,Fl=null,qi=!1,rn=0,p0=0,bn=1/0,zn=null,va=null,Ml=0,ma=null,zu=null,$t=0,Yi=0,Gi=null,T0=null,ye=0,Xi=null;function st(){return(ll&2)!==0&&K!==0?K&-K:r.T!==null?Ji():Yc()}function E0(){if(ct===0)if((K&536870912)===0||W){var l=Me;Me<<=1,(Me&3932160)===0&&(Me=262144),ct=l}else ct=536870912;return l=nt.current,l!==null&&(l.flags|=32),ct}function Il(l,t,a){(l===dl&&(al===2||al===9)||l.cancelPendingCommit!==null)&&(pu(l,0),ha(l,K,ct,!1)),Nu(l,a),((ll&2)===0||l!==dl)&&(l===dl&&((ll&2)===0&&(Za|=a),gl===4&&ha(l,K,ct,!1)),Ht(l))}function A0(l,t,a){if((ll&6)!==0)throw Error(h(327));var u=!a&&(t&127)===0&&(t&l.expiredLanes)===0||Ru(l,t),e=u?Tv(l,t):Zi(l,t,!0),n=u;do{if(e===0){ru&&!u&&ha(l,t,0,!1);break}else{if(a=l.current.alternate,n&&!zv(a)){e=Zi(l,t,!1),n=!1;continue}if(e===2){if(n=t,l.errorRecoveryDisabledLanes&n)var f=0;else f=l.pendingLanes&-536870913,f=f!==0?f:f&536870912?536870912:0;if(f!==0){t=f;l:{var i=l;e=oe;var c=i.current.memoizedState.isDehydrated;if(c&&(pu(i,f).flags|=256),f=Zi(i,f,!1),f!==2){if(Bi&&!c){i.errorRecoveryDisabledLanes|=n,Za|=n,e=4;break l}n=Fl,Fl=e,n!==null&&(Fl===null?Fl=n:Fl.push.apply(Fl,n))}e=f}if(n=!1,e!==2)continue}}if(e===1){pu(l,0),ha(l,t,0,!0);break}l:{switch(u=l,n=e,n){case 0:case 1:throw Error(h(345));case 4:if((t&4194048)!==t)break;case 6:ha(u,t,ct,!oa);break l;case 2:Fl=null;break;case 3:case 5:break;default:throw Error(h(329))}if((t&62914560)===t&&(e=rn+300-lt(),10<e)){if(ha(u,t,ct,!oa),Ue(u,0,!0)!==0)break l;$t=t,u.timeoutHandle=to(_0.bind(null,u,a,Fl,zn,qi,t,ct,Za,bu,oa,n,"Throttled",-0,0),e);break l}_0(u,a,Fl,zn,qi,t,ct,Za,bu,oa,n,null,-0,0)}}break}while(!0);Ht(l)}function _0(l,t,a,u,e,n,f,i,c,v,S,z,m,g){if(l.timeoutHandle=-1,z=t.subtreeFlags,z&8192||(z&16785408)===16785408){z={stylesheets:null,count:0,imgCount:0,imgBytes:0,suspenseyImages:[],waitingForImages:!0,waitingForViewTransition:!1,unsuspend:Bt},S0(t,n,z);var O=(n&62914560)===n?rn-lt():(n&4194048)===n?p0-lt():0;if(O=em(z,O),O!==null){$t=n,l.cancelPendingCommit=O(N0.bind(null,l,t,n,a,u,e,f,i,c,S,z,null,m,g)),ha(l,n,f,!v);return}}N0(l,t,n,a,u,e,f,i,c)}function zv(l){for(var t=l;;){var a=t.tag;if((a===0||a===11||a===15)&&t.flags&16384&&(a=t.updateQueue,a!==null&&(a=a.stores,a!==null)))for(var u=0;u<a.length;u++){var e=a[u],n=e.getSnapshot;e=e.value;try{if(!ut(n(),e))return!1}catch{return!1}}if(a=t.child,t.subtreeFlags&16384&&a!==null)a.return=t,t=a;else{if(t===l)break;for(;t.sibling===null;){if(t.return===null||t.return===l)return!0;t=t.return}t.sibling.return=t.return,t=t.sibling}}return!0}function ha(l,t,a,u){t&=~ji,t&=~Za,l.suspendedLanes|=t,l.pingedLanes&=~t,u&&(l.warmLanes|=t),u=l.expirationTimes;for(var e=t;0<e;){var n=31-at(e),f=1<<n;u[n]=-1,e&=~f}a!==0&&Bc(l,a,t)}function pn(){return(ll&6)===0?(ve(0),!1):!0}function Qi(){if(Z!==null){if(al===0)var l=Z.return;else l=Z,Gt=Na=null,ui(l),ou=null,ku=0,l=Z;for(;l!==null;)a0(l.alternate,l),l=l.return;Z=null}}function pu(l,t){var a=l.timeoutHandle;a!==-1&&(l.timeoutHandle=-1,Xv(a)),a=l.cancelPendingCommit,a!==null&&(l.cancelPendingCommit=null,a()),$t=0,Qi(),dl=l,Z=a=qt(l.current,null),K=t,al=0,it=null,oa=!1,ru=Ru(l,t),Bi=!1,bu=ct=ji=Za=ya=gl=0,Fl=oe=null,qi=!1,(t&8)!==0&&(t|=t&32);var u=l.entangledLanes;if(u!==0)for(l=l.entanglements,u&=t;0<u;){var e=31-at(u),n=1<<e;t|=l[e],u&=~n}return kt=t,Qe(),a}function O0(l,t){Y=null,r.H=ue,t===du||t===ke?(t=Zs(),al=3):t===Kf?(t=Zs(),al=4):al=t===bi?8:t!==null&&typeof t=="object"&&typeof t.then=="function"?6:1,it=t,Z===null&&(gl=1,dn(l,mt(t,l.current)))}function M0(){var l=nt.current;return l===null?!0:(K&4194048)===K?rt===null:(K&62914560)===K||(K&536870912)!==0?l===rt:!1}function D0(){var l=r.H;return r.H=ue,l===null?ue:l}function U0(){var l=r.A;return r.A=rv,l}function Tn(){gl=4,oa||(K&4194048)!==K&&nt.current!==null||(ru=!0),(ya&134217727)===0&&(Za&134217727)===0||dl===null||ha(dl,K,ct,!1)}function Zi(l,t,a){var u=ll;ll|=2;var e=D0(),n=U0();(dl!==l||K!==t)&&(zn=null,pu(l,t)),t=!1;var f=gl;l:do try{if(al!==0&&Z!==null){var i=Z,c=it;switch(al){case 8:Qi(),f=6;break l;case 3:case 2:case 9:case 6:nt.current===null&&(t=!0);var v=al;if(al=0,it=null,Tu(l,i,c,v),a&&ru){f=0;break l}break;default:v=al,al=0,it=null,Tu(l,i,c,v)}}pv(),f=gl;break}catch(S){O0(l,S)}while(!0);return t&&l.shellSuspendCounter++,Gt=Na=null,ll=u,r.H=e,r.A=n,Z===null&&(dl=null,K=0,Qe()),f}function pv(){for(;Z!==null;)x0(Z)}function Tv(l,t){var a=ll;ll|=2;var u=D0(),e=U0();dl!==l||K!==t?(zn=null,bn=lt()+500,pu(l,t)):ru=Ru(l,t);l:do try{if(al!==0&&Z!==null){t=Z;var n=it;t:switch(al){case 1:al=0,it=null,Tu(l,t,n,1);break;case 2:case 9:if(Xs(n)){al=0,it=null,H0(t);break}t=function(){al!==2&&al!==9||dl!==l||(al=7),Ht(l)},n.then(t,t);break l;case 3:al=7;break l;case 4:al=5;break l;case 7:Xs(n)?(al=0,it=null,H0(t)):(al=0,it=null,Tu(l,t,n,7));break;case 5:var f=null;switch(Z.tag){case 26:f=Z.memoizedState;case 5:case 27:var i=Z;if(f?So(f):i.stateNode.complete){al=0,it=null;var c=i.sibling;if(c!==null)Z=c;else{var v=i.return;v!==null?(Z=v,En(v)):Z=null}break t}}al=0,it=null,Tu(l,t,n,5);break;case 6:al=0,it=null,Tu(l,t,n,6);break;case 8:Qi(),gl=6;break l;default:throw Error(h(462))}}Ev();break}catch(S){O0(l,S)}while(!0);return Gt=Na=null,r.H=u,r.A=e,ll=a,Z!==null?0:(dl=null,K=0,Qe(),gl)}function Ev(){for(;Z!==null&&!Jo();)x0(Z)}function x0(l){var t=l0(l.alternate,l,kt);l.memoizedProps=l.pendingProps,t===null?En(l):Z=t}function H0(l){var t=l,a=t.alternate;switch(t.tag){case 15:case 0:t=Wd(a,t,t.pendingProps,t.type,void 0,K);break;case 11:t=Wd(a,t,t.pendingProps,t.type.render,t.ref,K);break;case 5:ui(t);default:a0(a,t),t=Z=Us(t,kt),t=l0(a,t,kt)}l.memoizedProps=l.pendingProps,t===null?En(l):Z=t}function Tu(l,t,a,u){Gt=Na=null,ui(t),ou=null,ku=0;var e=t.return;try{if(ov(l,e,t,a,K)){gl=1,dn(l,mt(a,l.current)),Z=null;return}}catch(n){if(e!==null)throw Z=e,n;gl=1,dn(l,mt(a,l.current)),Z=null;return}t.flags&32768?(W||u===1?l=!0:ru||(K&536870912)!==0?l=!1:(oa=l=!0,(u===2||u===9||u===3||u===6)&&(u=nt.current,u!==null&&u.tag===13&&(u.flags|=16384))),R0(t,l)):En(t)}function En(l){var t=l;do{if((t.flags&32768)!==0){R0(t,oa);return}l=t.return;var a=mv(t.alternate,t,kt);if(a!==null){Z=a;return}if(t=t.sibling,t!==null){Z=t;return}Z=t=l}while(t!==null);gl===0&&(gl=5)}function R0(l,t){do{var a=hv(l.alternate,l);if(a!==null){a.flags&=32767,Z=a;return}if(a=l.return,a!==null&&(a.flags|=32768,a.subtreeFlags=0,a.deletions=null),!t&&(l=l.sibling,l!==null)){Z=l;return}Z=l=a}while(l!==null);gl=6,Z=null}function N0(l,t,a,u,e,n,f,i,c){l.cancelPendingCommit=null;do An();while(Ml!==0);if((ll&6)!==0)throw Error(h(327));if(t!==null){if(t===l.current)throw Error(h(177));if(n=t.lanes|t.childLanes,n|=xf,ay(l,a,n,f,i,c),l===dl&&(Z=dl=null,K=0),zu=t,ma=l,$t=a,Yi=n,Gi=e,T0=u,(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?(l.callbackNode=null,l.callbackPriority=0,Mv(_e,function(){return Y0(),null})):(l.callbackNode=null,l.callbackPriority=0),u=(t.flags&13878)!==0,(t.subtreeFlags&13878)!==0||u){u=r.T,r.T=null,e=A.p,A.p=2,f=ll,ll|=4;try{gv(l,t,a)}finally{ll=f,A.p=e,r.T=u}}Ml=1,C0(),B0(),j0()}}function C0(){if(Ml===1){Ml=0;var l=ma,t=zu,a=(t.flags&13878)!==0;if((t.subtreeFlags&13878)!==0||a){a=r.T,r.T=null;var u=A.p;A.p=2;var e=ll;ll|=4;try{m0(t,l);var n=lc,f=zs(l.containerInfo),i=n.focusedElem,c=n.selectionRange;if(f!==i&&i&&i.ownerDocument&&bs(i.ownerDocument.documentElement,i)){if(c!==null&&_f(i)){var v=c.start,S=c.end;if(S===void 0&&(S=v),"selectionStart"in i)i.selectionStart=v,i.selectionEnd=Math.min(S,i.value.length);else{var z=i.ownerDocument||document,m=z&&z.defaultView||window;if(m.getSelection){var g=m.getSelection(),O=i.textContent.length,N=Math.min(c.start,O),il=c.end===void 0?N:Math.min(c.end,O);!g.extend&&N>il&&(f=il,il=N,N=f);var o=rs(i,N),s=rs(i,il);if(o&&s&&(g.rangeCount!==1||g.anchorNode!==o.node||g.anchorOffset!==o.offset||g.focusNode!==s.node||g.focusOffset!==s.offset)){var y=z.createRange();y.setStart(o.node,o.offset),g.removeAllRanges(),N>il?(g.addRange(y),g.extend(s.node,s.offset)):(y.setEnd(s.node,s.offset),g.addRange(y))}}}}for(z=[],g=i;g=g.parentNode;)g.nodeType===1&&z.push({element:g,left:g.scrollLeft,top:g.scrollTop});for(typeof i.focus=="function"&&i.focus(),i=0;i<z.length;i++){var b=z[i];b.element.scrollLeft=b.left,b.element.scrollTop=b.top}}jn=!!Pi,lc=Pi=null}finally{ll=e,A.p=u,r.T=a}}l.current=t,Ml=2}}function B0(){if(Ml===2){Ml=0;var l=ma,t=zu,a=(t.flags&8772)!==0;if((t.subtreeFlags&8772)!==0||a){a=r.T,r.T=null;var u=A.p;A.p=2;var e=ll;ll|=4;try{s0(l,t.alternate,t)}finally{ll=e,A.p=u,r.T=a}}Ml=3}}function j0(){if(Ml===4||Ml===3){Ml=0,wo();var l=ma,t=zu,a=$t,u=T0;(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?Ml=5:(Ml=0,zu=ma=null,q0(l,l.pendingLanes));var e=l.pendingLanes;if(e===0&&(va=null),nf(a),t=t.stateNode,tt&&typeof tt.onCommitFiberRoot=="function")try{tt.onCommitFiberRoot(Hu,t,void 0,(t.current.flags&128)===128)}catch{}if(u!==null){t=r.T,e=A.p,A.p=2,r.T=null;try{for(var n=l.onRecoverableError,f=0;f<u.length;f++){var i=u[f];n(i.value,{componentStack:i.stack})}}finally{r.T=t,A.p=e}}($t&3)!==0&&An(),Ht(l),e=l.pendingLanes,(a&261930)!==0&&(e&42)!==0?l===Xi?ye++:(ye=0,Xi=l):ye=0,ve(0)}}function q0(l,t){(l.pooledCacheLanes&=t)===0&&(t=l.pooledCache,t!=null&&(l.pooledCache=null,wu(t)))}function An(){return C0(),B0(),j0(),Y0()}function Y0(){if(Ml!==5)return!1;var l=ma,t=Yi;Yi=0;var a=nf($t),u=r.T,e=A.p;try{A.p=32>a?32:a,r.T=null,a=Gi,Gi=null;var n=ma,f=$t;if(Ml=0,zu=ma=null,$t=0,(ll&6)!==0)throw Error(h(331));var i=ll;if(ll|=4,b0(n.current),g0(n,n.current,f,a),ll=i,ve(0,!1),tt&&typeof tt.onPostCommitFiberRoot=="function")try{tt.onPostCommitFiberRoot(Hu,n)}catch{}return!0}finally{A.p=e,r.T=u,q0(l,t)}}function G0(l,t,a){t=mt(a,t),t=ri(l.stateNode,t,2),l=ia(l,t,2),l!==null&&(Nu(l,2),Ht(l))}function ul(l,t,a){if(l.tag===3)G0(l,l,a);else for(;t!==null;){if(t.tag===3){G0(t,l,a);break}else if(t.tag===1){var u=t.stateNode;if(typeof t.type.getDerivedStateFromError=="function"||typeof u.componentDidCatch=="function"&&(va===null||!va.has(u))){l=mt(a,l),a=Xd(2),u=ia(t,a,2),u!==null&&(Qd(a,u,t,l),Nu(u,2),Ht(u));break}}t=t.return}}function Vi(l,t,a){var u=l.pingCache;if(u===null){u=l.pingCache=new bv;var e=new Set;u.set(t,e)}else e=u.get(t),e===void 0&&(e=new Set,u.set(t,e));e.has(a)||(Bi=!0,e.add(a),l=Av.bind(null,l,t,a),t.then(l,l))}function Av(l,t,a){var u=l.pingCache;u!==null&&u.delete(t),l.pingedLanes|=l.suspendedLanes&a,l.warmLanes&=~a,dl===l&&(K&a)===a&&(gl===4||gl===3&&(K&62914560)===K&&300>lt()-rn?(ll&2)===0&&pu(l,0):ji|=a,bu===K&&(bu=0)),Ht(l)}function X0(l,t){t===0&&(t=Cc()),l=xa(l,t),l!==null&&(Nu(l,t),Ht(l))}function _v(l){var t=l.memoizedState,a=0;t!==null&&(a=t.retryLane),X0(l,a)}function Ov(l,t){var a=0;switch(l.tag){case 31:case 13:var u=l.stateNode,e=l.memoizedState;e!==null&&(a=e.retryLane);break;case 19:u=l.stateNode;break;case 22:u=l.stateNode._retryCache;break;default:throw Error(h(314))}u!==null&&u.delete(t),X0(l,a)}function Mv(l,t){return tf(l,t)}var _n=null,Eu=null,Li=!1,On=!1,Ki=!1,ga=0;function Ht(l){l!==Eu&&l.next===null&&(Eu===null?_n=Eu=l:Eu=Eu.next=l),On=!0,Li||(Li=!0,Uv())}function ve(l,t){if(!Ki&&On){Ki=!0;do for(var a=!1,u=_n;u!==null;){if(l!==0){var e=u.pendingLanes;if(e===0)var n=0;else{var f=u.suspendedLanes,i=u.pingedLanes;n=(1<<31-at(42|l)+1)-1,n&=e&~(f&~i),n=n&201326741?n&201326741|1:n?n|2:0}n!==0&&(a=!0,L0(u,n))}else n=K,n=Ue(u,u===dl?n:0,u.cancelPendingCommit!==null||u.timeoutHandle!==-1),(n&3)===0||Ru(u,n)||(a=!0,L0(u,n));u=u.next}while(a);Ki=!1}}function Dv(){Q0()}function Q0(){On=Li=!1;var l=0;ga!==0&&Gv()&&(l=ga);for(var t=lt(),a=null,u=_n;u!==null;){var e=u.next,n=Z0(u,t);n===0?(u.next=null,a===null?_n=e:a.next=e,e===null&&(Eu=a)):(a=u,(l!==0||(n&3)!==0)&&(On=!0)),u=e}Ml!==0&&Ml!==5||ve(l),ga!==0&&(ga=0)}function Z0(l,t){for(var a=l.suspendedLanes,u=l.pingedLanes,e=l.expirationTimes,n=l.pendingLanes&-62914561;0<n;){var f=31-at(n),i=1<<f,c=e[f];c===-1?((i&a)===0||(i&u)!==0)&&(e[f]=ty(i,t)):c<=t&&(l.expiredLanes|=i),n&=~i}if(t=dl,a=K,a=Ue(l,l===t?a:0,l.cancelPendingCommit!==null||l.timeoutHandle!==-1),u=l.callbackNode,a===0||l===t&&(al===2||al===9)||l.cancelPendingCommit!==null)return u!==null&&u!==null&&af(u),l.callbackNode=null,l.callbackPriority=0;if((a&3)===0||Ru(l,a)){if(t=a&-a,t===l.callbackPriority)return t;switch(u!==null&&af(u),nf(a)){case 2:case 8:a=Rc;break;case 32:a=_e;break;case 268435456:a=Nc;break;default:a=_e}return u=V0.bind(null,l),a=tf(a,u),l.callbackPriority=t,l.callbackNode=a,t}return u!==null&&u!==null&&af(u),l.callbackPriority=2,l.callbackNode=null,2}function V0(l,t){if(Ml!==0&&Ml!==5)return l.callbackNode=null,l.callbackPriority=0,null;var a=l.callbackNode;if(An()&&l.callbackNode!==a)return null;var u=K;return u=Ue(l,l===dl?u:0,l.cancelPendingCommit!==null||l.timeoutHandle!==-1),u===0?null:(A0(l,u,t),Z0(l,lt()),l.callbackNode!=null&&l.callbackNode===a?V0.bind(null,l):null)}function L0(l,t){if(An())return null;A0(l,t,!0)}function Uv(){Qv(function(){(ll&6)!==0?tf(Hc,Dv):Q0()})}function Ji(){if(ga===0){var l=cu;l===0&&(l=Oe,Oe<<=1,(Oe&261888)===0&&(Oe=256)),ga=l}return ga}function K0(l){return l==null||typeof l=="symbol"||typeof l=="boolean"?null:typeof l=="function"?l:Ne(""+l)}function J0(l,t){var a=t.ownerDocument.createElement("input");return a.name=t.name,a.value=t.value,l.id&&a.setAttribute("form",l.id),t.parentNode.insertBefore(a,t),l=new FormData(l),a.parentNode.removeChild(a),l}function xv(l,t,a,u,e){if(t==="submit"&&a&&a.stateNode===e){var n=K0((e[Jl]||null).action),f=u.submitter;f&&(t=(t=f[Jl]||null)?K0(t.formAction):f.getAttribute("formAction"),t!==null&&(n=t,f=null));var i=new qe("action","action",null,u,e);l.push({event:i,listeners:[{instance:null,listener:function(){if(u.defaultPrevented){if(ga!==0){var c=f?J0(e,f):new FormData(e);yi(a,{pending:!0,data:c,method:e.method,action:n},null,c)}}else typeof n=="function"&&(i.preventDefault(),c=f?J0(e,f):new FormData(e),yi(a,{pending:!0,data:c,method:e.method,action:n},n,c))},currentTarget:e}]})}}for(var wi=0;wi<Uf.length;wi++){var Wi=Uf[wi],Hv=Wi.toLowerCase(),Rv=Wi[0].toUpperCase()+Wi.slice(1);Tt(Hv,"on"+Rv)}Tt(Es,"onAnimationEnd"),Tt(As,"onAnimationIteration"),Tt(_s,"onAnimationStart"),Tt("dblclick","onDoubleClick"),Tt("focusin","onFocus"),Tt("focusout","onBlur"),Tt(Wy,"onTransitionRun"),Tt(ky,"onTransitionStart"),Tt($y,"onTransitionCancel"),Tt(Os,"onTransitionEnd"),Wa("onMouseEnter",["mouseout","mouseover"]),Wa("onMouseLeave",["mouseout","mouseover"]),Wa("onPointerEnter",["pointerout","pointerover"]),Wa("onPointerLeave",["pointerout","pointerover"]),Oa("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),Oa("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),Oa("onBeforeInput",["compositionend","keypress","textInput","paste"]),Oa("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),Oa("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),Oa("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var me="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),Nv=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(me));function w0(l,t){t=(t&4)!==0;for(var a=0;a<l.length;a++){var u=l[a],e=u.event;u=u.listeners;l:{var n=void 0;if(t)for(var f=u.length-1;0<=f;f--){var i=u[f],c=i.instance,v=i.currentTarget;if(i=i.listener,c!==n&&e.isPropagationStopped())break l;n=i,e.currentTarget=v;try{n(e)}catch(S){Xe(S)}e.currentTarget=null,n=c}else for(f=0;f<u.length;f++){if(i=u[f],c=i.instance,v=i.currentTarget,i=i.listener,c!==n&&e.isPropagationStopped())break l;n=i,e.currentTarget=v;try{n(e)}catch(S){Xe(S)}e.currentTarget=null,n=c}}}}function V(l,t){var a=t[ff];a===void 0&&(a=t[ff]=new Set);var u=l+"__bubble";a.has(u)||(W0(t,l,2,!1),a.add(u))}function ki(l,t,a){var u=0;t&&(u|=4),W0(a,l,u,t)}var Mn="_reactListening"+Math.random().toString(36).slice(2);function $i(l){if(!l[Mn]){l[Mn]=!0,Qc.forEach(function(a){a!=="selectionchange"&&(Nv.has(a)||ki(a,!1,l),ki(a,!0,l))});var t=l.nodeType===9?l:l.ownerDocument;t===null||t[Mn]||(t[Mn]=!0,ki("selectionchange",!1,t))}}function W0(l,t,a,u){switch(Ao(t)){case 2:var e=im;break;case 8:e=cm;break;default:e=oc}a=e.bind(null,t,a,l),e=void 0,!gf||t!=="touchstart"&&t!=="touchmove"&&t!=="wheel"||(e=!0),u?e!==void 0?l.addEventListener(t,a,{capture:!0,passive:e}):l.addEventListener(t,a,!0):e!==void 0?l.addEventListener(t,a,{passive:e}):l.addEventListener(t,a,!1)}function Fi(l,t,a,u,e){var n=u;if((t&1)===0&&(t&2)===0&&u!==null)l:for(;;){if(u===null)return;var f=u.tag;if(f===3||f===4){var i=u.stateNode.containerInfo;if(i===e)break;if(f===4)for(f=u.return;f!==null;){var c=f.tag;if((c===3||c===4)&&f.stateNode.containerInfo===e)return;f=f.return}for(;i!==null;){if(f=Ka(i),f===null)return;if(c=f.tag,c===5||c===6||c===26||c===27){u=n=f;continue l}i=i.parentNode}}u=u.return}Pc(function(){var v=n,S=mf(a),z=[];l:{var m=Ms.get(l);if(m!==void 0){var g=qe,O=l;switch(l){case"keypress":if(Be(a)===0)break l;case"keydown":case"keyup":g=Oy;break;case"focusin":O="focus",g=zf;break;case"focusout":O="blur",g=zf;break;case"beforeblur":case"afterblur":g=zf;break;case"click":if(a.button===2)break l;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":g=as;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":g=my;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":g=Uy;break;case Es:case As:case _s:g=Sy;break;case Os:g=Hy;break;case"scroll":case"scrollend":g=yy;break;case"wheel":g=Ny;break;case"copy":case"cut":case"paste":g=by;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":g=es;break;case"toggle":case"beforetoggle":g=By}var N=(t&4)!==0,il=!N&&(l==="scroll"||l==="scrollend"),o=N?m!==null?m+"Capture":null:m;N=[];for(var s=v,y;s!==null;){var b=s;if(y=b.stateNode,b=b.tag,b!==5&&b!==26&&b!==27||y===null||o===null||(b=ju(s,o),b!=null&&N.push(he(s,b,y))),il)break;s=s.return}0<N.length&&(m=new g(m,O,null,a,S),z.push({event:m,listeners:N}))}}if((t&7)===0){l:{if(m=l==="mouseover"||l==="pointerover",g=l==="mouseout"||l==="pointerout",m&&a!==vf&&(O=a.relatedTarget||a.fromElement)&&(Ka(O)||O[La]))break l;if((g||m)&&(m=S.window===S?S:(m=S.ownerDocument)?m.defaultView||m.parentWindow:window,g?(O=a.relatedTarget||a.toElement,g=v,O=O?Ka(O):null,O!==null&&(il=Sl(O),N=O.tag,O!==il||N!==5&&N!==27&&N!==6)&&(O=null)):(g=null,O=v),g!==O)){if(N=as,b="onMouseLeave",o="onMouseEnter",s="mouse",(l==="pointerout"||l==="pointerover")&&(N=es,b="onPointerLeave",o="onPointerEnter",s="pointer"),il=g==null?m:Bu(g),y=O==null?m:Bu(O),m=new N(b,s+"leave",g,a,S),m.target=il,m.relatedTarget=y,b=null,Ka(S)===v&&(N=new N(o,s+"enter",O,a,S),N.target=y,N.relatedTarget=il,b=N),il=b,g&&O)t:{for(N=Cv,o=g,s=O,y=0,b=o;b;b=N(b))y++;b=0;for(var H=s;H;H=N(H))b++;for(;0<y-b;)o=N(o),y--;for(;0<b-y;)s=N(s),b--;for(;y--;){if(o===s||s!==null&&o===s.alternate){N=o;break t}o=N(o),s=N(s)}N=null}else N=null;g!==null&&k0(z,m,g,N,!1),O!==null&&il!==null&&k0(z,il,O,N,!0)}}l:{if(m=v?Bu(v):window,g=m.nodeName&&m.nodeName.toLowerCase(),g==="select"||g==="input"&&m.type==="file")var I=ys;else if(ds(m))if(vs)I=Ky;else{I=Vy;var D=Zy}else g=m.nodeName,!g||g.toLowerCase()!=="input"||m.type!=="checkbox"&&m.type!=="radio"?v&&yf(v.elementType)&&(I=ys):I=Ly;if(I&&(I=I(l,v))){os(z,I,a,S);break l}D&&D(l,m,v),l==="focusout"&&v&&m.type==="number"&&v.memoizedProps.value!=null&&of(m,"number",m.value)}switch(D=v?Bu(v):window,l){case"focusin":(ds(D)||D.contentEditable==="true")&&(lu=D,Of=v,Lu=null);break;case"focusout":Lu=Of=lu=null;break;case"mousedown":Mf=!0;break;case"contextmenu":case"mouseup":case"dragend":Mf=!1,ps(z,a,S);break;case"selectionchange":if(wy)break;case"keydown":case"keyup":ps(z,a,S)}var G;if(Tf)l:{switch(l){case"compositionstart":var J="onCompositionStart";break l;case"compositionend":J="onCompositionEnd";break l;case"compositionupdate":J="onCompositionUpdate";break l}J=void 0}else Pa?cs(l,a)&&(J="onCompositionEnd"):l==="keydown"&&a.keyCode===229&&(J="onCompositionStart");J&&(ns&&a.locale!=="ko"&&(Pa||J!=="onCompositionStart"?J==="onCompositionEnd"&&Pa&&(G=ls()):(la=S,Sf="value"in la?la.value:la.textContent,Pa=!0)),D=Dn(v,J),0<D.length&&(J=new us(J,l,null,a,S),z.push({event:J,listeners:D}),G?J.data=G:(G=ss(a),G!==null&&(J.data=G)))),(G=qy?Yy(l,a):Gy(l,a))&&(J=Dn(v,"onBeforeInput"),0<J.length&&(D=new us("onBeforeInput","beforeinput",null,a,S),z.push({event:D,listeners:J}),D.data=G)),xv(z,l,v,a,S)}w0(z,t)})}function he(l,t,a){return{instance:l,listener:t,currentTarget:a}}function Dn(l,t){for(var a=t+"Capture",u=[];l!==null;){var e=l,n=e.stateNode;if(e=e.tag,e!==5&&e!==26&&e!==27||n===null||(e=ju(l,a),e!=null&&u.unshift(he(l,e,n)),e=ju(l,t),e!=null&&u.push(he(l,e,n))),l.tag===3)return u;l=l.return}return[]}function Cv(l){if(l===null)return null;do l=l.return;while(l&&l.tag!==5&&l.tag!==27);return l||null}function k0(l,t,a,u,e){for(var n=t._reactName,f=[];a!==null&&a!==u;){var i=a,c=i.alternate,v=i.stateNode;if(i=i.tag,c!==null&&c===u)break;i!==5&&i!==26&&i!==27||v===null||(c=v,e?(v=ju(a,n),v!=null&&f.unshift(he(a,v,c))):e||(v=ju(a,n),v!=null&&f.push(he(a,v,c)))),a=a.return}f.length!==0&&l.push({event:t,listeners:f})}var Bv=/\r\n?/g,jv=/\u0000|\uFFFD/g;function $0(l){return(typeof l=="string"?l:""+l).replace(Bv,`
`).replace(jv,"")}function F0(l,t){return t=$0(t),$0(l)===t}function fl(l,t,a,u,e,n){switch(a){case"children":typeof u=="string"?t==="body"||t==="textarea"&&u===""||$a(l,u):(typeof u=="number"||typeof u=="bigint")&&t!=="body"&&$a(l,""+u);break;case"className":He(l,"class",u);break;case"tabIndex":He(l,"tabindex",u);break;case"dir":case"role":case"viewBox":case"width":case"height":He(l,a,u);break;case"style":Fc(l,u,n);break;case"data":if(t!=="object"){He(l,"data",u);break}case"src":case"href":if(u===""&&(t!=="a"||a!=="href")){l.removeAttribute(a);break}if(u==null||typeof u=="function"||typeof u=="symbol"||typeof u=="boolean"){l.removeAttribute(a);break}u=Ne(""+u),l.setAttribute(a,u);break;case"action":case"formAction":if(typeof u=="function"){l.setAttribute(a,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof n=="function"&&(a==="formAction"?(t!=="input"&&fl(l,t,"name",e.name,e,null),fl(l,t,"formEncType",e.formEncType,e,null),fl(l,t,"formMethod",e.formMethod,e,null),fl(l,t,"formTarget",e.formTarget,e,null)):(fl(l,t,"encType",e.encType,e,null),fl(l,t,"method",e.method,e,null),fl(l,t,"target",e.target,e,null)));if(u==null||typeof u=="symbol"||typeof u=="boolean"){l.removeAttribute(a);break}u=Ne(""+u),l.setAttribute(a,u);break;case"onClick":u!=null&&(l.onclick=Bt);break;case"onScroll":u!=null&&V("scroll",l);break;case"onScrollEnd":u!=null&&V("scrollend",l);break;case"dangerouslySetInnerHTML":if(u!=null){if(typeof u!="object"||!("__html"in u))throw Error(h(61));if(a=u.__html,a!=null){if(e.children!=null)throw Error(h(60));l.innerHTML=a}}break;case"multiple":l.multiple=u&&typeof u!="function"&&typeof u!="symbol";break;case"muted":l.muted=u&&typeof u!="function"&&typeof u!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(u==null||typeof u=="function"||typeof u=="boolean"||typeof u=="symbol"){l.removeAttribute("xlink:href");break}a=Ne(""+u),l.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",a);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":u!=null&&typeof u!="function"&&typeof u!="symbol"?l.setAttribute(a,""+u):l.removeAttribute(a);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":u&&typeof u!="function"&&typeof u!="symbol"?l.setAttribute(a,""):l.removeAttribute(a);break;case"capture":case"download":u===!0?l.setAttribute(a,""):u!==!1&&u!=null&&typeof u!="function"&&typeof u!="symbol"?l.setAttribute(a,u):l.removeAttribute(a);break;case"cols":case"rows":case"size":case"span":u!=null&&typeof u!="function"&&typeof u!="symbol"&&!isNaN(u)&&1<=u?l.setAttribute(a,u):l.removeAttribute(a);break;case"rowSpan":case"start":u==null||typeof u=="function"||typeof u=="symbol"||isNaN(u)?l.removeAttribute(a):l.setAttribute(a,u);break;case"popover":V("beforetoggle",l),V("toggle",l),xe(l,"popover",u);break;case"xlinkActuate":Ct(l,"http://www.w3.org/1999/xlink","xlink:actuate",u);break;case"xlinkArcrole":Ct(l,"http://www.w3.org/1999/xlink","xlink:arcrole",u);break;case"xlinkRole":Ct(l,"http://www.w3.org/1999/xlink","xlink:role",u);break;case"xlinkShow":Ct(l,"http://www.w3.org/1999/xlink","xlink:show",u);break;case"xlinkTitle":Ct(l,"http://www.w3.org/1999/xlink","xlink:title",u);break;case"xlinkType":Ct(l,"http://www.w3.org/1999/xlink","xlink:type",u);break;case"xmlBase":Ct(l,"http://www.w3.org/XML/1998/namespace","xml:base",u);break;case"xmlLang":Ct(l,"http://www.w3.org/XML/1998/namespace","xml:lang",u);break;case"xmlSpace":Ct(l,"http://www.w3.org/XML/1998/namespace","xml:space",u);break;case"is":xe(l,"is",u);break;case"innerText":case"textContent":break;default:(!(2<a.length)||a[0]!=="o"&&a[0]!=="O"||a[1]!=="n"&&a[1]!=="N")&&(a=dy.get(a)||a,xe(l,a,u))}}function Ii(l,t,a,u,e,n){switch(a){case"style":Fc(l,u,n);break;case"dangerouslySetInnerHTML":if(u!=null){if(typeof u!="object"||!("__html"in u))throw Error(h(61));if(a=u.__html,a!=null){if(e.children!=null)throw Error(h(60));l.innerHTML=a}}break;case"children":typeof u=="string"?$a(l,u):(typeof u=="number"||typeof u=="bigint")&&$a(l,""+u);break;case"onScroll":u!=null&&V("scroll",l);break;case"onScrollEnd":u!=null&&V("scrollend",l);break;case"onClick":u!=null&&(l.onclick=Bt);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!Zc.hasOwnProperty(a))l:{if(a[0]==="o"&&a[1]==="n"&&(e=a.endsWith("Capture"),t=a.slice(2,e?a.length-7:void 0),n=l[Jl]||null,n=n!=null?n[a]:null,typeof n=="function"&&l.removeEventListener(t,n,e),typeof u=="function")){typeof n!="function"&&n!==null&&(a in l?l[a]=null:l.hasAttribute(a)&&l.removeAttribute(a)),l.addEventListener(t,u,e);break l}a in l?l[a]=u:u===!0?l.setAttribute(a,""):xe(l,a,u)}}}function ql(l,t,a){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":V("error",l),V("load",l);var u=!1,e=!1,n;for(n in a)if(a.hasOwnProperty(n)){var f=a[n];if(f!=null)switch(n){case"src":u=!0;break;case"srcSet":e=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(h(137,t));default:fl(l,t,n,f,a,null)}}e&&fl(l,t,"srcSet",a.srcSet,a,null),u&&fl(l,t,"src",a.src,a,null);return;case"input":V("invalid",l);var i=n=f=e=null,c=null,v=null;for(u in a)if(a.hasOwnProperty(u)){var S=a[u];if(S!=null)switch(u){case"name":e=S;break;case"type":f=S;break;case"checked":c=S;break;case"defaultChecked":v=S;break;case"value":n=S;break;case"defaultValue":i=S;break;case"children":case"dangerouslySetInnerHTML":if(S!=null)throw Error(h(137,t));break;default:fl(l,t,u,S,a,null)}}wc(l,n,i,c,v,f,e,!1);return;case"select":V("invalid",l),u=f=n=null;for(e in a)if(a.hasOwnProperty(e)&&(i=a[e],i!=null))switch(e){case"value":n=i;break;case"defaultValue":f=i;break;case"multiple":u=i;default:fl(l,t,e,i,a,null)}t=n,a=f,l.multiple=!!u,t!=null?ka(l,!!u,t,!1):a!=null&&ka(l,!!u,a,!0);return;case"textarea":V("invalid",l),n=e=u=null;for(f in a)if(a.hasOwnProperty(f)&&(i=a[f],i!=null))switch(f){case"value":u=i;break;case"defaultValue":e=i;break;case"children":n=i;break;case"dangerouslySetInnerHTML":if(i!=null)throw Error(h(91));break;default:fl(l,t,f,i,a,null)}kc(l,u,e,n);return;case"option":for(c in a)if(a.hasOwnProperty(c)&&(u=a[c],u!=null))switch(c){case"selected":l.selected=u&&typeof u!="function"&&typeof u!="symbol";break;default:fl(l,t,c,u,a,null)}return;case"dialog":V("beforetoggle",l),V("toggle",l),V("cancel",l),V("close",l);break;case"iframe":case"object":V("load",l);break;case"video":case"audio":for(u=0;u<me.length;u++)V(me[u],l);break;case"image":V("error",l),V("load",l);break;case"details":V("toggle",l);break;case"embed":case"source":case"link":V("error",l),V("load",l);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(v in a)if(a.hasOwnProperty(v)&&(u=a[v],u!=null))switch(v){case"children":case"dangerouslySetInnerHTML":throw Error(h(137,t));default:fl(l,t,v,u,a,null)}return;default:if(yf(t)){for(S in a)a.hasOwnProperty(S)&&(u=a[S],u!==void 0&&Ii(l,t,S,u,a,void 0));return}}for(i in a)a.hasOwnProperty(i)&&(u=a[i],u!=null&&fl(l,t,i,u,a,null))}function qv(l,t,a,u){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var e=null,n=null,f=null,i=null,c=null,v=null,S=null;for(g in a){var z=a[g];if(a.hasOwnProperty(g)&&z!=null)switch(g){case"checked":break;case"value":break;case"defaultValue":c=z;default:u.hasOwnProperty(g)||fl(l,t,g,null,u,z)}}for(var m in u){var g=u[m];if(z=a[m],u.hasOwnProperty(m)&&(g!=null||z!=null))switch(m){case"type":n=g;break;case"name":e=g;break;case"checked":v=g;break;case"defaultChecked":S=g;break;case"value":f=g;break;case"defaultValue":i=g;break;case"children":case"dangerouslySetInnerHTML":if(g!=null)throw Error(h(137,t));break;default:g!==z&&fl(l,t,m,g,u,z)}}df(l,f,i,c,v,S,n,e);return;case"select":g=f=i=m=null;for(n in a)if(c=a[n],a.hasOwnProperty(n)&&c!=null)switch(n){case"value":break;case"multiple":g=c;default:u.hasOwnProperty(n)||fl(l,t,n,null,u,c)}for(e in u)if(n=u[e],c=a[e],u.hasOwnProperty(e)&&(n!=null||c!=null))switch(e){case"value":m=n;break;case"defaultValue":i=n;break;case"multiple":f=n;default:n!==c&&fl(l,t,e,n,u,c)}t=i,a=f,u=g,m!=null?ka(l,!!a,m,!1):!!u!=!!a&&(t!=null?ka(l,!!a,t,!0):ka(l,!!a,a?[]:"",!1));return;case"textarea":g=m=null;for(i in a)if(e=a[i],a.hasOwnProperty(i)&&e!=null&&!u.hasOwnProperty(i))switch(i){case"value":break;case"children":break;default:fl(l,t,i,null,u,e)}for(f in u)if(e=u[f],n=a[f],u.hasOwnProperty(f)&&(e!=null||n!=null))switch(f){case"value":m=e;break;case"defaultValue":g=e;break;case"children":break;case"dangerouslySetInnerHTML":if(e!=null)throw Error(h(91));break;default:e!==n&&fl(l,t,f,e,u,n)}Wc(l,m,g);return;case"option":for(var O in a)if(m=a[O],a.hasOwnProperty(O)&&m!=null&&!u.hasOwnProperty(O))switch(O){case"selected":l.selected=!1;break;default:fl(l,t,O,null,u,m)}for(c in u)if(m=u[c],g=a[c],u.hasOwnProperty(c)&&m!==g&&(m!=null||g!=null))switch(c){case"selected":l.selected=m&&typeof m!="function"&&typeof m!="symbol";break;default:fl(l,t,c,m,u,g)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var N in a)m=a[N],a.hasOwnProperty(N)&&m!=null&&!u.hasOwnProperty(N)&&fl(l,t,N,null,u,m);for(v in u)if(m=u[v],g=a[v],u.hasOwnProperty(v)&&m!==g&&(m!=null||g!=null))switch(v){case"children":case"dangerouslySetInnerHTML":if(m!=null)throw Error(h(137,t));break;default:fl(l,t,v,m,u,g)}return;default:if(yf(t)){for(var il in a)m=a[il],a.hasOwnProperty(il)&&m!==void 0&&!u.hasOwnProperty(il)&&Ii(l,t,il,void 0,u,m);for(S in u)m=u[S],g=a[S],!u.hasOwnProperty(S)||m===g||m===void 0&&g===void 0||Ii(l,t,S,m,u,g);return}}for(var o in a)m=a[o],a.hasOwnProperty(o)&&m!=null&&!u.hasOwnProperty(o)&&fl(l,t,o,null,u,m);for(z in u)m=u[z],g=a[z],!u.hasOwnProperty(z)||m===g||m==null&&g==null||fl(l,t,z,m,u,g)}function I0(l){switch(l){case"css":case"script":case"font":case"img":case"image":case"input":case"link":return!0;default:return!1}}function Yv(){if(typeof performance.getEntriesByType=="function"){for(var l=0,t=0,a=performance.getEntriesByType("resource"),u=0;u<a.length;u++){var e=a[u],n=e.transferSize,f=e.initiatorType,i=e.duration;if(n&&i&&I0(f)){for(f=0,i=e.responseEnd,u+=1;u<a.length;u++){var c=a[u],v=c.startTime;if(v>i)break;var S=c.transferSize,z=c.initiatorType;S&&I0(z)&&(c=c.responseEnd,f+=S*(c<i?1:(i-v)/(c-v)))}if(--u,t+=8*(n+f)/(e.duration/1e3),l++,10<l)break}}if(0<l)return t/l/1e6}return navigator.connection&&(l=navigator.connection.downlink,typeof l=="number")?l:5}var Pi=null,lc=null;function Un(l){return l.nodeType===9?l:l.ownerDocument}function P0(l){switch(l){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function lo(l,t){if(l===0)switch(t){case"svg":return 1;case"math":return 2;default:return 0}return l===1&&t==="foreignObject"?0:l}function tc(l,t){return l==="textarea"||l==="noscript"||typeof t.children=="string"||typeof t.children=="number"||typeof t.children=="bigint"||typeof t.dangerouslySetInnerHTML=="object"&&t.dangerouslySetInnerHTML!==null&&t.dangerouslySetInnerHTML.__html!=null}var ac=null;function Gv(){var l=window.event;return l&&l.type==="popstate"?l===ac?!1:(ac=l,!0):(ac=null,!1)}var to=typeof setTimeout=="function"?setTimeout:void 0,Xv=typeof clearTimeout=="function"?clearTimeout:void 0,ao=typeof Promise=="function"?Promise:void 0,Qv=typeof queueMicrotask=="function"?queueMicrotask:typeof ao<"u"?function(l){return ao.resolve(null).then(l).catch(Zv)}:to;function Zv(l){setTimeout(function(){throw l})}function Sa(l){return l==="head"}function uo(l,t){var a=t,u=0;do{var e=a.nextSibling;if(l.removeChild(a),e&&e.nodeType===8)if(a=e.data,a==="/$"||a==="/&"){if(u===0){l.removeChild(e),Mu(t);return}u--}else if(a==="$"||a==="$?"||a==="$~"||a==="$!"||a==="&")u++;else if(a==="html")ge(l.ownerDocument.documentElement);else if(a==="head"){a=l.ownerDocument.head,ge(a);for(var n=a.firstChild;n;){var f=n.nextSibling,i=n.nodeName;n[Cu]||i==="SCRIPT"||i==="STYLE"||i==="LINK"&&n.rel.toLowerCase()==="stylesheet"||a.removeChild(n),n=f}}else a==="body"&&ge(l.ownerDocument.body);a=e}while(a);Mu(t)}function eo(l,t){var a=l;l=0;do{var u=a.nextSibling;if(a.nodeType===1?t?(a._stashedDisplay=a.style.display,a.style.display="none"):(a.style.display=a._stashedDisplay||"",a.getAttribute("style")===""&&a.removeAttribute("style")):a.nodeType===3&&(t?(a._stashedText=a.nodeValue,a.nodeValue=""):a.nodeValue=a._stashedText||""),u&&u.nodeType===8)if(a=u.data,a==="/$"){if(l===0)break;l--}else a!=="$"&&a!=="$?"&&a!=="$~"&&a!=="$!"||l++;a=u}while(a)}function uc(l){var t=l.firstChild;for(t&&t.nodeType===10&&(t=t.nextSibling);t;){var a=t;switch(t=t.nextSibling,a.nodeName){case"HTML":case"HEAD":case"BODY":uc(a),cf(a);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(a.rel.toLowerCase()==="stylesheet")continue}l.removeChild(a)}}function Vv(l,t,a,u){for(;l.nodeType===1;){var e=a;if(l.nodeName.toLowerCase()!==t.toLowerCase()){if(!u&&(l.nodeName!=="INPUT"||l.type!=="hidden"))break}else if(u){if(!l[Cu])switch(t){case"meta":if(!l.hasAttribute("itemprop"))break;return l;case"link":if(n=l.getAttribute("rel"),n==="stylesheet"&&l.hasAttribute("data-precedence"))break;if(n!==e.rel||l.getAttribute("href")!==(e.href==null||e.href===""?null:e.href)||l.getAttribute("crossorigin")!==(e.crossOrigin==null?null:e.crossOrigin)||l.getAttribute("title")!==(e.title==null?null:e.title))break;return l;case"style":if(l.hasAttribute("data-precedence"))break;return l;case"script":if(n=l.getAttribute("src"),(n!==(e.src==null?null:e.src)||l.getAttribute("type")!==(e.type==null?null:e.type)||l.getAttribute("crossorigin")!==(e.crossOrigin==null?null:e.crossOrigin))&&n&&l.hasAttribute("async")&&!l.hasAttribute("itemprop"))break;return l;default:return l}}else if(t==="input"&&l.type==="hidden"){var n=e.name==null?null:""+e.name;if(e.type==="hidden"&&l.getAttribute("name")===n)return l}else return l;if(l=bt(l.nextSibling),l===null)break}return null}function Lv(l,t,a){if(t==="")return null;for(;l.nodeType!==3;)if((l.nodeType!==1||l.nodeName!=="INPUT"||l.type!=="hidden")&&!a||(l=bt(l.nextSibling),l===null))return null;return l}function no(l,t){for(;l.nodeType!==8;)if((l.nodeType!==1||l.nodeName!=="INPUT"||l.type!=="hidden")&&!t||(l=bt(l.nextSibling),l===null))return null;return l}function ec(l){return l.data==="$?"||l.data==="$~"}function nc(l){return l.data==="$!"||l.data==="$?"&&l.ownerDocument.readyState!=="loading"}function Kv(l,t){var a=l.ownerDocument;if(l.data==="$~")l._reactRetry=t;else if(l.data!=="$?"||a.readyState!=="loading")t();else{var u=function(){t(),a.removeEventListener("DOMContentLoaded",u)};a.addEventListener("DOMContentLoaded",u),l._reactRetry=u}}function bt(l){for(;l!=null;l=l.nextSibling){var t=l.nodeType;if(t===1||t===3)break;if(t===8){if(t=l.data,t==="$"||t==="$!"||t==="$?"||t==="$~"||t==="&"||t==="F!"||t==="F")break;if(t==="/$"||t==="/&")return null}}return l}var fc=null;function fo(l){l=l.nextSibling;for(var t=0;l;){if(l.nodeType===8){var a=l.data;if(a==="/$"||a==="/&"){if(t===0)return bt(l.nextSibling);t--}else a!=="$"&&a!=="$!"&&a!=="$?"&&a!=="$~"&&a!=="&"||t++}l=l.nextSibling}return null}function io(l){l=l.previousSibling;for(var t=0;l;){if(l.nodeType===8){var a=l.data;if(a==="$"||a==="$!"||a==="$?"||a==="$~"||a==="&"){if(t===0)return l;t--}else a!=="/$"&&a!=="/&"||t++}l=l.previousSibling}return null}function co(l,t,a){switch(t=Un(a),l){case"html":if(l=t.documentElement,!l)throw Error(h(452));return l;case"head":if(l=t.head,!l)throw Error(h(453));return l;case"body":if(l=t.body,!l)throw Error(h(454));return l;default:throw Error(h(451))}}function ge(l){for(var t=l.attributes;t.length;)l.removeAttributeNode(t[0]);cf(l)}var zt=new Map,so=new Set;function xn(l){return typeof l.getRootNode=="function"?l.getRootNode():l.nodeType===9?l:l.ownerDocument}var Ft=A.d;A.d={f:Jv,r:wv,D:Wv,C:kv,L:$v,m:Fv,X:Pv,S:Iv,M:lm};function Jv(){var l=Ft.f(),t=pn();return l||t}function wv(l){var t=Ja(l);t!==null&&t.tag===5&&t.type==="form"?Od(t):Ft.r(l)}var Au=typeof document>"u"?null:document;function oo(l,t,a){var u=Au;if(u&&typeof t=="string"&&t){var e=yt(t);e='link[rel="'+l+'"][href="'+e+'"]',typeof a=="string"&&(e+='[crossorigin="'+a+'"]'),so.has(e)||(so.add(e),l={rel:l,crossOrigin:a,href:t},u.querySelector(e)===null&&(t=u.createElement("link"),ql(t,"link",l),xl(t),u.head.appendChild(t)))}}function Wv(l){Ft.D(l),oo("dns-prefetch",l,null)}function kv(l,t){Ft.C(l,t),oo("preconnect",l,t)}function $v(l,t,a){Ft.L(l,t,a);var u=Au;if(u&&l&&t){var e='link[rel="preload"][as="'+yt(t)+'"]';t==="image"&&a&&a.imageSrcSet?(e+='[imagesrcset="'+yt(a.imageSrcSet)+'"]',typeof a.imageSizes=="string"&&(e+='[imagesizes="'+yt(a.imageSizes)+'"]')):e+='[href="'+yt(l)+'"]';var n=e;switch(t){case"style":n=_u(l);break;case"script":n=Ou(l)}zt.has(n)||(l=R({rel:"preload",href:t==="image"&&a&&a.imageSrcSet?void 0:l,as:t},a),zt.set(n,l),u.querySelector(e)!==null||t==="style"&&u.querySelector(Se(n))||t==="script"&&u.querySelector(re(n))||(t=u.createElement("link"),ql(t,"link",l),xl(t),u.head.appendChild(t)))}}function Fv(l,t){Ft.m(l,t);var a=Au;if(a&&l){var u=t&&typeof t.as=="string"?t.as:"script",e='link[rel="modulepreload"][as="'+yt(u)+'"][href="'+yt(l)+'"]',n=e;switch(u){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":n=Ou(l)}if(!zt.has(n)&&(l=R({rel:"modulepreload",href:l},t),zt.set(n,l),a.querySelector(e)===null)){switch(u){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(a.querySelector(re(n)))return}u=a.createElement("link"),ql(u,"link",l),xl(u),a.head.appendChild(u)}}}function Iv(l,t,a){Ft.S(l,t,a);var u=Au;if(u&&l){var e=wa(u).hoistableStyles,n=_u(l);t=t||"default";var f=e.get(n);if(!f){var i={loading:0,preload:null};if(f=u.querySelector(Se(n)))i.loading=5;else{l=R({rel:"stylesheet",href:l,"data-precedence":t},a),(a=zt.get(n))&&ic(l,a);var c=f=u.createElement("link");xl(c),ql(c,"link",l),c._p=new Promise(function(v,S){c.onload=v,c.onerror=S}),c.addEventListener("load",function(){i.loading|=1}),c.addEventListener("error",function(){i.loading|=2}),i.loading|=4,Hn(f,t,u)}f={type:"stylesheet",instance:f,count:1,state:i},e.set(n,f)}}}function Pv(l,t){Ft.X(l,t);var a=Au;if(a&&l){var u=wa(a).hoistableScripts,e=Ou(l),n=u.get(e);n||(n=a.querySelector(re(e)),n||(l=R({src:l,async:!0},t),(t=zt.get(e))&&cc(l,t),n=a.createElement("script"),xl(n),ql(n,"link",l),a.head.appendChild(n)),n={type:"script",instance:n,count:1,state:null},u.set(e,n))}}function lm(l,t){Ft.M(l,t);var a=Au;if(a&&l){var u=wa(a).hoistableScripts,e=Ou(l),n=u.get(e);n||(n=a.querySelector(re(e)),n||(l=R({src:l,async:!0,type:"module"},t),(t=zt.get(e))&&cc(l,t),n=a.createElement("script"),xl(n),ql(n,"link",l),a.head.appendChild(n)),n={type:"script",instance:n,count:1,state:null},u.set(e,n))}}function yo(l,t,a,u){var e=(e=Q.current)?xn(e):null;if(!e)throw Error(h(446));switch(l){case"meta":case"title":return null;case"style":return typeof a.precedence=="string"&&typeof a.href=="string"?(t=_u(a.href),a=wa(e).hoistableStyles,u=a.get(t),u||(u={type:"style",instance:null,count:0,state:null},a.set(t,u)),u):{type:"void",instance:null,count:0,state:null};case"link":if(a.rel==="stylesheet"&&typeof a.href=="string"&&typeof a.precedence=="string"){l=_u(a.href);var n=wa(e).hoistableStyles,f=n.get(l);if(f||(e=e.ownerDocument||e,f={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},n.set(l,f),(n=e.querySelector(Se(l)))&&!n._p&&(f.instance=n,f.state.loading=5),zt.has(l)||(a={rel:"preload",as:"style",href:a.href,crossOrigin:a.crossOrigin,integrity:a.integrity,media:a.media,hrefLang:a.hrefLang,referrerPolicy:a.referrerPolicy},zt.set(l,a),n||tm(e,l,a,f.state))),t&&u===null)throw Error(h(528,""));return f}if(t&&u!==null)throw Error(h(529,""));return null;case"script":return t=a.async,a=a.src,typeof a=="string"&&t&&typeof t!="function"&&typeof t!="symbol"?(t=Ou(a),a=wa(e).hoistableScripts,u=a.get(t),u||(u={type:"script",instance:null,count:0,state:null},a.set(t,u)),u):{type:"void",instance:null,count:0,state:null};default:throw Error(h(444,l))}}function _u(l){return'href="'+yt(l)+'"'}function Se(l){return'link[rel="stylesheet"]['+l+"]"}function vo(l){return R({},l,{"data-precedence":l.precedence,precedence:null})}function tm(l,t,a,u){l.querySelector('link[rel="preload"][as="style"]['+t+"]")?u.loading=1:(t=l.createElement("link"),u.preload=t,t.addEventListener("load",function(){return u.loading|=1}),t.addEventListener("error",function(){return u.loading|=2}),ql(t,"link",a),xl(t),l.head.appendChild(t))}function Ou(l){return'[src="'+yt(l)+'"]'}function re(l){return"script[async]"+l}function mo(l,t,a){if(t.count++,t.instance===null)switch(t.type){case"style":var u=l.querySelector('style[data-href~="'+yt(a.href)+'"]');if(u)return t.instance=u,xl(u),u;var e=R({},a,{"data-href":a.href,"data-precedence":a.precedence,href:null,precedence:null});return u=(l.ownerDocument||l).createElement("style"),xl(u),ql(u,"style",e),Hn(u,a.precedence,l),t.instance=u;case"stylesheet":e=_u(a.href);var n=l.querySelector(Se(e));if(n)return t.state.loading|=4,t.instance=n,xl(n),n;u=vo(a),(e=zt.get(e))&&ic(u,e),n=(l.ownerDocument||l).createElement("link"),xl(n);var f=n;return f._p=new Promise(function(i,c){f.onload=i,f.onerror=c}),ql(n,"link",u),t.state.loading|=4,Hn(n,a.precedence,l),t.instance=n;case"script":return n=Ou(a.src),(e=l.querySelector(re(n)))?(t.instance=e,xl(e),e):(u=a,(e=zt.get(n))&&(u=R({},a),cc(u,e)),l=l.ownerDocument||l,e=l.createElement("script"),xl(e),ql(e,"link",u),l.head.appendChild(e),t.instance=e);case"void":return null;default:throw Error(h(443,t.type))}else t.type==="stylesheet"&&(t.state.loading&4)===0&&(u=t.instance,t.state.loading|=4,Hn(u,a.precedence,l));return t.instance}function Hn(l,t,a){for(var u=a.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),e=u.length?u[u.length-1]:null,n=e,f=0;f<u.length;f++){var i=u[f];if(i.dataset.precedence===t)n=i;else if(n!==e)break}n?n.parentNode.insertBefore(l,n.nextSibling):(t=a.nodeType===9?a.head:a,t.insertBefore(l,t.firstChild))}function ic(l,t){l.crossOrigin==null&&(l.crossOrigin=t.crossOrigin),l.referrerPolicy==null&&(l.referrerPolicy=t.referrerPolicy),l.title==null&&(l.title=t.title)}function cc(l,t){l.crossOrigin==null&&(l.crossOrigin=t.crossOrigin),l.referrerPolicy==null&&(l.referrerPolicy=t.referrerPolicy),l.integrity==null&&(l.integrity=t.integrity)}var Rn=null;function ho(l,t,a){if(Rn===null){var u=new Map,e=Rn=new Map;e.set(a,u)}else e=Rn,u=e.get(a),u||(u=new Map,e.set(a,u));if(u.has(l))return u;for(u.set(l,null),a=a.getElementsByTagName(l),e=0;e<a.length;e++){var n=a[e];if(!(n[Cu]||n[Nl]||l==="link"&&n.getAttribute("rel")==="stylesheet")&&n.namespaceURI!=="http://www.w3.org/2000/svg"){var f=n.getAttribute(t)||"";f=l+f;var i=u.get(f);i?i.push(n):u.set(f,[n])}}return u}function go(l,t,a){l=l.ownerDocument||l,l.head.insertBefore(a,t==="title"?l.querySelector("head > title"):null)}function am(l,t,a){if(a===1||t.itemProp!=null)return!1;switch(l){case"meta":case"title":return!0;case"style":if(typeof t.precedence!="string"||typeof t.href!="string"||t.href==="")break;return!0;case"link":if(typeof t.rel!="string"||typeof t.href!="string"||t.href===""||t.onLoad||t.onError)break;switch(t.rel){case"stylesheet":return l=t.disabled,typeof t.precedence=="string"&&l==null;default:return!0}case"script":if(t.async&&typeof t.async!="function"&&typeof t.async!="symbol"&&!t.onLoad&&!t.onError&&t.src&&typeof t.src=="string")return!0}return!1}function So(l){return!(l.type==="stylesheet"&&(l.state.loading&3)===0)}function um(l,t,a,u){if(a.type==="stylesheet"&&(typeof u.media!="string"||matchMedia(u.media).matches!==!1)&&(a.state.loading&4)===0){if(a.instance===null){var e=_u(u.href),n=t.querySelector(Se(e));if(n){t=n._p,t!==null&&typeof t=="object"&&typeof t.then=="function"&&(l.count++,l=Nn.bind(l),t.then(l,l)),a.state.loading|=4,a.instance=n,xl(n);return}n=t.ownerDocument||t,u=vo(u),(e=zt.get(e))&&ic(u,e),n=n.createElement("link"),xl(n);var f=n;f._p=new Promise(function(i,c){f.onload=i,f.onerror=c}),ql(n,"link",u),a.instance=n}l.stylesheets===null&&(l.stylesheets=new Map),l.stylesheets.set(a,t),(t=a.state.preload)&&(a.state.loading&3)===0&&(l.count++,a=Nn.bind(l),t.addEventListener("load",a),t.addEventListener("error",a))}}var sc=0;function em(l,t){return l.stylesheets&&l.count===0&&Bn(l,l.stylesheets),0<l.count||0<l.imgCount?function(a){var u=setTimeout(function(){if(l.stylesheets&&Bn(l,l.stylesheets),l.unsuspend){var n=l.unsuspend;l.unsuspend=null,n()}},6e4+t);0<l.imgBytes&&sc===0&&(sc=62500*Yv());var e=setTimeout(function(){if(l.waitingForImages=!1,l.count===0&&(l.stylesheets&&Bn(l,l.stylesheets),l.unsuspend)){var n=l.unsuspend;l.unsuspend=null,n()}},(l.imgBytes>sc?50:800)+t);return l.unsuspend=a,function(){l.unsuspend=null,clearTimeout(u),clearTimeout(e)}}:null}function Nn(){if(this.count--,this.count===0&&(this.imgCount===0||!this.waitingForImages)){if(this.stylesheets)Bn(this,this.stylesheets);else if(this.unsuspend){var l=this.unsuspend;this.unsuspend=null,l()}}}var Cn=null;function Bn(l,t){l.stylesheets=null,l.unsuspend!==null&&(l.count++,Cn=new Map,t.forEach(nm,l),Cn=null,Nn.call(l))}function nm(l,t){if(!(t.state.loading&4)){var a=Cn.get(l);if(a)var u=a.get(null);else{a=new Map,Cn.set(l,a);for(var e=l.querySelectorAll("link[data-precedence],style[data-precedence]"),n=0;n<e.length;n++){var f=e[n];(f.nodeName==="LINK"||f.getAttribute("media")!=="not all")&&(a.set(f.dataset.precedence,f),u=f)}u&&a.set(null,u)}e=t.instance,f=e.getAttribute("data-precedence"),n=a.get(f)||u,n===u&&a.set(null,e),a.set(f,e),this.count++,u=Nn.bind(this),e.addEventListener("load",u),e.addEventListener("error",u),n?n.parentNode.insertBefore(e,n.nextSibling):(l=l.nodeType===9?l.head:l,l.insertBefore(e,l.firstChild)),t.state.loading|=4}}var be={$$typeof:bl,Provider:null,Consumer:null,_currentValue:B,_currentValue2:B,_threadCount:0};function fm(l,t,a,u,e,n,f,i,c){this.tag=1,this.containerInfo=l,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=uf(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=uf(0),this.hiddenUpdates=uf(null),this.identifierPrefix=u,this.onUncaughtError=e,this.onCaughtError=n,this.onRecoverableError=f,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=c,this.incompleteTransitions=new Map}function ro(l,t,a,u,e,n,f,i,c,v,S,z){return l=new fm(l,t,a,f,c,v,S,z,i),t=1,n===!0&&(t|=24),n=et(3,null,null,t),l.current=n,n.stateNode=l,t=Zf(),t.refCount++,l.pooledCache=t,t.refCount++,n.memoizedState={element:u,isDehydrated:a,cache:t},Jf(n),l}function bo(l){return l?(l=uu,l):uu}function zo(l,t,a,u,e,n){e=bo(e),u.context===null?u.context=e:u.pendingContext=e,u=fa(t),u.payload={element:a},n=n===void 0?null:n,n!==null&&(u.callback=n),a=ia(l,u,t),a!==null&&(Il(a,l,t),Fu(a,l,t))}function po(l,t){if(l=l.memoizedState,l!==null&&l.dehydrated!==null){var a=l.retryLane;l.retryLane=a!==0&&a<t?a:t}}function dc(l,t){po(l,t),(l=l.alternate)&&po(l,t)}function To(l){if(l.tag===13||l.tag===31){var t=xa(l,67108864);t!==null&&Il(t,l,67108864),dc(l,67108864)}}function Eo(l){if(l.tag===13||l.tag===31){var t=st();t=ef(t);var a=xa(l,t);a!==null&&Il(a,l,t),dc(l,t)}}var jn=!0;function im(l,t,a,u){var e=r.T;r.T=null;var n=A.p;try{A.p=2,oc(l,t,a,u)}finally{A.p=n,r.T=e}}function cm(l,t,a,u){var e=r.T;r.T=null;var n=A.p;try{A.p=8,oc(l,t,a,u)}finally{A.p=n,r.T=e}}function oc(l,t,a,u){if(jn){var e=yc(u);if(e===null)Fi(l,t,u,qn,a),_o(l,u);else if(dm(e,l,t,a,u))u.stopPropagation();else if(_o(l,u),t&4&&-1<sm.indexOf(l)){for(;e!==null;){var n=Ja(e);if(n!==null)switch(n.tag){case 3:if(n=n.stateNode,n.current.memoizedState.isDehydrated){var f=_a(n.pendingLanes);if(f!==0){var i=n;for(i.pendingLanes|=2,i.entangledLanes|=2;f;){var c=1<<31-at(f);i.entanglements[1]|=c,f&=~c}Ht(n),(ll&6)===0&&(bn=lt()+500,ve(0))}}break;case 31:case 13:i=xa(n,2),i!==null&&Il(i,n,2),pn(),dc(n,2)}if(n=yc(u),n===null&&Fi(l,t,u,qn,a),n===e)break;e=n}e!==null&&u.stopPropagation()}else Fi(l,t,u,null,a)}}function yc(l){return l=mf(l),vc(l)}var qn=null;function vc(l){if(qn=null,l=Ka(l),l!==null){var t=Sl(l);if(t===null)l=null;else{var a=t.tag;if(a===13){if(l=rl(t),l!==null)return l;l=null}else if(a===31){if(l=Dl(t),l!==null)return l;l=null}else if(a===3){if(t.stateNode.current.memoizedState.isDehydrated)return t.tag===3?t.stateNode.containerInfo:null;l=null}else t!==l&&(l=null)}}return qn=l,null}function Ao(l){switch(l){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(Wo()){case Hc:return 2;case Rc:return 8;case _e:case ko:return 32;case Nc:return 268435456;default:return 32}default:return 32}}var mc=!1,ra=null,ba=null,za=null,ze=new Map,pe=new Map,pa=[],sm="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function _o(l,t){switch(l){case"focusin":case"focusout":ra=null;break;case"dragenter":case"dragleave":ba=null;break;case"mouseover":case"mouseout":za=null;break;case"pointerover":case"pointerout":ze.delete(t.pointerId);break;case"gotpointercapture":case"lostpointercapture":pe.delete(t.pointerId)}}function Te(l,t,a,u,e,n){return l===null||l.nativeEvent!==n?(l={blockedOn:t,domEventName:a,eventSystemFlags:u,nativeEvent:n,targetContainers:[e]},t!==null&&(t=Ja(t),t!==null&&To(t)),l):(l.eventSystemFlags|=u,t=l.targetContainers,e!==null&&t.indexOf(e)===-1&&t.push(e),l)}function dm(l,t,a,u,e){switch(t){case"focusin":return ra=Te(ra,l,t,a,u,e),!0;case"dragenter":return ba=Te(ba,l,t,a,u,e),!0;case"mouseover":return za=Te(za,l,t,a,u,e),!0;case"pointerover":var n=e.pointerId;return ze.set(n,Te(ze.get(n)||null,l,t,a,u,e)),!0;case"gotpointercapture":return n=e.pointerId,pe.set(n,Te(pe.get(n)||null,l,t,a,u,e)),!0}return!1}function Oo(l){var t=Ka(l.target);if(t!==null){var a=Sl(t);if(a!==null){if(t=a.tag,t===13){if(t=rl(a),t!==null){l.blockedOn=t,Gc(l.priority,function(){Eo(a)});return}}else if(t===31){if(t=Dl(a),t!==null){l.blockedOn=t,Gc(l.priority,function(){Eo(a)});return}}else if(t===3&&a.stateNode.current.memoizedState.isDehydrated){l.blockedOn=a.tag===3?a.stateNode.containerInfo:null;return}}}l.blockedOn=null}function Yn(l){if(l.blockedOn!==null)return!1;for(var t=l.targetContainers;0<t.length;){var a=yc(l.nativeEvent);if(a===null){a=l.nativeEvent;var u=new a.constructor(a.type,a);vf=u,a.target.dispatchEvent(u),vf=null}else return t=Ja(a),t!==null&&To(t),l.blockedOn=a,!1;t.shift()}return!0}function Mo(l,t,a){Yn(l)&&a.delete(t)}function om(){mc=!1,ra!==null&&Yn(ra)&&(ra=null),ba!==null&&Yn(ba)&&(ba=null),za!==null&&Yn(za)&&(za=null),ze.forEach(Mo),pe.forEach(Mo)}function Gn(l,t){l.blockedOn===t&&(l.blockedOn=null,mc||(mc=!0,E.unstable_scheduleCallback(E.unstable_NormalPriority,om)))}var Xn=null;function Do(l){Xn!==l&&(Xn=l,E.unstable_scheduleCallback(E.unstable_NormalPriority,function(){Xn===l&&(Xn=null);for(var t=0;t<l.length;t+=3){var a=l[t],u=l[t+1],e=l[t+2];if(typeof u!="function"){if(vc(u||a)===null)continue;break}var n=Ja(a);n!==null&&(l.splice(t,3),t-=3,yi(n,{pending:!0,data:e,method:a.method,action:u},u,e))}}))}function Mu(l){function t(c){return Gn(c,l)}ra!==null&&Gn(ra,l),ba!==null&&Gn(ba,l),za!==null&&Gn(za,l),ze.forEach(t),pe.forEach(t);for(var a=0;a<pa.length;a++){var u=pa[a];u.blockedOn===l&&(u.blockedOn=null)}for(;0<pa.length&&(a=pa[0],a.blockedOn===null);)Oo(a),a.blockedOn===null&&pa.shift();if(a=(l.ownerDocument||l).$$reactFormReplay,a!=null)for(u=0;u<a.length;u+=3){var e=a[u],n=a[u+1],f=e[Jl]||null;if(typeof n=="function")f||Do(a);else if(f){var i=null;if(n&&n.hasAttribute("formAction")){if(e=n,f=n[Jl]||null)i=f.formAction;else if(vc(e)!==null)continue}else i=f.action;typeof i=="function"?a[u+1]=i:(a.splice(u,3),u-=3),Do(a)}}}function Uo(){function l(n){n.canIntercept&&n.info==="react-transition"&&n.intercept({handler:function(){return new Promise(function(f){return e=f})},focusReset:"manual",scroll:"manual"})}function t(){e!==null&&(e(),e=null),u||setTimeout(a,20)}function a(){if(!u&&!navigation.transition){var n=navigation.currentEntry;n&&n.url!=null&&navigation.navigate(n.url,{state:n.getState(),info:"react-transition",history:"replace"})}}if(typeof navigation=="object"){var u=!1,e=null;return navigation.addEventListener("navigate",l),navigation.addEventListener("navigatesuccess",t),navigation.addEventListener("navigateerror",t),setTimeout(a,100),function(){u=!0,navigation.removeEventListener("navigate",l),navigation.removeEventListener("navigatesuccess",t),navigation.removeEventListener("navigateerror",t),e!==null&&(e(),e=null)}}}function hc(l){this._internalRoot=l}Qn.prototype.render=hc.prototype.render=function(l){var t=this._internalRoot;if(t===null)throw Error(h(409));var a=t.current,u=st();zo(a,u,l,t,null,null)},Qn.prototype.unmount=hc.prototype.unmount=function(){var l=this._internalRoot;if(l!==null){this._internalRoot=null;var t=l.containerInfo;zo(l.current,2,null,l,null,null),pn(),t[La]=null}};function Qn(l){this._internalRoot=l}Qn.prototype.unstable_scheduleHydration=function(l){if(l){var t=Yc();l={blockedOn:null,target:l,priority:t};for(var a=0;a<pa.length&&t!==0&&t<pa[a].priority;a++);pa.splice(a,0,l),a===0&&Oo(l)}};var xo=cl.version;if(xo!=="19.2.4")throw Error(h(527,xo,"19.2.4"));A.findDOMNode=function(l){var t=l._reactInternals;if(t===void 0)throw typeof l.render=="function"?Error(h(188)):(l=Object.keys(l).join(","),Error(h(268,l)));return l=T(t),l=l!==null?$(l):null,l=l===null?null:l.stateNode,l};var ym={bundleType:0,version:"19.2.4",rendererPackageName:"react-dom",currentDispatcherRef:r,reconcilerVersion:"19.2.4"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var Zn=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!Zn.isDisabled&&Zn.supportsFiber)try{Hu=Zn.inject(ym),tt=Zn}catch{}}return Uu.createRoot=function(l,t){if(!vl(l))throw Error(h(299));var a=!1,u="",e=jd,n=qd,f=Yd;return t!=null&&(t.unstable_strictMode===!0&&(a=!0),t.identifierPrefix!==void 0&&(u=t.identifierPrefix),t.onUncaughtError!==void 0&&(e=t.onUncaughtError),t.onCaughtError!==void 0&&(n=t.onCaughtError),t.onRecoverableError!==void 0&&(f=t.onRecoverableError)),t=ro(l,1,!1,null,null,a,u,null,e,n,f,Uo),l[La]=t.current,$i(l),new hc(t)},Uu.hydrateRoot=function(l,t,a){if(!vl(l))throw Error(h(299));var u=!1,e="",n=jd,f=qd,i=Yd,c=null;return a!=null&&(a.unstable_strictMode===!0&&(u=!0),a.identifierPrefix!==void 0&&(e=a.identifierPrefix),a.onUncaughtError!==void 0&&(n=a.onUncaughtError),a.onCaughtError!==void 0&&(f=a.onCaughtError),a.onRecoverableError!==void 0&&(i=a.onRecoverableError),a.formState!==void 0&&(c=a.formState)),t=ro(l,1,!0,t,a??null,u,e,c,n,f,i,Uo),t.context=bo(null),a=t.current,u=st(),u=ef(u),e=fa(u),e.callback=null,ia(a,e,u),a=u,t.current.lanes=a,Nu(t,a),Ht(t),l[La]=t.current,$i(l),new Qn(t)},Uu.version="19.2.4",Uu}var _c;function Go(){if(_c)return Ln.exports;_c=1;function E(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(E)}catch(cl){console.error(cl)}}return E(),Ln.exports=Yo(),Ln.exports}var Xo=Go(),Rt=Wn();const L={bg:"var(--bg)",bgCard:"var(--bg2)",accent:"var(--accent)",text:"var(--text)",textMuted:"var(--text2)",error:"var(--red)",border:"var(--border)",danger:"var(--red)"},X={container:{background:L.bg,color:L.text,fontFamily:"'Inter', 'Segoe UI', system-ui, sans-serif",fontSize:"14px",padding:"16px",borderRadius:"8px",border:`1px solid ${L.border}`,minWidth:"360px"},header:{display:"flex",alignItems:"center",justifyContent:"space-between",marginBottom:"16px"},title:{margin:0,fontSize:"16px",fontWeight:600,color:L.text},refreshBtn:{background:"transparent",border:`1px solid ${L.border}`,color:L.textMuted,borderRadius:"6px",padding:"4px 10px",cursor:"pointer",fontSize:"13px",transition:"color 0.15s, border-color 0.15s"},form:{background:L.bgCard,border:`1px solid ${L.border}`,borderRadius:"8px",padding:"12px",marginBottom:"16px"},textarea:{width:"100%",background:L.bg,border:`1px solid ${L.border}`,borderRadius:"6px",color:L.text,padding:"8px 10px",fontSize:"13px",resize:"vertical",minHeight:"72px",boxSizing:"border-box",outline:"none",fontFamily:"inherit"},formRow:{display:"flex",gap:"8px",marginTop:"8px",alignItems:"center"},select:{background:L.bg,border:`1px solid ${L.border}`,borderRadius:"6px",color:L.text,padding:"6px 10px",fontSize:"13px",outline:"none",cursor:"pointer",flex:"0 0 auto"},spawnBtn:{background:L.accent,border:"none",borderRadius:"6px",color:"white",padding:"6px 16px",fontSize:"13px",fontWeight:600,cursor:"pointer",flex:"1",transition:"background 0.15s"},spawnBtnDisabled:{background:"var(--accent-dim, rgba(99,140,255,0.3))",cursor:"not-allowed",opacity:.6},section:{marginBottom:"12px"},sectionTitle:{fontSize:"11px",fontWeight:700,textTransform:"uppercase",letterSpacing:"0.08em",color:L.textMuted,marginBottom:"8px",marginTop:0},taskCard:{background:L.bgCard,border:`1px solid ${L.border}`,borderRadius:"6px",padding:"10px 12px",marginBottom:"6px",display:"flex",flexDirection:"column",gap:"6px"},taskRow:{display:"flex",alignItems:"center",justifyContent:"space-between",gap:"8px"},taskDesc:{color:L.text,fontSize:"13px",flex:1,overflow:"hidden",textOverflow:"ellipsis",whiteSpace:"nowrap"},taskMeta:{display:"flex",alignItems:"center",gap:"8px",flexShrink:0},modelBadge:{background:"var(--accent-dim, rgba(99,140,255,0.15))",color:"var(--accent)",borderRadius:"4px",padding:"2px 6px",fontSize:"11px",fontWeight:600,textTransform:"capitalize"},elapsed:{color:L.textMuted,fontSize:"12px",flexShrink:0},spinner:{display:"inline-block",width:"14px",height:"14px",border:`2px solid ${L.border}`,borderTopColor:L.accent,borderRadius:"50%",flexShrink:0},killBtn:{background:"transparent",border:`1px solid ${L.danger}`,color:L.error,borderRadius:"4px",padding:"2px 8px",fontSize:"12px",cursor:"pointer",flexShrink:0},viewBtn:{background:"transparent",border:`1px solid ${L.border}`,color:L.textMuted,borderRadius:"4px",padding:"2px 8px",fontSize:"12px",cursor:"pointer",flexShrink:0},emptyState:{color:L.textMuted,fontSize:"13px",textAlign:"center",padding:"12px 0",fontStyle:"italic"},errorMsg:{color:L.error,fontSize:"12px",marginTop:"6px"},modalOverlay:{position:"fixed",inset:0,background:"rgba(0,0,0,0.7)",display:"flex",alignItems:"center",justifyContent:"center",zIndex:9999},modalBox:{background:L.bgCard,border:`1px solid ${L.border}`,borderRadius:"10px",width:"90vw",maxWidth:"640px",maxHeight:"80vh",display:"flex",flexDirection:"column",overflow:"hidden"},modalHeader:{display:"flex",alignItems:"center",justifyContent:"space-between",padding:"12px 16px",borderBottom:`1px solid ${L.border}`},modalTitle:{color:L.text,fontWeight:600,fontSize:"14px",margin:0},modalCloseBtn:{background:"transparent",border:"none",color:L.textMuted,fontSize:"18px",cursor:"pointer",lineHeight:1,padding:"0 4px"},modalBody:{overflowY:"auto",padding:"16px",flex:1},outputPre:{background:L.bg,border:`1px solid ${L.border}`,borderRadius:"6px",padding:"12px",color:L.text,fontSize:"12px",fontFamily:"'JetBrains Mono', 'Fira Code', monospace",whiteSpace:"pre-wrap",wordBreak:"break-all",margin:0,lineHeight:1.6}};function Oc(E){if(E<1e3)return`${E}ms`;if(E<6e4)return`${(E/1e3).toFixed(1)}s`;const cl=Math.floor(E/6e4),k=Math.floor(E%6e4/1e3);return`${cl}m ${k}s`}function $n(E,cl){return E.length>cl?E.slice(0,cl)+"…":E}function Qo(){return window._tok||localStorage.getItem("session_token")||""}function Ee(){return{"Content-Type":"application/json","X-Session-Token":Qo()}}let Mc=!1;function Zo(){if(Mc)return;Mc=!0;const E=document.createElement("style");E.textContent="@keyframes _salmalm_spin { to { transform: rotate(360deg); } }",document.head.appendChild(E)}function Vo({task:E,onClose:cl}){return U.jsx("div",{style:X.modalOverlay,onClick:cl,children:U.jsxs("div",{style:X.modalBox,onClick:k=>k.stopPropagation(),children:[U.jsxs("div",{style:X.modalHeader,children:[U.jsxs("p",{style:X.modalTitle,children:["Task Output — ",$n(E.description,60)]}),U.jsx("button",{style:X.modalCloseBtn,onClick:cl,children:"×"})]}),U.jsx("div",{style:X.modalBody,children:U.jsx("pre",{style:X.outputPre,children:E.output||E.result_preview||"(no output)"})})]})})}function Lo(){const[E,cl]=Rt.useState([]),[k,h]=Rt.useState(""),[vl,Sl]=Rt.useState("auto"),[rl,Dl]=Rt.useState(!1),[x,T]=Rt.useState(""),[$,R]=Rt.useState(null);Rt.useEffect(()=>{Zo()},[]);const F=Rt.useCallback(async()=>{try{const C=await fetch("/api/agent/tasks",{headers:Ee()});if(C.ok){const bl=await C.json();cl(bl.tasks??[])}}catch{}},[]);Rt.useEffect(()=>{F();const C=setInterval(F,3e3);return()=>clearInterval(C)},[F]);const Gl=async()=>{if(k.trim()){Dl(!0),T("");try{const bl=await(await fetch("/api/agent/task",{method:"POST",headers:Ee(),body:JSON.stringify({description:k.trim(),model:vl})})).json();bl.ok?(h(""),await F()):T(bl.error||"Failed to spawn agent")}catch(C){T((C==null?void 0:C.message)||"Network error")}finally{Dl(!1)}}},Xl=async C=>{try{await fetch(`/api/agent/task/${C}`,{method:"DELETE",headers:Ee()}),await F()}catch{}},Rl=async()=>{try{await fetch("/api/agent/tasks/clear",{method:"POST",headers:{...Ee(),"Content-Type":"application/json"},body:"{}"}),await F()}catch{}},Pl=E.filter(C=>C.status==="running"||C.status==="pending"),Ul=E.filter(C=>C.status==="done"||C.status==="failed"||C.status==="cancelled");return U.jsxs("div",{style:X.container,children:[U.jsxs("div",{style:X.header,children:[U.jsx("h2",{style:X.title,children:"🤖 Agent Tasks"}),U.jsx("button",{style:X.refreshBtn,onClick:F,children:"↻ Refresh"})]}),U.jsxs("div",{style:X.form,children:[U.jsx("textarea",{style:X.textarea,value:k,onChange:C=>h(C.target.value),placeholder:"Describe what you want the agent to do...",rows:3,onKeyDown:C=>{C.key==="Enter"&&(C.ctrlKey||C.metaKey)&&Gl()}}),U.jsxs("div",{style:X.formRow,children:[U.jsxs("select",{style:X.select,value:vl,onChange:C=>Sl(C.target.value),children:[U.jsx("option",{value:"auto",children:"auto"}),U.jsxs("optgroup",{label:"── Anthropic ──",children:[U.jsx("option",{value:"haiku",children:"haiku"}),U.jsx("option",{value:"sonnet",children:"sonnet"}),U.jsx("option",{value:"opus",children:"opus"})]}),U.jsxs("optgroup",{label:"── OpenAI ──",children:[U.jsx("option",{value:"gpt-4o-mini",children:"gpt-4o-mini"}),U.jsx("option",{value:"gpt-4o",children:"gpt-4o"}),U.jsx("option",{value:"gpt",children:"gpt (5.2)"})]}),U.jsxs("optgroup",{label:"── Google ──",children:[U.jsx("option",{value:"gemini-2.0-flash",children:"gemini-flash"}),U.jsx("option",{value:"gemini-2.5-pro-preview-03-25",children:"gemini-pro"})]}),U.jsxs("optgroup",{label:"── xAI ──",children:[U.jsx("option",{value:"grok-3-mini",children:"grok-mini"}),U.jsx("option",{value:"grok-3",children:"grok-3"})]})]}),U.jsx("button",{style:{...X.spawnBtn,...rl?X.spawnBtnDisabled:{}},disabled:rl,onClick:Gl,children:rl?"Spawning…":"⚡ Spawn Agent"})]}),x&&U.jsxs("p",{style:X.errorMsg,children:["⚠ ",x]})]}),U.jsxs("div",{style:X.section,children:[U.jsxs("p",{style:X.sectionTitle,children:["⚙ Active (",Pl.length,")"]}),Pl.length===0?U.jsx("p",{style:X.emptyState,children:"No active tasks — spawn one above!"}):Pl.map(C=>U.jsx("div",{style:X.taskCard,children:U.jsxs("div",{style:X.taskRow,children:[U.jsx("span",{style:{...X.spinner,animation:"_salmalm_spin 0.8s linear infinite"}}),U.jsx("span",{style:X.taskDesc,children:$n(C.description,80)}),U.jsxs("div",{style:X.taskMeta,children:[U.jsx("span",{style:X.modelBadge,children:C.model}),U.jsx("span",{style:X.elapsed,children:Oc(C.elapsed_ms)}),U.jsx("button",{style:X.killBtn,onClick:()=>Xl(C.id),children:"Kill"})]})]})},C.id))]}),U.jsxs("div",{style:X.section,children:[U.jsxs("div",{style:{display:"flex",alignItems:"center",justifyContent:"space-between",marginBottom:"8px"},children:[U.jsxs("p",{style:{...X.sectionTitle,margin:0},children:["✓ Completed (",Ul.length,")"]}),Ul.length>0&&U.jsx("button",{onClick:Rl,style:{fontSize:"11px",padding:"3px 10px",borderRadius:"6px",border:"1px solid #7f1d1d",background:"#1a0505",color:"#fca5a5",cursor:"pointer"},children:"🗑 전체 삭제"})]}),Ul.length===0?U.jsx("p",{style:X.emptyState,children:"Completed tasks will appear here."}):Ul.map(C=>U.jsx("div",{style:X.taskCard,children:U.jsxs("div",{style:X.taskRow,children:[U.jsx("span",{style:{fontSize:"15px",flexShrink:0},children:C.status==="done"?"✅":"❌"}),U.jsx("span",{style:X.taskDesc,children:$n(C.description,80)}),U.jsxs("div",{style:X.taskMeta,children:[U.jsx("span",{style:X.modelBadge,children:C.model}),U.jsx("span",{style:X.elapsed,children:Oc(C.elapsed_ms)}),U.jsx("button",{style:X.viewBtn,onClick:()=>R(C),children:"View Output"})]})]})},C.id))]}),$&&U.jsx(Vo,{task:$,onClose:()=>R(null)})]})}const Dc=()=>{const E=document.getElementById("agent-panel-root");E&&Xo.createRoot(E).render(U.jsx(Lo,{}))};document.readyState==="loading"?document.addEventListener("DOMContentLoaded",Dc):Dc()})();
